import * as _angular_core from '@angular/core';
import { AfterViewInit, OnDestroy } from '@angular/core';
import * as i2 from 'tableau-ui-angular/button';
import * as i3 from 'tableau-ui-angular/common';
import * as i4 from 'tableau-ui-angular/icon';

declare class ArrowScrollComponent implements AfterViewInit, OnDestroy {
    /**
     * The type of scroll behavior to use.
     * 'default' uses the default scroll behavior,
     * 'arrow' uses arrow buttons for scrolling.
     */
    readonly $scrollType: _angular_core.InputSignal<"arrow" | "default">;
    /**
     * The direction of the scroll.
     * 'horizontal' scrolls horizontally,
     * 'vertical' scrolls vertically.
     */
    readonly $scrollDirection: _angular_core.InputSignal<"horizontal" | "vertical">;
    /**
     * Gap between the scroll buttons the scroll container, can be adjusted to fit design requirements.
     * @default '0.25rem'
     */
    readonly $buttonsGap: _angular_core.InputSignal<string>;
    /**
     * Color of the scroll buttons, can be adjusted to fit design requirements.
     * @default 'plain'
     */
    readonly $buttonsColor: _angular_core.InputSignal<"error" | "plain" | "primary" | "secondary">;
    /**
     * CSS color for the scroll button icons, can be adjusted to fit design requirements.
     * @default undefined
     */
    readonly $buttonsCssColor: _angular_core.InputSignal<string>;
    /**
     * The amount to scroll when the scroll buttons are clicked.
     * This value is in pixels for vertical scrolling and in pixels for horizontal scrolling.
     * @default 100
     */
    readonly $buttonScrollAmount: _angular_core.InputSignal<number>;
    /**
     * Whether to show a separator between the scroll buttons and the scroll container.
     * @default false
     */
    readonly $showScrollButtonSeparator: _angular_core.InputSignal<boolean>;
    private readonly $scrollContainer;
    private readonly $scrollContainerDimensions;
    protected readonly $scrollArrowsVisible: _angular_core.Signal<boolean>;
    private readonly scrollDirectionChanged;
    private readonly $scrollLeft;
    private readonly $scrollTop;
    readonly $canScroll: _angular_core.Signal<{
        back: boolean;
        forward: boolean;
    }>;
    private observer;
    private scrollHandler;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    onResize(): void;
    private recalculateScrollContainerDimensions;
    private wheelHandler;
    private overrideMouseWheelForHorizontal;
    private removeMouseWheelOverride;
    scroll(direction: 'back' | 'forward'): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<ArrowScrollComponent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<ArrowScrollComponent, "tab-arrow-scroll", never, { "$scrollType": { "alias": "scrollType"; "required": true; "isSignal": true; }; "$scrollDirection": { "alias": "scrollDirection"; "required": true; "isSignal": true; }; "$buttonsGap": { "alias": "buttonsGap"; "required": false; "isSignal": true; }; "$buttonsColor": { "alias": "buttonsColor"; "required": false; "isSignal": true; }; "$buttonsCssColor": { "alias": "buttonsCssColor"; "required": false; "isSignal": true; }; "$buttonScrollAmount": { "alias": "buttonScrollAmount"; "required": false; "isSignal": true; }; "$showScrollButtonSeparator": { "alias": "showScrollButtonSeparator"; "required": false; "isSignal": true; }; }, {}, never, ["tab-icon[back-button]", "*", "tab-icon[forward-button]"], false, never>;
}

declare class TableauUiArrowScrollModule {
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<TableauUiArrowScrollModule, never>;
    static ɵmod: _angular_core.ɵɵNgModuleDeclaration<TableauUiArrowScrollModule, [typeof ArrowScrollComponent], [typeof i2.TableauUiButtonModule, typeof i3.TableauUiCommonModule, typeof i4.TableauUiIconModule], [typeof ArrowScrollComponent]>;
    static ɵinj: _angular_core.ɵɵInjectorDeclaration<TableauUiArrowScrollModule>;
}

export { ArrowScrollComponent, TableauUiArrowScrollModule };
