import * as i0 from '@angular/core';
import { Signal, TemplateRef, WritableSignal, OnDestroy } from '@angular/core';
import { Subject } from 'rxjs';
import * as i3 from 'tableau-ui-angular/common';
import { OptionComponent, IOptionGridContext, PrefixComponent, SuffixComponent } from 'tableau-ui-angular/common';
import * as i5 from 'tableau-ui-angular/dialog';
import { DialogRef } from 'tableau-ui-angular/dialog';
import { Primitive } from 'tableau-ui-angular/types';
import * as i4 from '@angular/common';

declare class AutoCompleteComponent<T extends Primitive> {
    private readonly dialogService;
    private readonly elementRef;
    protected readonly dropdownId: string;
    readonly selectValue$: Subject<OptionComponent<T>>;
    /**
     * The CSS text to apply to the dropdown container
     * @remarks
     * Use this to apply height, maxHeight, etc. to the dropdown container
     * @default '{}'
     */
    readonly $dropdownContainerCss: i0.ModelSignal<Record<string, string>>;
    /**
     * The CSS text to apply to the options container in the dropdown
     * @remarks
     * Use this to apply height, maxHeight, etc. to the dropdown
     * This is applied to the options container, excluding the prefix & suffix
     *
     * @default "{ maxHeight: '300px', height: 'fit-content'}"
     */
    readonly $dropdownOptionsContainerCss: i0.ModelSignal<Record<string, string>>;
    /**
     * The template context to use for the dropdown options
     * @remarks
     * Use this to display the 'icon', 'text', and 'hint' properties of the options conditionally
     */
    readonly $dropdownValueTemplateContext: i0.ModelSignal<IOptionGridContext>;
    protected readonly $options: Signal<readonly OptionComponent<T>[]>;
    protected readonly $dropdownPrefix: Signal<PrefixComponent | undefined>;
    protected readonly $dropdownSuffix: Signal<SuffixComponent | undefined>;
    protected readonly $dropdownTemplate: Signal<TemplateRef<null> | undefined>;
    constructor();
    private readonly $openDialog;
    openDropdown(parentControl: HTMLInputElement): DialogRef<unknown>;
    closeDropdown(): void;
    protected readonly $highlightedOption: WritableSignal<OptionComponent<T> | undefined>;
    protected optionMouseDown(event: MouseEvent): void;
    private optionKeyNavSubscription;
    private registerKeyNavigation;
    private unregisterKeyNavigation;
    /**
     *
     * @param e Handles KeyDown event for:
     * - host element
     * - global keydown event when dropdown is open
     * @returns
     */
    private onKeyDown;
    static ɵfac: i0.ɵɵFactoryDeclaration<AutoCompleteComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AutoCompleteComponent<any>, "tab-autocomplete", never, { "$dropdownContainerCss": { "alias": "dropdownContainerCss"; "required": false; "isSignal": true; }; "$dropdownOptionsContainerCss": { "alias": "dropdownOptionsContainerCss"; "required": false; "isSignal": true; }; "$dropdownValueTemplateContext": { "alias": "dropdownValueTemplateContext"; "required": false; "isSignal": true; }; }, { "$dropdownContainerCss": "dropdownContainerCssChange"; "$dropdownOptionsContainerCss": "dropdownOptionsContainerCssChange"; "$dropdownValueTemplateContext": "dropdownValueTemplateContextChange"; }, ["$options", "$dropdownPrefix", "$dropdownSuffix"], ["tab-prefix", "tab-suffix"], false, never>;
}

declare class AutoCompleteDirective<T extends Primitive> implements OnDestroy {
    private readonly ref;
    readonly $tabAutoComplete: i0.InputSignal<AutoCompleteComponent<T>>;
    private autoCompleteSelectedSub;
    private readonly autocompleteChanged;
    onFocusIn(): void;
    onFocusOut(): void;
    onInput(): void;
    onClick(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AutoCompleteDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AutoCompleteDirective<any>, "input[tabAutoComplete]", never, { "$tabAutoComplete": { "alias": "tabAutoComplete"; "required": true; "isSignal": true; }; }, {}, never, never, false, never>;
}

declare class TableauUiAutoCompleteModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<TableauUiAutoCompleteModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<TableauUiAutoCompleteModule, [typeof AutoCompleteComponent, typeof AutoCompleteDirective], [typeof i3.TableauUiCommonModule, typeof i4.CommonModule, typeof i5.TableauUiDialogModule], [typeof AutoCompleteComponent, typeof AutoCompleteDirective]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<TableauUiAutoCompleteModule>;
}

export { AutoCompleteComponent, AutoCompleteDirective, TableauUiAutoCompleteModule };
