import * as _angular_core from '@angular/core';
import { Signal } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import * as i3 from 'tableau-ui-angular/common';
import { HintComponent, ErrorComponent } from 'tableau-ui-angular/common';
import * as i2 from '@angular/common';

declare class CheckboxComponent implements ControlValueAccessor {
    /**
     * The disabled state of the checkbox.
     * For forms, disable the form field instead of using this property.
     */
    readonly $disabled: _angular_core.ModelSignal<boolean>;
    /**
     * The value of the checkbox.
     * - `true`: Checkbox is checked
     * - `false`: Checkbox is unchecked
     * - `'partial'`: Checkbox is in a partial state (e.g., indeterminate)
     */
    readonly $value: _angular_core.ModelSignal<boolean | "partial">;
    /**
     * The loading state of the checkbox.
     * This can be used to indicate that the checkbox is in a loading state, e.g., when data is being fetched.
     */
    readonly $loading: _angular_core.InputSignal<boolean>;
    /**
     * The value to set when the checkbox is in a partial state and is clicked.
     */
    readonly $valueAfterPartial: _angular_core.InputSignal<boolean>;
    /**
     * The id of the checkbox form field for autocomplete
     */
    readonly $id: _angular_core.InputSignal<string>;
    /**
     * The name of the checkbox form field for autocomplete
     */
    readonly $name: _angular_core.InputSignal<string>;
    /**
     * The autocomplete attribute of the checkbox form field
     *  * @default 'off'
     */
    readonly $autocomplete: _angular_core.InputSignal<AutoFill>;
    protected readonly $hintElement: Signal<HintComponent | undefined>;
    protected readonly $errorElement: Signal<ErrorComponent | undefined>;
    onChange: (value: boolean) => void;
    onTouched: () => void;
    writeValue(value: boolean): void;
    registerOnChange(fn: (value: boolean) => void): void;
    registerOnTouched(fn: () => void): void;
    setDisabledState(isDisabled: boolean): void;
    toggleValue(): void;
    onKeyDown(e: KeyboardEvent): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<CheckboxComponent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<CheckboxComponent, "tab-checkbox", never, { "$disabled": { "alias": "disabled"; "required": false; "isSignal": true; }; "$value": { "alias": "value"; "required": false; "isSignal": true; }; "$loading": { "alias": "loading"; "required": false; "isSignal": true; }; "$valueAfterPartial": { "alias": "valueAfterPartial"; "required": false; "isSignal": true; }; "$id": { "alias": "id"; "required": false; "isSignal": true; }; "$name": { "alias": "name"; "required": false; "isSignal": true; }; "$autocomplete": { "alias": "autocomplete"; "required": false; "isSignal": true; }; }, { "$disabled": "disabledChange"; "$value": "valueChange"; }, ["$hintElement", "$errorElement"], ["*", "tab-hint", "tab-error"], false, never>;
}

declare class TableauUiCheckboxModule {
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<TableauUiCheckboxModule, never>;
    static ɵmod: _angular_core.ɵɵNgModuleDeclaration<TableauUiCheckboxModule, [typeof CheckboxComponent], [typeof i2.CommonModule, typeof i3.TableauUiCommonModule], [typeof CheckboxComponent]>;
    static ɵinj: _angular_core.ɵɵInjectorDeclaration<TableauUiCheckboxModule>;
}

export { CheckboxComponent, TableauUiCheckboxModule };
