import * as _angular_core from '@angular/core';
import { TemplateRef } from '@angular/core';
import * as i3 from '@angular/common';

declare class DrawerComponent {
    readonly $template: _angular_core.Signal<TemplateRef<unknown>>;
    /**
     * The drawer position.
     * When changed after the drawer is opened, it will only be applied next open.
     * @default 'left'
     */
    readonly $position: _angular_core.InputSignal<"left" | "right">;
    /**
     * The border to show between the drawer and the content.
     * @default 'solid 1px var(--twc-color-border-light)'
     */
    readonly $border: _angular_core.InputSignal<string>;
    /**
     * The gap to apply to between the drawer and the content.
     * This is useful to avoid content being too close to the edges.
     * Any CSS value is accepted, like '10px', '1rem', '2em', etc.
     * @default '0.5rem'
     */
    readonly $padding: _angular_core.InputSignal<string>;
    /**
     * The drawer mode.
     * When changed after the drawer is opened, it will only be applied next open
     */
    /**
     * The drawer width.
     * This can be a CSS value like '300px', '50%', or '30rem'.
     */
    readonly $width: _angular_core.InputSignal<string>;
    /**
     * The drawer status.
     * @default 'false'
     */
    readonly $isOpen: _angular_core.ModelSignal<boolean>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<DrawerComponent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<DrawerComponent, "tab-drawer", never, { "$position": { "alias": "position"; "required": false; "isSignal": true; }; "$border": { "alias": "border"; "required": false; "isSignal": true; }; "$padding": { "alias": "padding"; "required": false; "isSignal": true; }; "$width": { "alias": "width"; "required": true; "isSignal": true; }; "$isOpen": { "alias": "isOpen"; "required": false; "isSignal": true; }; }, { "$isOpen": "isOpenChange"; }, never, ["*"], false, never>;
}

declare class DrawerContainerComponent {
    private readonly $drawers;
    private readonly drawersChanged;
    readonly $leftDrawer: _angular_core.Signal<DrawerComponent>;
    readonly $rightDrawer: _angular_core.Signal<DrawerComponent>;
    readonly $rightDrawerPositionExpression: _angular_core.Signal<string>;
    readonly $leftDrawerPositionExpression: _angular_core.Signal<string>;
    private getBorderWidth;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<DrawerContainerComponent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<DrawerContainerComponent, "tab-drawer-container", never, {}, {}, ["$drawers"], ["*"], false, never>;
}

declare class TableauUiDrawerModule {
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<TableauUiDrawerModule, never>;
    static ɵmod: _angular_core.ɵɵNgModuleDeclaration<TableauUiDrawerModule, [typeof DrawerContainerComponent, typeof DrawerComponent], [typeof i3.CommonModule], [typeof DrawerContainerComponent, typeof DrawerComponent]>;
    static ɵinj: _angular_core.ɵɵInjectorDeclaration<TableauUiDrawerModule>;
}

export { DrawerComponent, DrawerContainerComponent, TableauUiDrawerModule };
