import * as i0 from '@angular/core';
import { input, model, contentChildren, effect, untracked, computed, HostListener, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import * as i1 from 'tableau-ui-angular/common';
import { OptionComponent, TableauUiCommonModule } from 'tableau-ui-angular/common';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3 from 'tableau-ui-angular/tooltip';
import { TableauUiTooltipModule } from 'tableau-ui-angular/tooltip';

class ButtonToggleComponent {
    /**
     * Disables the button toggle component.
     * This will prevent any interaction with the component
     * @default false
     */
    $disabled = input(false, {
        alias: 'disabled',
    });
    /**
     * The value of the button toggle component.
     * This is the value that will be emitted when an option is selected.
     * If no value is selected, it will be undefined.
     * @default undefined
     */
    $selectedValue = model(undefined, {
        alias: 'selectedValue',
    });
    $options = contentChildren((OptionComponent));
    selectedValueChange = effect(() => {
        const val = this.$selectedValue();
        const option = untracked(() => this.$options()).find((opt) => opt.$value() === val);
        if (!option || this.$disabled() || option.$disabled()) {
            this.$selectedValue.set(undefined);
        }
    });
    $optionRenderContext = computed(() => {
        return {
            renderIcon: true,
            renderText: true,
            renderAsDisabled: this.$disabled(),
        };
    });
    optionClicked(option) {
        if (this.$disabled() || option.$disabled()) {
            return;
        }
        this.$selectedValue.set(option.$value());
    }
    onKeyDown(event) {
        if (event.key === 'ArrowLeft') {
            const curIndex = this.$options().findIndex((opt) => opt.$value() === this.$selectedValue());
            if (curIndex === -1) {
                // find the last enabled option
                const lastEnabledOption = this.$options()
                    .slice()
                    .reverse()
                    .find((opt) => !opt.$disabled());
                if (lastEnabledOption) {
                    this.$selectedValue.set(lastEnabledOption.$value());
                }
            }
            else {
                // find the previous enabled option
                const prevEnabledOption = this.$options()
                    .slice(0, curIndex)
                    .reverse()
                    .find((opt) => !opt.$disabled());
                if (prevEnabledOption) {
                    this.$selectedValue.set(prevEnabledOption.$value());
                }
                else {
                    const prevEnabledFromEndOption = this.$options()
                        .slice(curIndex + 1)
                        .reverse()
                        .find((opt) => !opt.$disabled());
                    if (prevEnabledFromEndOption) {
                        this.$selectedValue.set(prevEnabledFromEndOption.$value());
                    }
                }
            }
        }
        else if (event.key === 'ArrowRight') {
            const curIndex = this.$options().findIndex((opt) => opt.$value() === this.$selectedValue());
            if (curIndex === -1) {
                // find the first enabled option
                const firstEnabledOption = this.$options().find((opt) => !opt.$disabled());
                if (firstEnabledOption) {
                    this.$selectedValue.set(firstEnabledOption.$value());
                }
            }
            else {
                // find the next enabled option
                const nextEnabledOption = this.$options()
                    .slice(curIndex + 1)
                    .find((opt) => !opt.$disabled());
                if (nextEnabledOption) {
                    this.$selectedValue.set(nextEnabledOption.$value());
                }
                else {
                    const nextEnabledFromStartOption = this.$options()
                        .slice(0, curIndex)
                        .find((opt) => !opt.$disabled());
                    if (nextEnabledFromStartOption) {
                        this.$selectedValue.set(nextEnabledFromStartOption.$value());
                    }
                }
            }
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ButtonToggleComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: ButtonToggleComponent, isStandalone: false, selector: "tab-button-toggle", inputs: { $disabled: { classPropertyName: "$disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, $selectedValue: { classPropertyName: "$selectedValue", publicName: "selectedValue", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { $selectedValue: "selectedValueChange" }, host: { listeners: { "keydown": "onKeyDown($event)" }, properties: { "class.disabled": "$disabled()", "attr.disabled": "$disabled() ? true : null", "tabindex": "$disabled() ? -1: 0" } }, queries: [{ propertyName: "$options", predicate: (OptionComponent), isSignal: true }], ngImport: i0, template: "@for (option of $options(); track option.$value()) {\n    <!--eslint-disable-next-line @angular-eslint/template/click-events-have-key-events, @angular-eslint/template/interactive-supports-focus-->\n    <div\n        class=\"option\"\n        [class.disabled]=\"$disabled() || option.$disabled()\"\n        [tooltip]=\"option.$hint() ? tooltipTemplate : undefined\"\n        [tooltipContext]=\"{\n            hint: option.$hint() ? option.$hint() : undefined,\n        }\"\n        [class.selected]=\"$selectedValue() === option.$value()\"\n        (click)=\"optionClicked(option)\"\n    >\n        <ng-container [ngTemplateOutlet]=\"option.$template()\" [ngTemplateOutletContext]=\"$optionRenderContext()\" />\n    </div>\n\n    <ng-template #tooltipTemplate let-hint=\"hint\">\n        @if (hint) {\n            <tab-hint class=\"hint\">{{ hint }}</tab-hint>\n        }\n    </ng-template>\n}\n", styles: [":host{display:flex;border:1px solid transparent;border-radius:2px;box-sizing:border-box;pointer-events:all;font-family:inherit;font-size:var(--twc-font-size-body);font-weight:700;height:fit-content;-webkit-user-select:none;user-select:none;width:fit-content;padding:0;align-items:stretch;background-color:transparent;outline:solid 0 var(--twc-color-focused-input)}:host:focus-visible{outline-width:2px;outline-offset:-2px}:host:not([disabled],[disabled=false]){border-color:var(--twc-color-border);color:var(--twc-color-text)}:host[disabled]:not([disabled=false]){background-color:transparent!important;border-color:var(--twc-color-border-light)!important;color:var(--twc-color-disabled)!important}:host .option{padding:.5em;flex:1 1 2rem;display:flex;justify-content:center}:host .option.selected{background-color:var(--twc-color-primary);color:var(--twc-color-on-primary)}:host .option:not(.selected,.disabled):hover{cursor:pointer;background-color:var(--twc-color-mouse-highlight)}:host .option.disabled:hover{cursor:not-allowed}\n"], dependencies: [{ kind: "component", type: i1.HintComponent, selector: "tab-hint", inputs: ["type", "showOnError"] }, { kind: "directive", type: i2.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i3.TooltipDirective, selector: "[tooltip]", inputs: ["tooltip", "tooltipContext", "tooltipPosition", "tooltipMargin", "tooltipPadding", "tooltipArgsMode", "tooltipFullArgs", "tooltipLazyArgs"], outputs: ["tooltipChange", "tooltipContextChange", "tooltipPositionChange", "tooltipMarginChange", "tooltipPaddingChange"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ButtonToggleComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-button-toggle', standalone: false, changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        '[class.disabled]': '$disabled()',
                        '[attr.disabled]': '$disabled() ? true : null',
                        '[tabindex]': '$disabled() ? -1: 0',
                    }, template: "@for (option of $options(); track option.$value()) {\n    <!--eslint-disable-next-line @angular-eslint/template/click-events-have-key-events, @angular-eslint/template/interactive-supports-focus-->\n    <div\n        class=\"option\"\n        [class.disabled]=\"$disabled() || option.$disabled()\"\n        [tooltip]=\"option.$hint() ? tooltipTemplate : undefined\"\n        [tooltipContext]=\"{\n            hint: option.$hint() ? option.$hint() : undefined,\n        }\"\n        [class.selected]=\"$selectedValue() === option.$value()\"\n        (click)=\"optionClicked(option)\"\n    >\n        <ng-container [ngTemplateOutlet]=\"option.$template()\" [ngTemplateOutletContext]=\"$optionRenderContext()\" />\n    </div>\n\n    <ng-template #tooltipTemplate let-hint=\"hint\">\n        @if (hint) {\n            <tab-hint class=\"hint\">{{ hint }}</tab-hint>\n        }\n    </ng-template>\n}\n", styles: [":host{display:flex;border:1px solid transparent;border-radius:2px;box-sizing:border-box;pointer-events:all;font-family:inherit;font-size:var(--twc-font-size-body);font-weight:700;height:fit-content;-webkit-user-select:none;user-select:none;width:fit-content;padding:0;align-items:stretch;background-color:transparent;outline:solid 0 var(--twc-color-focused-input)}:host:focus-visible{outline-width:2px;outline-offset:-2px}:host:not([disabled],[disabled=false]){border-color:var(--twc-color-border);color:var(--twc-color-text)}:host[disabled]:not([disabled=false]){background-color:transparent!important;border-color:var(--twc-color-border-light)!important;color:var(--twc-color-disabled)!important}:host .option{padding:.5em;flex:1 1 2rem;display:flex;justify-content:center}:host .option.selected{background-color:var(--twc-color-primary);color:var(--twc-color-on-primary)}:host .option:not(.selected,.disabled):hover{cursor:pointer;background-color:var(--twc-color-mouse-highlight)}:host .option.disabled:hover{cursor:not-allowed}\n"] }]
        }], propDecorators: { onKeyDown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }] } });

class TableauUiButtonToggleModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiButtonToggleModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiButtonToggleModule, declarations: [ButtonToggleComponent], imports: [TableauUiCommonModule, CommonModule, TableauUiTooltipModule], exports: [ButtonToggleComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiButtonToggleModule, imports: [TableauUiCommonModule, CommonModule, TableauUiTooltipModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiButtonToggleModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [TableauUiCommonModule, CommonModule, TableauUiTooltipModule],
                    declarations: [ButtonToggleComponent],
                    exports: [ButtonToggleComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ButtonToggleComponent, TableauUiButtonToggleModule };
//# sourceMappingURL=tableau-ui-angular-button-toggle.mjs.map
