import * as i0 from '@angular/core';
import { inject, ElementRef, input, HostListener, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

class ButtonComponent {
    $nativeElement = inject(ElementRef);
    $disabled = input(false, {
        alias: 'disabled',
    });
    $loading = input(false, {
        alias: 'loading',
    });
    $tabindex = input('0', {
        alias: 'tabindex',
    });
    $type = input('button', {
        alias: 'type',
    });
    $kind = input('stroked', {
        alias: 'kind',
    });
    $color = input('secondary', {
        alias: 'color',
    });
    $layout = input('default', {
        alias: 'layout',
    });
    $inline = input(false, {
        alias: 'inline',
    });
    $noFocusOnClick = input(true, {
        alias: 'noFocusOnClick',
    });
    clickFromKeyboard = false;
    handleKeydown(event) {
        const el = this.$nativeElement.nativeElement;
        this.clickFromKeyboard = true; // set flag to indicate click from keyboard
        if ((el instanceof HTMLLinkElement && event.code === 'Enter') || event.code === 'Space') {
            event.preventDefault(); // stop scroll or native behavior
            el.click(); // trigger click manually
        }
    }
    handleMouseDown() {
        this.clickFromKeyboard = false; // reset flag on mouse down
    }
    handlePointerDown() {
        this.clickFromKeyboard = false; // reset flag on pointer down
    }
    handleTouchStart() {
        this.clickFromKeyboard = false; // reset flag on touch start
    }
    mouseClickHandler() {
        if (this.clickFromKeyboard) {
            this.clickFromKeyboard = false; // reset flag after click
            return;
        }
        if (this.$noFocusOnClick()) {
            // Prevent focus on click if $noFocusOnClick is true
            setTimeout(() => {
                this.$nativeElement.nativeElement.blur();
            });
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: ButtonComponent, isStandalone: false, selector: "button:not([tab-menu-button]),a[button]:not([tab-menu-button])", inputs: { $disabled: { classPropertyName: "$disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, $loading: { classPropertyName: "$loading", publicName: "loading", isSignal: true, isRequired: false, transformFunction: null }, $tabindex: { classPropertyName: "$tabindex", publicName: "tabindex", isSignal: true, isRequired: false, transformFunction: null }, $type: { classPropertyName: "$type", publicName: "type", isSignal: true, isRequired: false, transformFunction: null }, $kind: { classPropertyName: "$kind", publicName: "kind", isSignal: true, isRequired: false, transformFunction: null }, $color: { classPropertyName: "$color", publicName: "color", isSignal: true, isRequired: false, transformFunction: null }, $layout: { classPropertyName: "$layout", publicName: "layout", isSignal: true, isRequired: false, transformFunction: null }, $inline: { classPropertyName: "$inline", publicName: "inline", isSignal: true, isRequired: false, transformFunction: null }, $noFocusOnClick: { classPropertyName: "$noFocusOnClick", publicName: "noFocusOnClick", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "role": "button" }, listeners: { "click": "mouseClickHandler()", "keydown": "handleKeydown($event)", "mousedown": "handleMouseDown()", "pointerdown": "handlePointerDown()", "touchstart": "handleTouchStart()" }, properties: { "attr.type": "$type()", "class": "`${$color()} ${$kind()}`", "attr.disabled": "$disabled() || $loading() ? true : null", "class.loading": "$loading()", "attr.tabindex": "$disabled() ? \"-1\": $tabindex()", "attr.layout": "$layout()", "attr.inline": "$inline()" } }, ngImport: i0, template: "<span class=\"content-wrapper\">\n    @if ($layout() === 'default' || $loading()) {\n        <span class=\"loader-wrapper\">\n            <img\n                alt=\"Wait indicator\"\n                class=\"f79w7hb\"\n                src=\"data:image/svg+xml,%0A%3Csvg%20viewBox%3D%220%200%2050%2050%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%0A%20%20%3Cstyle%3E%0A%20%20%20%20%23tail%20%7B%20fill%3A%20url(%23fade)%20%7D%0A%20%20%20%20%23head%20%7B%20fill%3A%20rgb(97%2C%20101%2C%20112)%20%7D%0A%20%20%20%20stop%20%7B%20stop-color%3A%20rgb(97%2C%20101%2C%20112)%20%7D%0A%20%20%3C%2Fstyle%3E%0A%20%20%3ClinearGradient%20id%3D%22fade%22%20x2%3D%2250%22%20y1%3D%2225%22%20y2%3D%2225%22%20gradientUnits%3D%22userSpaceOnUse%22%3E%0A%20%20%20%20%3Cstop%20offset%3D%220%22%20stop-opacity%3D%220%22%2F%3E%0A%20%20%20%20%3Cstop%20offset%3D%22.15%22%20stop-opacity%3D%22.04%22%2F%3E%0A%20%20%20%20%3Cstop%20offset%3D%22.3%22%20stop-opacity%3D%22.16%22%2F%3E%0A%20%20%20%20%3Cstop%20offset%3D%22.45%22%20stop-opacity%3D%22.36%22%2F%3E%0A%20%20%20%20%3Cstop%20offset%3D%22.61%22%20stop-opacity%3D%22.64%22%2F%3E%0A%20%20%20%20%3Cstop%20offset%3D%22.76%22%2F%3E%0A%20%20%3C%2FlinearGradient%3E%0A%20%20%3Cpath%20id%3D%22head%22%20d%3D%22M0%2025a25%2025%200%201%200%2050%200h-3.9a21.1%2021.1%200%201%201-42.2%200%22%20%2F%3E%0A%20%20%3Cpath%20id%3D%22tail%22%20d%3D%22M50%2025a25%2025%200%200%200-50%200h3.9a21.1%2021.1%200%201%201%2042.2%200%22%20%2F%3E%0A%3C%2Fsvg%3E\"\n            />\n        </span>\n    }\n    @if ($layout() === 'default' || !$loading()) {\n        <ng-content />\n    }\n</span>\n", styles: [":host{border:1px solid transparent;border-radius:2px;box-sizing:border-box;pointer-events:all;cursor:pointer;font-family:inherit;font-size:var(--twc-font-size-body);font-weight:700;height:fit-content;-webkit-user-select:none;user-select:none;width:fit-content;min-height:1rem;min-width:1rem;padding:0;align-items:center;justify-content:center;text-decoration:none}:host[inline=true]{display:inline-flex}:host[inline=false]{display:flex}:host:hover{text-decoration:none}:host .content-wrapper{display:flex;justify-content:center;align-items:center;pointer-events:none;white-space:nowrap}:host .content-wrapper .loader-wrapper{visibility:hidden;display:flex}@keyframes loading-button-spinner{to{transform:rotate(360deg)}}:host .content-wrapper .loader-wrapper img{animation:loading-button-spinner 1s linear infinite;cursor:wait;margin:auto;overflow:hidden;height:1.1rem;width:1.1rem}:host[layout=default]{min-height:2em;line-height:1.5;min-width:8rem;padding:0 2rem}:host[layout=default] .loader-wrapper{margin-left:-1.5rem;margin-right:.3rem}:host[layout=icon]{min-height:1.5rem;min-width:1.5rem}:host[layout=small-icon]{min-height:1rem;min-width:1rem}:host.loading .loader-wrapper{visibility:visible!important}:host.stroked{background-color:var(--twc-color-base)}:host.stroked.primary:not([disabled],[disabled=false]){color:var(--twc-color-primary);border-color:var(--twc-color-primary)}:host.stroked.primary:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.stroked.primary[disabled]:not([disabled=false]){color:var(--twc-color-disabled);border-color:var(--twc-color-disabled)}:host.stroked.secondary:not([disabled],[disabled=false]){border-color:var(--twc-color-border);color:var(--twc-color-text)}:host.stroked.secondary:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.stroked.secondary[disabled]:not([disabled=false]){background-color:transparent!important;border-color:var(--twc-color-border-light)!important;color:var(--twc-color-disabled)!important}:host.stroked.error:not([disabled],[disabled=false]){color:var(--twc-color-error);border-color:var(--twc-color-error)}:host.stroked.error:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.stroked.error[disabled]:not([disabled=false]){color:var(--twc-color-disabled);border-color:var(--twc-color-disabled)}:host.stroked.plain:not([disabled],[disabled=false]){color:var(--twc-color-text)}:host.stroked.plain:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.stroked.plain[disabled]:not([disabled=false]){color:var(--twc-color-disabled)!important}:host.raised.primary:not([disabled],[disabled=false]){background-color:var(--twc-color-primary);color:var(--twc-color-on-primary)}:host.raised.primary:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-primary-dark)}:host.raised.primary[disabled]:not([disabled=false]){background-color:var(--twc-color-border-dark-disabled)!important;color:var(--twc-color-text-light)!important}:host.raised.secondary:not([disabled],[disabled=false]){background-color:var(--twc-color-highlight);border-color:var(--twc-color-border-dark);color:var(--twc-color-text)}:host.raised.secondary:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.raised.secondary[disabled]:not([disabled=false]){background-color:transparent!important;border-color:var(--twc-color-border-light)!important;color:var(--twc-color-disabled)!important}:host.raised.error:not([disabled],[disabled=false]){background-color:var(--twc-color-error);color:var(--twc-color-on-primary)}:host.raised.error:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-error-dark)}:host.raised.error[disabled]:not([disabled=false]){background-color:var(--twc-color-border-dark-disabled)!important;color:var(--twc-color-text-light)!important}:host.raised.plain:not([disabled],[disabled=false]){background-color:var(--twc-color-highlight);color:var(--twc-color-text)}:host.raised.plain:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.raised.plain[disabled]:not([disabled=false]){background-color:transparent!important;color:var(--twc-color-disabled)!important}:host[disabled]:not([disabled=false]){cursor:default;pointer-events:none}:host:focus-visible,:host:focus{box-shadow:inset 0 0 0 2px var(--twc-color-base);outline:2px solid var(--twc-color-focused-input);outline-offset:-2px}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button:not([tab-menu-button]),a[button]:not([tab-menu-button])', standalone: false, changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        '[attr.type]': '$type()',
                        '[class]': '`${$color()} ${$kind()}`',
                        '[attr.disabled]': '$disabled() || $loading() ? true : null',
                        '[class.loading]': '$loading()',
                        '[attr.tabindex]': '$disabled() ? "-1": $tabindex()',
                        role: 'button',
                        '[attr.layout]': '$layout()',
                        '[attr.inline]': '$inline()',
                        '(click)': 'mouseClickHandler()',
                    }, template: "<span class=\"content-wrapper\">\n    @if ($layout() === 'default' || $loading()) {\n        <span class=\"loader-wrapper\">\n            <img\n                alt=\"Wait indicator\"\n                class=\"f79w7hb\"\n                src=\"data:image/svg+xml,%0A%3Csvg%20viewBox%3D%220%200%2050%2050%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%0A%20%20%3Cstyle%3E%0A%20%20%20%20%23tail%20%7B%20fill%3A%20url(%23fade)%20%7D%0A%20%20%20%20%23head%20%7B%20fill%3A%20rgb(97%2C%20101%2C%20112)%20%7D%0A%20%20%20%20stop%20%7B%20stop-color%3A%20rgb(97%2C%20101%2C%20112)%20%7D%0A%20%20%3C%2Fstyle%3E%0A%20%20%3ClinearGradient%20id%3D%22fade%22%20x2%3D%2250%22%20y1%3D%2225%22%20y2%3D%2225%22%20gradientUnits%3D%22userSpaceOnUse%22%3E%0A%20%20%20%20%3Cstop%20offset%3D%220%22%20stop-opacity%3D%220%22%2F%3E%0A%20%20%20%20%3Cstop%20offset%3D%22.15%22%20stop-opacity%3D%22.04%22%2F%3E%0A%20%20%20%20%3Cstop%20offset%3D%22.3%22%20stop-opacity%3D%22.16%22%2F%3E%0A%20%20%20%20%3Cstop%20offset%3D%22.45%22%20stop-opacity%3D%22.36%22%2F%3E%0A%20%20%20%20%3Cstop%20offset%3D%22.61%22%20stop-opacity%3D%22.64%22%2F%3E%0A%20%20%20%20%3Cstop%20offset%3D%22.76%22%2F%3E%0A%20%20%3C%2FlinearGradient%3E%0A%20%20%3Cpath%20id%3D%22head%22%20d%3D%22M0%2025a25%2025%200%201%200%2050%200h-3.9a21.1%2021.1%200%201%201-42.2%200%22%20%2F%3E%0A%20%20%3Cpath%20id%3D%22tail%22%20d%3D%22M50%2025a25%2025%200%200%200-50%200h3.9a21.1%2021.1%200%201%201%2042.2%200%22%20%2F%3E%0A%3C%2Fsvg%3E\"\n            />\n        </span>\n    }\n    @if ($layout() === 'default' || !$loading()) {\n        <ng-content />\n    }\n</span>\n", styles: [":host{border:1px solid transparent;border-radius:2px;box-sizing:border-box;pointer-events:all;cursor:pointer;font-family:inherit;font-size:var(--twc-font-size-body);font-weight:700;height:fit-content;-webkit-user-select:none;user-select:none;width:fit-content;min-height:1rem;min-width:1rem;padding:0;align-items:center;justify-content:center;text-decoration:none}:host[inline=true]{display:inline-flex}:host[inline=false]{display:flex}:host:hover{text-decoration:none}:host .content-wrapper{display:flex;justify-content:center;align-items:center;pointer-events:none;white-space:nowrap}:host .content-wrapper .loader-wrapper{visibility:hidden;display:flex}@keyframes loading-button-spinner{to{transform:rotate(360deg)}}:host .content-wrapper .loader-wrapper img{animation:loading-button-spinner 1s linear infinite;cursor:wait;margin:auto;overflow:hidden;height:1.1rem;width:1.1rem}:host[layout=default]{min-height:2em;line-height:1.5;min-width:8rem;padding:0 2rem}:host[layout=default] .loader-wrapper{margin-left:-1.5rem;margin-right:.3rem}:host[layout=icon]{min-height:1.5rem;min-width:1.5rem}:host[layout=small-icon]{min-height:1rem;min-width:1rem}:host.loading .loader-wrapper{visibility:visible!important}:host.stroked{background-color:var(--twc-color-base)}:host.stroked.primary:not([disabled],[disabled=false]){color:var(--twc-color-primary);border-color:var(--twc-color-primary)}:host.stroked.primary:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.stroked.primary[disabled]:not([disabled=false]){color:var(--twc-color-disabled);border-color:var(--twc-color-disabled)}:host.stroked.secondary:not([disabled],[disabled=false]){border-color:var(--twc-color-border);color:var(--twc-color-text)}:host.stroked.secondary:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.stroked.secondary[disabled]:not([disabled=false]){background-color:transparent!important;border-color:var(--twc-color-border-light)!important;color:var(--twc-color-disabled)!important}:host.stroked.error:not([disabled],[disabled=false]){color:var(--twc-color-error);border-color:var(--twc-color-error)}:host.stroked.error:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.stroked.error[disabled]:not([disabled=false]){color:var(--twc-color-disabled);border-color:var(--twc-color-disabled)}:host.stroked.plain:not([disabled],[disabled=false]){color:var(--twc-color-text)}:host.stroked.plain:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.stroked.plain[disabled]:not([disabled=false]){color:var(--twc-color-disabled)!important}:host.raised.primary:not([disabled],[disabled=false]){background-color:var(--twc-color-primary);color:var(--twc-color-on-primary)}:host.raised.primary:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-primary-dark)}:host.raised.primary[disabled]:not([disabled=false]){background-color:var(--twc-color-border-dark-disabled)!important;color:var(--twc-color-text-light)!important}:host.raised.secondary:not([disabled],[disabled=false]){background-color:var(--twc-color-highlight);border-color:var(--twc-color-border-dark);color:var(--twc-color-text)}:host.raised.secondary:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.raised.secondary[disabled]:not([disabled=false]){background-color:transparent!important;border-color:var(--twc-color-border-light)!important;color:var(--twc-color-disabled)!important}:host.raised.error:not([disabled],[disabled=false]){background-color:var(--twc-color-error);color:var(--twc-color-on-primary)}:host.raised.error:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-error-dark)}:host.raised.error[disabled]:not([disabled=false]){background-color:var(--twc-color-border-dark-disabled)!important;color:var(--twc-color-text-light)!important}:host.raised.plain:not([disabled],[disabled=false]){background-color:var(--twc-color-highlight);color:var(--twc-color-text)}:host.raised.plain:not([disabled],[disabled=false]):hover{background-color:var(--twc-color-mouse-highlight)}:host.raised.plain[disabled]:not([disabled=false]){background-color:transparent!important;color:var(--twc-color-disabled)!important}:host[disabled]:not([disabled=false]){cursor:default;pointer-events:none}:host:focus-visible,:host:focus{box-shadow:inset 0 0 0 2px var(--twc-color-base);outline:2px solid var(--twc-color-focused-input);outline-offset:-2px}\n"] }]
        }], propDecorators: { handleKeydown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }], handleMouseDown: [{
                type: HostListener,
                args: ['mousedown']
            }], handlePointerDown: [{
                type: HostListener,
                args: ['pointerdown']
            }], handleTouchStart: [{
                type: HostListener,
                args: ['touchstart']
            }] } });

class TableauUiButtonModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiButtonModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiButtonModule, declarations: [ButtonComponent], imports: [CommonModule], exports: [ButtonComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiButtonModule, imports: [CommonModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiButtonModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [ButtonComponent],
                    exports: [ButtonComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ButtonComponent, TableauUiButtonModule };
//# sourceMappingURL=tableau-ui-angular-button.mjs.map
