import * as i0 from '@angular/core';
import { model, input, contentChild, forwardRef, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import * as i1 from 'tableau-ui-angular/common';
import { HintComponent, ErrorComponent, TableauUiCommonModule } from 'tableau-ui-angular/common';
import { generateRandomString } from 'tableau-ui-angular/utils';
import { CommonModule } from '@angular/common';

class CheckboxComponent {
    /**
     * The disabled state of the checkbox.
     * For forms, disable the form field instead of using this property.
     */
    $disabled = model(false, {
        alias: 'disabled',
    });
    /**
     * The value of the checkbox.
     * - `true`: Checkbox is checked
     * - `false`: Checkbox is unchecked
     * - `'partial'`: Checkbox is in a partial state (e.g., indeterminate)
     */
    $value = model(false, {
        alias: 'value',
    });
    /**
     * The loading state of the checkbox.
     * This can be used to indicate that the checkbox is in a loading state, e.g., when data is being fetched.
     */
    $loading = input(false, {
        alias: 'loading',
    });
    /**
     * The value to set when the checkbox is in a partial state and is clicked.
     */
    $valueAfterPartial = input(false, {
        alias: 'valueAfterPartial',
    });
    /**
     * The id of the checkbox form field for autocomplete
     */
    $id = input(generateRandomString(), {
        alias: 'id',
    });
    /**
     * The name of the checkbox form field for autocomplete
     */
    $name = input('', {
        alias: 'name',
    });
    /**
     * The autocomplete attribute of the checkbox form field
     *  * @default 'off'
     */
    $autocomplete = input('off', {
        alias: 'autocomplete',
    });
    // nullable Signal type needs to be set explicitly -> ng-packagr strips nullability
    $hintElement = contentChild(HintComponent);
    // nullable Signal type needs to be set explicitly -> ng-packagr strips nullability
    $errorElement = contentChild(ErrorComponent);
    // eslint-disable-next-line @typescript-eslint/no-empty-function, @typescript-eslint/no-unused-vars
    onChange = (value) => { };
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    onTouched = () => { };
    writeValue(value) {
        this.$value.set(value);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.$disabled.set(isDisabled);
    }
    toggleValue() {
        if (!this.$disabled() && !this.$loading()) {
            let val = this.$value();
            if (val === 'partial') {
                val = this.$valueAfterPartial();
            }
            else {
                val = !val;
            }
            this.$value.set(val);
            this.onChange(val);
            this.onTouched();
        }
    }
    onKeyDown(e) {
        switch (e.key) {
            case 'Enter':
            case ' ':
                this.toggleValue();
                e.preventDefault();
                break;
            default:
                return;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CheckboxComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: CheckboxComponent, isStandalone: false, selector: "tab-checkbox", inputs: { $disabled: { classPropertyName: "$disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, $value: { classPropertyName: "$value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, $loading: { classPropertyName: "$loading", publicName: "loading", isSignal: true, isRequired: false, transformFunction: null }, $valueAfterPartial: { classPropertyName: "$valueAfterPartial", publicName: "valueAfterPartial", isSignal: true, isRequired: false, transformFunction: null }, $id: { classPropertyName: "$id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null }, $name: { classPropertyName: "$name", publicName: "name", isSignal: true, isRequired: false, transformFunction: null }, $autocomplete: { classPropertyName: "$autocomplete", publicName: "autocomplete", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { $disabled: "disabledChange", $value: "valueChange" }, host: { listeners: { "click": "toggleValue()" }, properties: { "class.disabled": "$disabled()", "class.checked": "$value() === true", "class.partial": "$value() === \"partial\"", "class.loading": "$loading()" }, classAttribute: "checkbox" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => CheckboxComponent),
                multi: true,
            },
        ], queries: [{ propertyName: "$hintElement", first: true, predicate: HintComponent, descendants: true, isSignal: true }, { propertyName: "$errorElement", first: true, predicate: ErrorComponent, descendants: true, isSignal: true }], ngImport: i0, template: "<input\n    type=\"checkbox\"\n    [attr.id]=\"$id()\"\n    [attr.name]=\"$name() ?? ''\"\n    [autocomplete]=\"$autocomplete()\"\n    [value]=\"$value()\"\n    [checked]=\"$value()\"\n    [tabindex]=\"$disabled() ? -1 : 0\"\n    (change)=\"toggleValue()\"\n    (keydown)=\"onKeyDown($event)\"\n/>\n\n@if ($loading()) {\n    <tab-loading-gif width=\"1.2rem\" height=\"1.2rem\" />\n} @else {\n    <div class=\"box\">\n        <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 12 12\"><path fill=\"currentColor\" transform=\"translate(-2, -2)\" d=\"M7.2 12.3c-.2 0-.4-.1-.5-.2l-3-3L4.8 8l2.3 2.3 4-6.7 1.3.8L7.9 12c-.2.2-.4.3-.7.3z\" /></svg>\n        <div class=\"partial\"></div>\n    </div>\n}\n\n<div class=\"label\">\n    <ng-content />\n</div>\n\n@if ($hintElement() || $errorElement()) {\n    <div class=\"extra-info\">\n        @if ($hintElement() && !$errorElement()) {\n            <ng-content select=\"tab-hint\" />\n        }\n        @if ($errorElement()) {\n            <ng-content select=\"tab-error\" />\n        }\n    </div>\n}\n", styles: [":host{box-sizing:border-box;width:fit-content;-webkit-user-select:none;user-select:none;display:grid;grid-template-columns:auto auto;grid-template-rows:auto auto;column-gap:.5em}:host tab-loading-gif,:host .box{width:1.2em;height:1.2em;grid-column:1;grid-row:1}:host .box{background-color:var(--twc-color-base);border:1px solid var(--twc-color-border-dark);border-radius:1px;box-sizing:border-box;display:grid;justify-items:center}:host .box svg{display:none;width:1em;height:1em}:host .box .partial{display:none;height:.2rem;width:60%;align-self:center;background-color:var(--twc-color-text)}:host.checked .box svg{display:block}:host.partial .box .partial{display:block}:host input{grid-column:1;grid-row:1;box-sizing:border-box;margin:0;opacity:0;padding:0;pointer-events:none;width:1.2em;height:1.2em;font-size:var(--twc-font-size-body);min-height:0}:host input:focus-visible+.box{outline:2px solid var(--twc-color-primary);outline-offset:2px}@supports (width: round(1em,1px)){:host input{width:round(1.2em,1px);height:round(1.2em,1px)}}:host:hover:not(.disabled) .box{background-color:var(--twc-color-mouse-highlight);border-color:var(--twc-color-border-dark)}:host:active:not(.disabled) .box{background-color:var(--twc-color-disabled);border-color:var(--twc-color-border-dark)}:host:not(.disabled){cursor:pointer}:host.disabled{color:var(--twc-color-disabled)}:host.disabled .box{border-color:var(--twc-color-disabled)}:host.disabled ::ng-deep .tab-hint{color:var(--twc-color-disabled)}:host .label{line-height:1.2;overflow:hidden;text-overflow:ellipsis;-webkit-user-select:none;user-select:none;grid-column:2;grid-row:1}:host .extra-info{grid-column:2;grid-row:2;font-size:.9em}\n"], dependencies: [{ kind: "component", type: i1.LoadingGifComponent, selector: "tab-loading-gif", inputs: ["color", "width", "height"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CheckboxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-checkbox', standalone: false, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => CheckboxComponent),
                            multi: true,
                        },
                    ], changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        class: 'checkbox',
                        '[class.disabled]': '$disabled()',
                        '[class.checked]': '$value() === true',
                        '[class.partial]': '$value() === "partial"',
                        '[class.loading]': '$loading()',
                        '(click)': 'toggleValue()',
                    }, template: "<input\n    type=\"checkbox\"\n    [attr.id]=\"$id()\"\n    [attr.name]=\"$name() ?? ''\"\n    [autocomplete]=\"$autocomplete()\"\n    [value]=\"$value()\"\n    [checked]=\"$value()\"\n    [tabindex]=\"$disabled() ? -1 : 0\"\n    (change)=\"toggleValue()\"\n    (keydown)=\"onKeyDown($event)\"\n/>\n\n@if ($loading()) {\n    <tab-loading-gif width=\"1.2rem\" height=\"1.2rem\" />\n} @else {\n    <div class=\"box\">\n        <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 12 12\"><path fill=\"currentColor\" transform=\"translate(-2, -2)\" d=\"M7.2 12.3c-.2 0-.4-.1-.5-.2l-3-3L4.8 8l2.3 2.3 4-6.7 1.3.8L7.9 12c-.2.2-.4.3-.7.3z\" /></svg>\n        <div class=\"partial\"></div>\n    </div>\n}\n\n<div class=\"label\">\n    <ng-content />\n</div>\n\n@if ($hintElement() || $errorElement()) {\n    <div class=\"extra-info\">\n        @if ($hintElement() && !$errorElement()) {\n            <ng-content select=\"tab-hint\" />\n        }\n        @if ($errorElement()) {\n            <ng-content select=\"tab-error\" />\n        }\n    </div>\n}\n", styles: [":host{box-sizing:border-box;width:fit-content;-webkit-user-select:none;user-select:none;display:grid;grid-template-columns:auto auto;grid-template-rows:auto auto;column-gap:.5em}:host tab-loading-gif,:host .box{width:1.2em;height:1.2em;grid-column:1;grid-row:1}:host .box{background-color:var(--twc-color-base);border:1px solid var(--twc-color-border-dark);border-radius:1px;box-sizing:border-box;display:grid;justify-items:center}:host .box svg{display:none;width:1em;height:1em}:host .box .partial{display:none;height:.2rem;width:60%;align-self:center;background-color:var(--twc-color-text)}:host.checked .box svg{display:block}:host.partial .box .partial{display:block}:host input{grid-column:1;grid-row:1;box-sizing:border-box;margin:0;opacity:0;padding:0;pointer-events:none;width:1.2em;height:1.2em;font-size:var(--twc-font-size-body);min-height:0}:host input:focus-visible+.box{outline:2px solid var(--twc-color-primary);outline-offset:2px}@supports (width: round(1em,1px)){:host input{width:round(1.2em,1px);height:round(1.2em,1px)}}:host:hover:not(.disabled) .box{background-color:var(--twc-color-mouse-highlight);border-color:var(--twc-color-border-dark)}:host:active:not(.disabled) .box{background-color:var(--twc-color-disabled);border-color:var(--twc-color-border-dark)}:host:not(.disabled){cursor:pointer}:host.disabled{color:var(--twc-color-disabled)}:host.disabled .box{border-color:var(--twc-color-disabled)}:host.disabled ::ng-deep .tab-hint{color:var(--twc-color-disabled)}:host .label{line-height:1.2;overflow:hidden;text-overflow:ellipsis;-webkit-user-select:none;user-select:none;grid-column:2;grid-row:1}:host .extra-info{grid-column:2;grid-row:2;font-size:.9em}\n"] }]
        }] });

class TableauUiCheckboxModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiCheckboxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiCheckboxModule, declarations: [CheckboxComponent], imports: [CommonModule, TableauUiCommonModule], exports: [CheckboxComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiCheckboxModule, imports: [CommonModule, TableauUiCommonModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiCheckboxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, TableauUiCommonModule],
                    declarations: [CheckboxComponent],
                    exports: [CheckboxComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { CheckboxComponent, TableauUiCheckboxModule };
//# sourceMappingURL=tableau-ui-angular-checkbox.mjs.map
