import * as i0 from '@angular/core';
import { inject, Injectable, NgModule } from '@angular/core';
import { SnackService, TableauUiSnackModule } from 'tableau-ui-angular/snack';

class ClipboardService {
    snackService = inject(SnackService);
    async writeText(text, handlePermissionError = true) {
        // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
        if (!navigator.clipboard) {
            throw this.getError(handlePermissionError, 'Clipboard is not available in this browser');
        }
        const perm = await navigator.permissions.query({
            name: 'clipboard-write',
        });
        if (perm.state === 'denied') {
            throw this.getError(handlePermissionError, 'Permission to write to clipboard is denied for this site');
        }
        try {
            await navigator.clipboard.writeText(text);
        }
        catch (e) {
            throw this.getError(handlePermissionError, 'Error writing to clipboard', e);
        }
    }
    async readText(handlePermissionError = true) {
        // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
        if (!navigator.clipboard) {
            throw this.getError(handlePermissionError, 'Clipboard is not available in this browser');
        }
        const perm = await navigator.permissions.query({
            name: 'clipboard-read',
        });
        if (perm.state === 'denied') {
            throw this.getError(handlePermissionError, 'Permission to write to clipboard is denied for this site');
        }
        try {
            return await navigator.clipboard.readText();
        }
        catch (e) {
            throw this.getError(handlePermissionError, 'Error reading from clipboard', e);
        }
    }
    getError(handleError, message, details) {
        console.error(message, details);
        if (handleError) {
            this.snackService.openSnack(message, 5000, 'error');
        }
        return new Error(message);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ClipboardService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ClipboardService, providedIn: 'any' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ClipboardService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'any',
                }]
        }] });

class TableauUiClipboardModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiClipboardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiClipboardModule, imports: [TableauUiSnackModule] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiClipboardModule, providers: [ClipboardService], imports: [TableauUiSnackModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiClipboardModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [TableauUiSnackModule],
                    declarations: [],
                    providers: [ClipboardService],
                    exports: [],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ClipboardService, TableauUiClipboardModule };
//# sourceMappingURL=tableau-ui-angular-clipboard.mjs.map
