import * as i0 from '@angular/core';
import { inject, ElementRef, input, effect, model, output, forwardRef, HostListener, Directive, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { ThemeService } from 'tableau-ui-angular/theme';
import { CommonModule } from '@angular/common';

class DatePickerDirective {
    el = inject(ElementRef);
    themeService = inject(ThemeService);
    // type can only be set once. Cannot change between date and datetime
    $type = input.required({
        alias: 'type',
    });
    originalType;
    typeChanged = effect(() => {
        this.originalType ??= this.$type();
        if (this.$type() !== this.originalType) {
            throw new Error('DatePickerDirective: type must be "date" or "datetime", can not be changed later');
        }
    });
    // nullable Signal type needs to be set explicitly -> ng-packagr strips nullability
    $value = model(undefined, {
        alias: 'value',
    });
    valueChange = output();
    onInput() {
        let val = undefined;
        if (!this.el.nativeElement.value) {
            val = undefined;
        }
        else {
            const date = new Date(this.el.nativeElement.value);
            if (isNaN(date.getTime())) {
                val = undefined;
            }
            else {
                val = date;
            }
        }
        this.$value.set(val);
        this.valueChange.emit(val);
        this._onTouched();
        this._onChange(val);
    }
    onFocus() {
        this._onTouched();
    }
    writeValue(obj) {
        if (obj instanceof Date && !isNaN(obj.getTime())) {
            if (this.$type() === 'datetime') {
                const year = obj.getFullYear();
                const month = (obj.getMonth() + 1).toString().padStart(2, '0');
                const day = obj.getDate().toString().padStart(2, '0');
                const hours = obj.getHours().toString().padStart(2, '0');
                const minutes = obj.getMinutes().toString().padStart(2, '0');
                this.el.nativeElement.value = `${year}-${month}-${day}T${hours}:${minutes}`;
            }
            else {
                const year = obj.getFullYear();
                const month = (obj.getMonth() + 1).toString().padStart(2, '0');
                const day = obj.getDate().toString().padStart(2, '0');
                this.el.nativeElement.value = `${year}-${month}-${day}`;
            }
        }
        else {
            this.el.nativeElement.value = '';
        }
    }
    // eslint-disable-next-line @typescript-eslint/no-empty-function, @typescript-eslint/no-unused-vars
    _onChange = (value) => { };
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    _onTouched = () => { };
    registerOnChange(fn) {
        this._onChange = fn;
    }
    registerOnTouched(fn) {
        this._onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.el.nativeElement.disabled = isDisabled;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: DatePickerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.3", type: DatePickerDirective, isStandalone: false, selector: "input[type=date],input[type=datetime-local],input[type=datetime],input[date-picker]", inputs: { $type: { classPropertyName: "$type", publicName: "type", isSignal: true, isRequired: true, transformFunction: null }, $value: { classPropertyName: "$value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { $value: "valueChange", valueChange: "valueChange" }, host: { listeners: { "input": "onInput()", "focus": "onFocus()" }, properties: { "attr.type": "$type() === \"datetime\" ? \"datetime-local\" : \"date\"" }, classAttribute: "date-picker" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => DatePickerDirective),
                multi: true,
            },
        ], ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: DatePickerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'input[type=date],input[type=datetime-local],input[type=datetime],input[date-picker]',
                    standalone: false,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => DatePickerDirective),
                            multi: true,
                        },
                    ],
                    host: {
                        class: 'date-picker',
                        '[attr.type]': '$type() === "datetime" ? "datetime-local" : "date"',
                    },
                }]
        }], propDecorators: { onInput: [{
                type: HostListener,
                args: ['input']
            }], onFocus: [{
                type: HostListener,
                args: ['focus']
            }] } });

class DateValidators {
    static minDate(minDate) {
        return (ctrl) => {
            if (ctrl.value !== undefined && ctrl.value !== null && ctrl.value instanceof Date && !isNaN(ctrl.value.getTime())) {
                const date = ctrl.value;
                if (date < minDate) {
                    return { minDate: true };
                }
            }
            return null;
        };
    }
    static maxDate(maxDate) {
        return (ctrl) => {
            if (ctrl.value !== undefined && ctrl.value !== null && ctrl.value instanceof Date && !isNaN(ctrl.value.getTime())) {
                const date = ctrl.value;
                if (date > maxDate) {
                    return { maxDate: true };
                }
            }
            return null;
        };
    }
}

class TableauUiDatePickerModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDatePickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDatePickerModule, declarations: [DatePickerDirective], imports: [CommonModule], exports: [DatePickerDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDatePickerModule, imports: [CommonModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDatePickerModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [DatePickerDirective],
                    exports: [DatePickerDirective],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DatePickerDirective, DateValidators, TableauUiDatePickerModule };
//# sourceMappingURL=tableau-ui-angular-date-picker.mjs.map
