import * as i0 from '@angular/core';
import { InjectionToken, inject, viewChild, ChangeDetectionStrategy, Component, Injector, ApplicationRef, EnvironmentInjector, createComponent, Injectable, NgModule } from '@angular/core';
import { Subject, fromEvent, map, Subscription } from 'rxjs';
import { tabbable } from 'tabbable';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from 'tableau-ui-angular/button';
import { TableauUiButtonModule } from 'tableau-ui-angular/button';
import { IconComponent } from 'tableau-ui-angular/icon';

const TAB_DIALOG_REF = new InjectionToken('TAB_DIALOG_REF');
function injectDialogRef() {
    return inject(TAB_DIALOG_REF);
}
class DialogRef {
    _closed$ = new Subject();
    closed$ = this._closed$.asObservable();
    _result = undefined;
    close(result) {
        this._closed$.next(result ?? this._result);
        this._closed$.complete();
    }
    /**
     * Sets the result of the dialog without closing it.
     * This is useful for cases where you want to update the result
     * but keep the dialog open, such as in a form submission.
     * If the close() function is called with a non-undefined result, it will overwrite this value
     * @param result The result to set.
     */
    setResultWithoutClosing(result) {
        this._result = result;
    }
}
class DialogRefInternal extends DialogRef {
    dialogElement = undefined;
    reposition = undefined;
}

const TAB_DATA_REF = new InjectionToken('TAB_DIALOG_DATA_REF');
function injectDialogData() {
    return inject(TAB_DATA_REF);
}

class ConfirmationDialogComponent {
    data = inject(TAB_DATA_REF);
    data2 = injectDialogData();
    dialogRef = injectDialogRef();
    $accept = viewChild.required('accept');
    $cancel = viewChild.required('cancel');
    ngAfterContentInit() {
        if (this.data.autofocus === 'accept') {
            this.$accept().$nativeElement.nativeElement.focus();
        }
        else if (this.data.autofocus === 'cancel') {
            this.$cancel().$nativeElement.nativeElement.focus();
        }
    }
    ngAfterViewInit() {
        if (this.data.autofocus === 'accept') {
            this.$accept().$nativeElement.nativeElement.focus();
        }
        else if (this.data.autofocus === 'cancel') {
            this.$cancel().$nativeElement.nativeElement.focus();
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ConfirmationDialogComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: ConfirmationDialogComponent, isStandalone: false, selector: "tab-confirmation-dialog", viewQueries: [{ propertyName: "$accept", first: true, predicate: ["accept"], descendants: true, isSignal: true }, { propertyName: "$cancel", first: true, predicate: ["cancel"], descendants: true, isSignal: true }], ngImport: i0, template: `
        <div class="dialog-content">
            @if (data.contentTemplate) {
                <div>
                    <ng-container *ngTemplateOutlet="data.contentTemplate" />
                </div>
            } @else {
                <div>{{ data.content }}</div>
            }
        </div>
        <div class="dialog-actions">
            <button #cancel tabindex="0" (click)="dialogRef.close(false)">
                {{ data.cancelBtnText ?? 'Cancel' }}
            </button>
            <button #accept tabindex="0" [color]="data.color" (click)="dialogRef.close(true)">
                {{ data.acceptBtnText ?? 'OK' }}
            </button>
        </div>
    `, isInline: true, styles: [".dialog-content{padding:12px 18px}.dialog-actions{display:flex;justify-content:flex-end;gap:1em;padding:0 12px 12px}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.ButtonComponent, selector: "button:not([tab-menu-button]),a[button]:not([tab-menu-button])", inputs: ["disabled", "loading", "tabindex", "type", "kind", "color", "layout", "inline", "noFocusOnClick"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ConfirmationDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-confirmation-dialog', standalone: false, template: `
        <div class="dialog-content">
            @if (data.contentTemplate) {
                <div>
                    <ng-container *ngTemplateOutlet="data.contentTemplate" />
                </div>
            } @else {
                <div>{{ data.content }}</div>
            }
        </div>
        <div class="dialog-actions">
            <button #cancel tabindex="0" (click)="dialogRef.close(false)">
                {{ data.cancelBtnText ?? 'Cancel' }}
            </button>
            <button #accept tabindex="0" [color]="data.color" (click)="dialogRef.close(true)">
                {{ data.acceptBtnText ?? 'OK' }}
            </button>
        </div>
    `, changeDetection: ChangeDetectionStrategy.OnPush, styles: [".dialog-content{padding:12px 18px}.dialog-actions{display:flex;justify-content:flex-end;gap:1em;padding:0 12px 12px}\n"] }]
        }] });
class IConfirmationDialogData {
    content;
    contentTemplate;
    contentTemplateContext;
    color = 'secondary';
    acceptBtnText;
    cancelBtnText;
    autofocus;
}

class TemplateDialogComponent {
    data = inject(TAB_DATA_REF);
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TemplateDialogComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.3", type: TemplateDialogComponent, isStandalone: false, selector: "tab-template-dialog", ngImport: i0, template: `
        <ng-container [ngTemplateOutlet]="data.contentTemplate" [ngTemplateOutletContext]="data.contentTemplateContext" />
    `, isInline: true, dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TemplateDialogComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'tab-template-dialog',
                    standalone: false,
                    template: `
        <ng-container [ngTemplateOutlet]="data.contentTemplate" [ngTemplateOutletContext]="data.contentTemplateContext" />
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                }]
        }] });

/**
 * The dialog will be placed in the global stacking context, placed at the end of the document body.
 * This is useful for dialogs that need to be displayed above all other content, such as modals or overlays.
 */
class GlobalStackOptions {
    referenceElement;
    constructor(
    /**
     * The reference element thats' DOMRect is passed to the left() and height() function of the dialog args.
     * Optional.
     */
    referenceElement) {
        this.referenceElement = referenceElement;
    }
}
/**
 * The dialog will be placed in the local stacking context, inserted after the specified element.
 * This is useful for dialogs that need to be displayed relative to a specific element, such as tooltips or popovers.
 * The dialog will be placed after the `insertAfterElement` in the DOM.
 * The dialog content will be tabbable right after the `insertAfterElement`.
 */
class LocalStackOptions {
    insertAfterElement;
    referenceElement;
    constructor(
    /**
     * The element after which the dialog will be inserted in the DOM.
     * If 'referenceElement' is not provided, this will be the reference element that's DOMRect is passed to the left() and height() function of the dialog args.
     */
    insertAfterElement, 
    /**
     * The reference element that's DOMRect is passed to the left() and height() function of the dialog args.
     * If not provided, the `insertAfterElement` will be used as the reference element.
     */
    referenceElement) {
        this.insertAfterElement = insertAfterElement;
        this.referenceElement = referenceElement;
    }
}

// Styles for the dialog container are in _dialog.service.scss in the styles folder
class DialogService {
    injector = inject(Injector);
    appRef = inject(ApplicationRef);
    environmentInjector = inject(EnvironmentInjector);
    openModal(component, data, args) {
        const a = {
            width: args?.width ?? '300px',
            height: args?.height ?? 'fit-content',
            maxWidth: args?.maxWidth ?? 'calc(100vw - 100px)',
            maxHeight: args?.maxHeight ?? 'calc(80vh - 50px)',
            closeOnBackdropClick: args?.closeOnBackdropClick ?? true,
            closeOnEscape: args?.closeOnEscape ?? true,
            backdropCss: {
                backgroundColor: 'var(--twc-modal-color-backdrop)',
            },
            containerCss: {
                backgroundColor: 'var(--twc-color-base)',
                borderColor: 'var(--twc-color-border-light)',
                borderStyle: 'solid',
                borderWidth: '1px',
                borderRadius: '1px',
                boxShadow: '0 2px 10px var(--twc-modal-color-box-shadow)',
                cursor: 'default',
                display: 'flex',
                flexDirection: 'column',
            },
            left(actualWidth) {
                return `calc(50vw - ${actualWidth / 2}px)`;
            },
            top(actualHeight) {
                return `calc(50vh - ${actualHeight / 2}px)`;
            },
            header: args?.header,
            trapFocus: true,
        };
        const ref = this.openDialog(component, data, a);
        return ref;
    }
    openTemplateModal(contentTemplate, contentTemplateContext, args) {
        return this.openModal(TemplateDialogComponent, { contentTemplate, contentTemplateContext }, args);
    }
    async openConfirmationMessageDialog(title, message, color, acceptBtnText, cancelBtnText, autofocus, args) {
        const modalArgs = {
            ...(args ?? {}),
            header: { title, allowClose: true },
        };
        return new Promise((resolve) => {
            const data = {
                content: message,
                color,
                autofocus,
                acceptBtnText,
                cancelBtnText,
                contentTemplate: undefined,
                contentTemplateContext: undefined,
            };
            const dialogRef = this.openModal(ConfirmationDialogComponent, data, modalArgs);
            dialogRef.closed$.subscribe((result) => {
                resolve(result ?? false);
            });
        });
    }
    async openConfirmationTemplateDialog(title, template, templateContext, color, acceptBtnText, cancelBtnText, autofocus, args) {
        const modalArgs = {
            ...(args ?? {}),
            header: { title, allowClose: true },
        };
        return new Promise((resolve) => {
            const data = {
                content: undefined,
                color,
                autofocus,
                acceptBtnText,
                cancelBtnText,
                contentTemplate: template,
                contentTemplateContext: templateContext,
            };
            const dialogRef = this.openModal(ConfirmationDialogComponent, data, modalArgs);
            dialogRef.closed$.subscribe((result) => {
                resolve(result ?? false);
            });
        });
    }
    startZIndex = 100;
    zIndexStep = 10;
    zIndex = this.startZIndex;
    dialogStack = [];
    openTemplateDialog(contentTemplate, args, contentTemplateContext, stackOptions = new GlobalStackOptions()) {
        return this.openDialog(TemplateDialogComponent, { contentTemplate, contentTemplateContext }, args, stackOptions);
    }
    openDialog(component, data, args = {}, stackOptions = new GlobalStackOptions()) {
        let trappedFocus = undefined;
        // Before creating the dialog, trap focus
        // This means that we get all elements which are tabbable and set the tabindex to -1 for the duration of the popup
        if (args.trapFocus === true) {
            trappedFocus = this.trapFocus();
        }
        const dialogRef = new DialogRefInternal();
        // calculate new zIndex
        let { zIndex } = this;
        if (this.dialogStack.length > 0) {
            zIndex = this.dialogStack[this.dialogStack.length - 1].zIndex + this.zIndexStep;
        }
        // push this dialog to the new stack
        this.dialogStack.push({ dialogRef, zIndex, args });
        // Set the backdrop
        const backdrop = this.createBackdrop(args, dialogRef, zIndex - 1, stackOptions);
        this.setEscapeHandler();
        // Create an injector that provides the DialogRef
        const injector = Injector.create({
            providers: [
                { provide: TAB_DIALOG_REF, useValue: dialogRef },
                { provide: TAB_DATA_REF, useValue: data },
            ],
            parent: this.injector,
        });
        // Create the component view
        const componentView = this.createView(component, injector);
        // Attach component to the application
        this.appRef.attachView(componentView);
        // Create a container for the dialog
        const dialogElement = this.createDialogElement(componentView, args, injector, dialogRef, zIndex);
        dialogRef.dialogElement = dialogElement;
        // always insert element after the backdrop
        if (backdrop) {
            backdrop?.insertAdjacentElement('afterend', dialogElement);
        }
        else if (stackOptions instanceof LocalStackOptions) {
            stackOptions.insertAfterElement.insertAdjacentElement('afterend', dialogElement);
        }
        else {
            document.body.appendChild(dialogElement);
        }
        // Handle container position and window resize event
        dialogRef.reposition = (getArgs) => {
            getArgs(args);
            DialogService.calculateAndSetPosition(dialogElement, args, stackOptions);
        };
        const resizeSubscription = DialogService.manageDialogPosition(dialogElement, args, stackOptions);
        // Handle dialog close
        dialogRef.closed$.subscribe(() => {
            if (resizeSubscription) {
                resizeSubscription.unsubscribe();
            }
            this.appRef.detachView(componentView);
            componentView.destroy();
            dialogElement.remove();
            const dialogIndex = this.dialogStack.findIndex((d) => d.zIndex === zIndex);
            this.dialogStack.splice(dialogIndex, 1);
            // clear backdrop
            backdrop?.remove();
            // set escape handler
            this.setEscapeHandler();
            // restore focus to the elements that were trapped
            if (trappedFocus) {
                this.restoreFocus(trappedFocus);
            }
        });
        return dialogRef;
    }
    createBackdrop(args, dialogRef, dialogZIndex, stackOptions) {
        if (args.skipCreatingBackdrop === true) {
            return undefined;
        }
        const backdrop = document.createElement('div');
        backdrop.classList.add('dialog-backdrop');
        backdrop.style.zIndex = (dialogZIndex - 1).toString();
        if (args.backdropCss) {
            Object.keys(args.backdropCss).forEach((key) => {
                backdrop.style[key] = args.backdropCss[key];
            });
        }
        if (stackOptions instanceof LocalStackOptions) {
            stackOptions.insertAfterElement.insertAdjacentElement('afterend', backdrop);
        }
        else {
            document.body.appendChild(backdrop);
        }
        if (args.closeOnBackdropClick === true) {
            backdrop.onclick = () => {
                dialogRef.close();
            };
        }
        return backdrop;
    }
    escapeSubscription = null;
    setEscapeHandler() {
        if (this.escapeSubscription) {
            this.escapeSubscription.unsubscribe();
            this.escapeSubscription = null;
        }
        if (this.dialogStack.length <= 0) {
            return;
        }
        // get the dialog to set the escape for
        const { dialogRef, args } = this.dialogStack[this.dialogStack.length - 1];
        if (args.closeOnEscape === true) {
            this.escapeSubscription = fromEvent(document, 'keydown')
                .pipe(map((e) => e))
                .subscribe((e) => {
                if (e.key === 'Escape') {
                    if (this.escapeSubscription) {
                        this.escapeSubscription.unsubscribe();
                        this.escapeSubscription = null;
                    }
                    dialogRef.close();
                    e.preventDefault();
                }
            });
        }
    }
    createView(component, injector) {
        const componentRef = createComponent(component, {
            environmentInjector: this.environmentInjector,
            elementInjector: injector,
        });
        return componentRef.hostView;
    }
    createDialogElement(viewRef, args, injector, dialogRef, zIndex) {
        const dialogElement = viewRef.rootNodes[0];
        dialogElement.classList.add('dialog-container');
        dialogElement.style.zIndex = zIndex.toString();
        if (args.containerCss) {
            Object.keys(args.containerCss).forEach((key) => {
                dialogElement.style[key] = args.containerCss[key];
            });
        }
        if (args.header) {
            const headerElement = document.createElement('div');
            headerElement.classList.add('dialog-header');
            const titleElement = document.createElement('div');
            titleElement.classList.add('dialog-title');
            titleElement.innerHTML = args.header.title;
            headerElement.appendChild(titleElement);
            if (args.header.allowClose) {
                const iconRef = createComponent(IconComponent, {
                    environmentInjector: this.environmentInjector,
                    elementInjector: injector,
                });
                const iconElement = iconRef.hostView.rootNodes[0];
                iconElement.textContent = 'close';
                iconElement.setAttribute('tabindex', '0');
                iconElement.addEventListener('click', () => {
                    dialogRef.close();
                });
                iconElement.addEventListener('keydown', (e) => {
                    if (e.key === 'Enter' || e.key === ' ') {
                        dialogRef.close();
                        e.preventDefault();
                    }
                });
                this.appRef.attachView(iconRef.hostView);
                headerElement.appendChild(iconElement);
            }
            dialogElement.insertBefore(headerElement, dialogElement.firstChild);
        }
        return dialogElement;
    }
    static manageDialogPosition(dialogElement, args, stackOptions) {
        // Temporarily position the dialog offscreen to get its dimensions
        dialogElement.style.top = '-9999px';
        dialogElement.style.left = '-9999px';
        setTimeout(() => {
            DialogService.calculateAndSetPosition(dialogElement, args, stackOptions);
        }, 10);
        let resizeSubscription = null;
        // Handle window resize event
        resizeSubscription = fromEvent(window, 'resize').subscribe(() => {
            DialogService.calculateAndSetPosition(dialogElement, args, stackOptions);
        });
        // Monitor changes to the size of the dialog
        const resizeObserver = new ResizeObserver(() => {
            DialogService.calculateAndSetPosition(dialogElement, args, stackOptions);
        });
        // Start observing the dialog element
        resizeObserver.observe(dialogElement);
        // Monitor changes to the size of the insertAfterElement
        const insertAfterResizeObserver = new ResizeObserver(() => {
            DialogService.calculateAndSetPosition(dialogElement, args, stackOptions);
        });
        // Start observing the referenceElement if it exists
        const referenceElement = this.getReferenceElement(stackOptions);
        if (referenceElement) {
            insertAfterResizeObserver.observe(referenceElement);
        }
        // Return a subscription-like object that also disconnects the observer
        return new Subscription(() => {
            resizeObserver.disconnect();
            resizeSubscription?.unsubscribe();
            insertAfterResizeObserver.disconnect();
        });
    }
    static getReferenceElement(stackOptions) {
        if (stackOptions instanceof LocalStackOptions) {
            return stackOptions.referenceElement ?? stackOptions.insertAfterElement;
        }
        else if (stackOptions instanceof GlobalStackOptions) {
            return stackOptions.referenceElement;
        }
        return undefined;
    }
    static calculateAndSetPosition(dialogElement, args, stackOptions) {
        if (args.maxWidth !== undefined) {
            dialogElement.style.maxWidth = args.maxWidth;
        }
        if (args.maxHeight !== undefined) {
            dialogElement.style.maxHeight = args.maxHeight;
        }
        dialogElement.style.overflowX = 'hidden';
        dialogElement.style.overflowY = 'hidden';
        const referenceElement = this.getReferenceElement(stackOptions);
        const referenceElementRect = referenceElement?.getBoundingClientRect();
        let widthCss;
        let heightCss;
        if (args.width === undefined) {
            widthCss = 'fit-content';
        }
        else if (typeof args.width === 'function') {
            if (!referenceElementRect) {
                throw new Error('When using a function for width, insertAfterElement must be provided.');
            }
            widthCss = args.width(referenceElementRect);
        }
        else {
            widthCss = args.width;
        }
        if (args.height === undefined) {
            heightCss = 'fit-content';
        }
        else if (typeof args.height === 'function') {
            if (!referenceElementRect) {
                throw new Error('When using a function for height, insertAfterElement must be provided.');
            }
            heightCss = args.height(referenceElementRect);
        }
        else {
            heightCss = args.height;
        }
        dialogElement.style.height = heightCss;
        dialogElement.style.width = widthCss;
        const actualWidth = dialogElement.offsetWidth;
        const actualHeight = dialogElement.offsetHeight;
        if (typeof args.top === 'function') {
            dialogElement.style.top = args.top(actualWidth, actualHeight, referenceElementRect);
        }
        else if (typeof args.top === 'string') {
            dialogElement.style.top = args.top;
        }
        if (typeof args.left === 'function') {
            dialogElement.style.left = args.left(actualWidth, actualHeight, referenceElementRect);
        }
        else if (typeof args.left === 'string') {
            dialogElement.style.left = args.left;
        }
        // if dialog is higher than the available page height, set it to scroll
        if (actualHeight + dialogElement.offsetTop > window.innerHeight) {
            dialogElement.style.height = `calc(100vh - ${dialogElement.offsetTop}px)`;
            dialogElement.style.overflowY = 'auto';
        }
        // if dialog is wider than the available page width, set it to scroll
        if (actualWidth + dialogElement.offsetLeft > window.innerWidth) {
            dialogElement.style.width = `calc(100vw - ${dialogElement.offsetLeft}px)`;
            dialogElement.style.overflowX = 'auto';
        }
    }
    trapFocus() {
        const tabbableElements = tabbable(document.body);
        const elementsTable = tabbableElements.map((e) => ({
            element: e,
            originalTabIndex: e.tabIndex,
        }));
        elementsTable.forEach((e) => (e.element.tabIndex = -1));
        const focusedElement = document.activeElement;
        if (focusedElement) {
            focusedElement.blur();
        }
        return {
            elements: elementsTable,
            focusedElement: focusedElement,
        };
    }
    restoreFocus(obj) {
        obj.elements.forEach((e) => (e.element.tabIndex = e.originalTabIndex));
        if (obj.focusedElement) {
            obj.focusedElement.focus();
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: DialogService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: DialogService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: DialogService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root', // This service is a singleton and should be provided in the root injector
                }]
        }] });

class TableauUiDialogModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDialogModule, declarations: [ConfirmationDialogComponent, TemplateDialogComponent], imports: [CommonModule, TableauUiButtonModule] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDialogModule, providers: [DialogService], imports: [CommonModule, TableauUiButtonModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDialogModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, TableauUiButtonModule],
                    declarations: [ConfirmationDialogComponent, TemplateDialogComponent],
                    providers: [DialogService],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DialogRef, DialogService, GlobalStackOptions, LocalStackOptions, TableauUiDialogModule, injectDialogData, injectDialogRef };
//# sourceMappingURL=tableau-ui-angular-dialog.mjs.map
