import * as i0 from '@angular/core';
import { viewChild, TemplateRef, input, model, ChangeDetectionStrategy, Component, contentChildren, effect, computed, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';

class DrawerComponent {
    $template = viewChild.required(TemplateRef);
    /**
     * The drawer position.
     * When changed after the drawer is opened, it will only be applied next open.
     * @default 'left'
     */
    $position = input('left', {
        alias: 'position',
    });
    /**
     * The border to show between the drawer and the content.
     * @default 'solid 1px var(--twc-color-border-light)'
     */
    $border = input('solid 1px var(--twc-color-border-light)', {
        alias: 'border',
    });
    /**
     * The gap to apply to between the drawer and the content.
     * This is useful to avoid content being too close to the edges.
     * Any CSS value is accepted, like '10px', '1rem', '2em', etc.
     * @default '0.5rem'
     */
    $padding = input('0.5rem', {
        alias: 'padding',
    });
    /**
     * The drawer mode.
     * When changed after the drawer is opened, it will only be applied next open
     */
    // readonly $mode = input.required<'over' | 'side'>({
    //   alias: 'mode'
    // });
    /**
     * The drawer width.
     * This can be a CSS value like '300px', '50%', or '30rem'.
     */
    $width = input.required({
        alias: 'width',
    });
    /**
     * The drawer status.
     * @default 'false'
     */
    $isOpen = model(false, {
        alias: 'isOpen',
    });
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: DrawerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.2.0", version: "20.0.3", type: DrawerComponent, isStandalone: false, selector: "tab-drawer", inputs: { $position: { classPropertyName: "$position", publicName: "position", isSignal: true, isRequired: false, transformFunction: null }, $border: { classPropertyName: "$border", publicName: "border", isSignal: true, isRequired: false, transformFunction: null }, $padding: { classPropertyName: "$padding", publicName: "padding", isSignal: true, isRequired: false, transformFunction: null }, $width: { classPropertyName: "$width", publicName: "width", isSignal: true, isRequired: true, transformFunction: null }, $isOpen: { classPropertyName: "$isOpen", publicName: "isOpen", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { $isOpen: "isOpenChange" }, viewQueries: [{ propertyName: "$template", first: true, predicate: TemplateRef, descendants: true, isSignal: true }], ngImport: i0, template: `
        <ng-template><ng-content /></ng-template>
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: DrawerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'tab-drawer',
                    standalone: false,
                    template: `
        <ng-template><ng-content /></ng-template>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                }]
        }] });

class DrawerContainerComponent {
    $drawers = contentChildren(DrawerComponent);
    drawersChanged = effect(() => {
        const drawers = this.$drawers();
        console.log('Drawers changed:', drawers);
        const leftDrawers = drawers.filter((e) => e.$position() === 'left');
        const rightDrawers = drawers.filter((e) => e.$position() === 'right');
        if (leftDrawers.length > 1) {
            throw new Error('There can only be one left drawer.');
        }
        if (rightDrawers.length > 1) {
            throw new Error('There can only be one right drawer.');
        }
    });
    $leftDrawer = computed(() => this.$drawers().find((e) => e.$position() === 'left'));
    $rightDrawer = computed(() => this.$drawers().find((e) => e.$position() === 'right'));
    $rightDrawerPositionExpression = computed(() => {
        const rightDrawer = this.$rightDrawer();
        if (!rightDrawer) {
            return '0px';
        }
        const width = rightDrawer.$width();
        let padding = rightDrawer.$padding();
        // if padding is just a number, add px
        if (/^\d+$/.test(padding)) {
            padding += 'px';
        }
        const borderWidth = this.getBorderWidth(rightDrawer.$border()) ?? '0px';
        const ret = `${width} + (${padding} * 2) + ${borderWidth}`;
        return ret;
    });
    $leftDrawerPositionExpression = computed(() => {
        const leftDrawer = this.$leftDrawer();
        if (!leftDrawer) {
            return '0px';
        }
        const width = leftDrawer.$width();
        let padding = leftDrawer.$padding();
        // if padding is just a number, add px
        if (/^\d+$/.test(padding)) {
            padding += 'px';
        }
        const borderWidth = this.getBorderWidth(leftDrawer.$border()) ?? '0px';
        const ret = `${width} + (${padding} * 2) + ${borderWidth}`;
        return ret;
    });
    getBorderWidth(border) {
        const parts = border.trim().split(/\s+/);
        const widthRegex = /^(\d+(\.\d+)?)(px|em|rem|%)$/;
        for (const part of parts) {
            if (widthRegex.test(part)) {
                return part;
            }
        }
        return null;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: DrawerContainerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: DrawerContainerComponent, isStandalone: false, selector: "tab-drawer-container", queries: [{ propertyName: "$drawers", predicate: DrawerComponent, isSignal: true }], ngImport: i0, template: "@let leftDrawer = $leftDrawer();\n@let rightDrawer = $rightDrawer();\n@if (leftDrawer) {\n    <div\n        #leftDrawerWrapper\n        class=\"drawer left\"\n        [style.left]=\"leftDrawer.$isOpen() ? '0' : `calc(-1 * (${$leftDrawerPositionExpression()}))`\"\n        [style.width]=\"leftDrawer.$width()\"\n        [style.borderRight]=\"leftDrawer.$border()\"\n    >\n        <ng-container [ngTemplateOutlet]=\"leftDrawer.$template()\" />\n    </div>\n}\n<div class=\"drawer-content\" [style.right]=\"rightDrawer?.$isOpen() ? `calc(${$rightDrawerPositionExpression()})` : '0'\" [style.left]=\"leftDrawer?.$isOpen() ? `calc(${$leftDrawerPositionExpression()})` : '0'\">\n    <ng-content />\n</div>\n\n@if (rightDrawer) {\n    <div class=\"drawer right\" [style.right]=\" rightDrawer.$isOpen() ? '0' :`calc(-1 * (${$rightDrawerPositionExpression()}))`\" [style.width]=\"rightDrawer.$width()\" [style.borderLeft]=\"rightDrawer.$border()\">\n        <ng-container [ngTemplateOutlet]=\"rightDrawer.$template()\" />\n    </div>\n}\n", styles: [":host{display:flex;grid-template-columns:auto 1fr auto;width:100%;height:100%;grid-template-rows:1fr;position:relative;overflow:hidden}:host>*{overflow:auto;transition:left .2s ease-in-out,right .2s ease-in-out;position:absolute;height:100%;max-height:100%}.drawer-content{grid-column:2;overflow:auto}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: DrawerContainerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-drawer-container', standalone: false, changeDetection: ChangeDetectionStrategy.OnPush, template: "@let leftDrawer = $leftDrawer();\n@let rightDrawer = $rightDrawer();\n@if (leftDrawer) {\n    <div\n        #leftDrawerWrapper\n        class=\"drawer left\"\n        [style.left]=\"leftDrawer.$isOpen() ? '0' : `calc(-1 * (${$leftDrawerPositionExpression()}))`\"\n        [style.width]=\"leftDrawer.$width()\"\n        [style.borderRight]=\"leftDrawer.$border()\"\n    >\n        <ng-container [ngTemplateOutlet]=\"leftDrawer.$template()\" />\n    </div>\n}\n<div class=\"drawer-content\" [style.right]=\"rightDrawer?.$isOpen() ? `calc(${$rightDrawerPositionExpression()})` : '0'\" [style.left]=\"leftDrawer?.$isOpen() ? `calc(${$leftDrawerPositionExpression()})` : '0'\">\n    <ng-content />\n</div>\n\n@if (rightDrawer) {\n    <div class=\"drawer right\" [style.right]=\" rightDrawer.$isOpen() ? '0' :`calc(-1 * (${$rightDrawerPositionExpression()}))`\" [style.width]=\"rightDrawer.$width()\" [style.borderLeft]=\"rightDrawer.$border()\">\n        <ng-container [ngTemplateOutlet]=\"rightDrawer.$template()\" />\n    </div>\n}\n", styles: [":host{display:flex;grid-template-columns:auto 1fr auto;width:100%;height:100%;grid-template-rows:1fr;position:relative;overflow:hidden}:host>*{overflow:auto;transition:left .2s ease-in-out,right .2s ease-in-out;position:absolute;height:100%;max-height:100%}.drawer-content{grid-column:2;overflow:auto}\n"] }]
        }] });

class TableauUiDrawerModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDrawerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDrawerModule, declarations: [DrawerContainerComponent, DrawerComponent], imports: [CommonModule], exports: [DrawerContainerComponent, DrawerComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDrawerModule, imports: [CommonModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiDrawerModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [DrawerContainerComponent, DrawerComponent],
                    exports: [DrawerContainerComponent, DrawerComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DrawerComponent, DrawerContainerComponent, TableauUiDrawerModule };
//# sourceMappingURL=tableau-ui-angular-drawer.mjs.map
