import * as i0 from '@angular/core';
import { signal, effect, ChangeDetectionStrategy, Component, Directive, model, input, contentChild, inject, NgModule } from '@angular/core';
import { toObservable } from '@angular/core/rxjs-interop';
import { startWith } from 'rxjs';
import { generateRandomString } from 'tableau-ui-angular/utils';
import * as i1 from 'tableau-ui-angular/button';
import { TableauUiButtonModule } from 'tableau-ui-angular/button';
import * as i2 from 'tableau-ui-angular/icon';
import { TableauUiIconModule } from 'tableau-ui-angular/icon';
import { CommonModule } from '@angular/common';

class AccordionRegistry {
    nodes = signal([]);
    register(node) {
        const nodes = this.nodes();
        const existingNode = nodes.find((n) => n.id === node.id);
        if (!existingNode) {
            this.nodes.set([...nodes, node]);
        }
    }
    unregister(node) {
        const nodes = this.nodes();
        const filteredNodes = nodes.filter((n) => n.id === node.id);
        if (filteredNodes.length !== nodes.length) {
            this.nodes.set(filteredNodes);
        }
    }
}

class AccordionComponent {
    registry = new AccordionRegistry();
    subs = [];
    registryChanged = effect(() => {
        const items = this.registry.nodes();
        this.subs.forEach((sub) => {
            sub.unsubscribe();
        });
        this.subs = items.map((item) => item.expandedChange$.subscribe((expanded) => {
            if (expanded) {
                items.forEach((i) => {
                    if (i.id !== item.id) {
                        i.$expanded.set(false);
                    }
                });
            }
        }));
    });
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: AccordionComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.3", type: AccordionComponent, isStandalone: false, selector: "tab-accordion", host: { properties: { "attr.role": "\"tablist\"", "attr.aria-multiselectable": "false", "attr.aria-orientation": "\"vertical\"" } }, ngImport: i0, template: '<ng-content select="tab-expansion-panel" />', isInline: true, styles: [":host{height:100%;display:flex;flex-direction:column;justify-content:flex-start}:host ::ng-deep tab-expansion-panel:not(:first-child){margin-top:-1px}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: AccordionComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-accordion', standalone: false, template: '<ng-content select="tab-expansion-panel" />', changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        '[attr.role]': '"tablist"',
                        '[attr.aria-multiselectable]': 'false',
                        '[attr.aria-orientation]': '"vertical"',
                    }, styles: [":host{height:100%;display:flex;flex-direction:column;justify-content:flex-start}:host ::ng-deep tab-expansion-panel:not(:first-child){margin-top:-1px}\n"] }]
        }] });

class ExpansionPanelTitleComponent {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ExpansionPanelTitleComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.3", type: ExpansionPanelTitleComponent, isStandalone: false, selector: "tab-expansion-panel-title", ngImport: i0, template: `
        <ng-content />
    `, isInline: true, styles: [":host{align-items:center;gap:.25rem;display:flex}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ExpansionPanelTitleComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-expansion-panel-title', standalone: false, template: `
        <ng-content />
    `, changeDetection: ChangeDetectionStrategy.OnPush, styles: [":host{align-items:center;gap:.25rem;display:flex}\n"] }]
        }] });
class ExpansionPanelTitleExpandedContentDirective {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ExpansionPanelTitleExpandedContentDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.3", type: ExpansionPanelTitleExpandedContentDirective, isStandalone: false, selector: "tab-expansion-panel-title[expanded]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ExpansionPanelTitleExpandedContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'tab-expansion-panel-title[expanded]',
                    standalone: false,
                }]
        }] });
class ExpansionPanelTitleCollapsedContentDirective {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ExpansionPanelTitleCollapsedContentDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.3", type: ExpansionPanelTitleCollapsedContentDirective, isStandalone: false, selector: "tab-expansion-panel-title[collapsed]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ExpansionPanelTitleCollapsedContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'tab-expansion-panel-title[collapsed]',
                    standalone: false,
                }]
        }] });

class ExpansionPanelComponent {
    id = generateRandomString(16);
    /**
     * The expanded state of the panel.
     * @default false
     */
    $expanded = model(false, {
        alias: 'expanded',
    });
    expandedChange$ = toObservable(this.$expanded).pipe(startWith(this.$expanded()));
    /**
     * The disabled state of the panel.
     * @default false
     */
    $disabled = input(false, {
        alias: 'disabled',
    });
    /**
     * Disables the hover color of the header
     */
    $noHeaderHover = input(false, {
        alias: 'noHeaderHover',
    });
    $expandedHeader = contentChild(ExpansionPanelTitleExpandedContentDirective);
    $collapsedHeader = contentChild(ExpansionPanelTitleCollapsedContentDirective);
    accordion = inject(AccordionComponent, {
        skipSelf: true,
        optional: true,
    });
    $registry = input(undefined, {
        alias: 'registry',
    });
    ngOnInit() {
        const registry = this.$registry() ?? this.accordion?.registry;
        registry?.register(this);
    }
    ngOnDestroy() {
        const registry = this.$registry() ?? this.accordion?.registry;
        registry?.unregister(this);
    }
    setExpanded(expanded) {
        if (this.$disabled()) {
            return;
        }
        this.$expanded.set(expanded);
    }
    onclick() {
        if (this.$disabled()) {
            return;
        }
        this.setExpanded(!this.$expanded());
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ExpansionPanelComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: ExpansionPanelComponent, isStandalone: false, selector: "tab-expansion-panel", inputs: { $expanded: { classPropertyName: "$expanded", publicName: "expanded", isSignal: true, isRequired: false, transformFunction: null }, $disabled: { classPropertyName: "$disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, $noHeaderHover: { classPropertyName: "$noHeaderHover", publicName: "noHeaderHover", isSignal: true, isRequired: false, transformFunction: null }, $registry: { classPropertyName: "$registry", publicName: "registry", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { $expanded: "expandedChange" }, host: { properties: { "attr.expanded": "$expanded() ? true : null", "attr.disabled": "$disabled() ? true : null" } }, queries: [{ propertyName: "$expandedHeader", first: true, predicate: ExpansionPanelTitleExpandedContentDirective, descendants: true, isSignal: true }, { propertyName: "$collapsedHeader", first: true, predicate: ExpansionPanelTitleCollapsedContentDirective, descendants: true, isSignal: true }], ngImport: i0, template: "<!-- eslint-disable-next-line @angular-eslint/template/interactive-supports-focus, @angular-eslint/template/click-events-have-key-events -->\n<div class=\"header\" [class.disabled]=\"$disabled()\" [class.no-hover]=\"$noHeaderHover()\" (click)=\"onclick()\">\n    @if ($expanded() && $expandedHeader()) {\n        <div>\n            <ng-content select=\"tab-expansion-panel-title[expanded]\" />\n        </div>\n    } @else if (!$expanded() && $collapsedHeader()) {\n        <div>\n            <ng-content select=\"tab-expansion-panel-title[collapsed]\" />\n        </div>\n    } @else {\n        <div><ng-content select=\"tab-expansion-panel-title\" /></div>\n    }\n    <button layout=\"icon\" color=\"plain\" [disabled]=\"$disabled()\">\n        <tab-icon [value]=\"$expanded() ? 'keyboard_arrow_up' : 'keyboard_arrow_down'\" />\n    </button>\n</div>\n\n@if ($expanded()) {\n    <div class=\"content\">\n        <ng-content />\n    </div>\n}\n", styles: [":host{background:var(--twc-color-base);border-color:var(--twc-color-border-light);border-radius:var(--twc-menu-border-radius);border-style:solid;border-width:1px;color:var(--twc-color-text);line-height:normal;overflow:hidden auto;-webkit-user-select:none;user-select:none;display:grid;grid-template-rows:auto;gap:.25rem}:host.expanded{grid-template-rows:auto 1fr}:host .header{display:grid;grid-template-columns:1fr auto;gap:.5rem;outline:none;padding:.25rem}:host .header div{margin-left:.25rem;align-self:center}:host .header button{min-height:1rem;min-width:1rem;align-self:center}:host .header button tab-icon{font-size:1.2rem}:host .header.disabled{color:var(--twc-color-disabled)}:host .header:not(.disabled,.no-hover):hover{background:var(--twc-color-highlight);cursor:pointer}:host .content{padding:.25rem}\n"], dependencies: [{ kind: "component", type: i1.ButtonComponent, selector: "button:not([tab-menu-button]),a[button]:not([tab-menu-button])", inputs: ["disabled", "loading", "tabindex", "type", "kind", "color", "layout", "inline", "noFocusOnClick"] }, { kind: "component", type: i2.IconComponent, selector: "tab-icon", inputs: ["value", "color", "type", "fill", "weight", "grade", "opticalSizePx"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ExpansionPanelComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-expansion-panel', standalone: false, changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        '[attr.expanded]': '$expanded() ? true : null',
                        '[attr.disabled]': '$disabled() ? true : null',
                    }, template: "<!-- eslint-disable-next-line @angular-eslint/template/interactive-supports-focus, @angular-eslint/template/click-events-have-key-events -->\n<div class=\"header\" [class.disabled]=\"$disabled()\" [class.no-hover]=\"$noHeaderHover()\" (click)=\"onclick()\">\n    @if ($expanded() && $expandedHeader()) {\n        <div>\n            <ng-content select=\"tab-expansion-panel-title[expanded]\" />\n        </div>\n    } @else if (!$expanded() && $collapsedHeader()) {\n        <div>\n            <ng-content select=\"tab-expansion-panel-title[collapsed]\" />\n        </div>\n    } @else {\n        <div><ng-content select=\"tab-expansion-panel-title\" /></div>\n    }\n    <button layout=\"icon\" color=\"plain\" [disabled]=\"$disabled()\">\n        <tab-icon [value]=\"$expanded() ? 'keyboard_arrow_up' : 'keyboard_arrow_down'\" />\n    </button>\n</div>\n\n@if ($expanded()) {\n    <div class=\"content\">\n        <ng-content />\n    </div>\n}\n", styles: [":host{background:var(--twc-color-base);border-color:var(--twc-color-border-light);border-radius:var(--twc-menu-border-radius);border-style:solid;border-width:1px;color:var(--twc-color-text);line-height:normal;overflow:hidden auto;-webkit-user-select:none;user-select:none;display:grid;grid-template-rows:auto;gap:.25rem}:host.expanded{grid-template-rows:auto 1fr}:host .header{display:grid;grid-template-columns:1fr auto;gap:.5rem;outline:none;padding:.25rem}:host .header div{margin-left:.25rem;align-self:center}:host .header button{min-height:1rem;min-width:1rem;align-self:center}:host .header button tab-icon{font-size:1.2rem}:host .header.disabled{color:var(--twc-color-disabled)}:host .header:not(.disabled,.no-hover):hover{background:var(--twc-color-highlight);cursor:pointer}:host .content{padding:.25rem}\n"] }]
        }] });

class TableauUiExpansionPanelModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiExpansionPanelModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiExpansionPanelModule, declarations: [ExpansionPanelComponent, ExpansionPanelTitleCollapsedContentDirective, ExpansionPanelTitleComponent, ExpansionPanelTitleExpandedContentDirective, AccordionComponent], imports: [CommonModule, TableauUiButtonModule, TableauUiIconModule], exports: [ExpansionPanelComponent, ExpansionPanelTitleCollapsedContentDirective, ExpansionPanelTitleComponent, ExpansionPanelTitleExpandedContentDirective, AccordionComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiExpansionPanelModule, imports: [CommonModule, TableauUiButtonModule, TableauUiIconModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiExpansionPanelModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, TableauUiButtonModule, TableauUiIconModule],
                    declarations: [ExpansionPanelComponent, ExpansionPanelTitleCollapsedContentDirective, ExpansionPanelTitleComponent, ExpansionPanelTitleExpandedContentDirective, AccordionComponent],
                    exports: [ExpansionPanelComponent, ExpansionPanelTitleCollapsedContentDirective, ExpansionPanelTitleComponent, ExpansionPanelTitleExpandedContentDirective, AccordionComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AccordionComponent, AccordionRegistry, ExpansionPanelComponent, ExpansionPanelTitleCollapsedContentDirective, ExpansionPanelTitleComponent, ExpansionPanelTitleExpandedContentDirective, TableauUiExpansionPanelModule };
//# sourceMappingURL=tableau-ui-angular-expansion-panel.mjs.map
