import * as i0 from '@angular/core';
import { Pipe, contentChildren, inject, ElementRef, model, computed, signal, Directive, forwardRef, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { OptionComponent, TableauUiCommonModule } from 'tableau-ui-angular/common';
import * as i2 from 'tableau-ui-angular/icon';
import { TableauUiIconModule } from 'tableau-ui-angular/icon';
import { NG_VALUE_ACCESSOR } from '@angular/forms';

class IsValueSelectedPipe {
    transform(selectedValue, optionValue, allowMultiple) {
        if (allowMultiple && Array.isArray(selectedValue)) {
            return selectedValue.includes(optionValue);
        }
        else {
            return (selectedValue === optionValue
            // ||
            // this.safeStringify(selectedValue) ===
            //     this.safeStringify(optionValue)
            );
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: IsValueSelectedPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: IsValueSelectedPipe, isStandalone: false, name: "isValueSelected" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: IsValueSelectedPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'isValueSelected',
                    standalone: false,
                    pure: true,
                }]
        }] });

const LIST_COMPONENT_HOST = {
    class: 'tab-input',
    '[class.silent-focus]': '$focusMode() === "silent"',
    '[tabindex]': '$disabled() || $focusMode() === "none" ? -1 : 0',
    '(keydown)': 'onKeyDown($event)',
    '(blur)': 'onBlur()',
    '(focus)': 'onFocus()',
    '(mouseleave)': 'onMouseOut()',
};
class ListBaseComponent {
    $options = contentChildren((OptionComponent));
    elementRef = inject(ElementRef);
    // #region Inputs
    $isMultiSelect() {
        return false;
    }
    /**
     * Sets the focusability of the list
     * @remarks
     * - 'strong' - The list can be focused and navigated using the keyboard. Focus indicators are shown and are strong (primary color).
     * - 'silent' - The list can be focused and navigated using the keyboard. Focus indicators are shown, but are subtle .
     * - 'none' - The list cannot be focused or navigated using the keyboard.
     * @default 'full'
     */
    $focusMode = model('strong', {
        alias: 'focusMode',
    });
    /**
     * Whether the list is disabled
     * @remarks
     * Set this using the FormControl if you are using reactive forms.
     * Only set this manually if you are not using reactive forms.
     *
     * @default false
     */
    $disabled = model(false, {
        alias: 'disabled',
    });
    /**
     * The currently selected value.
     * @remarks
     * If allowMultiple is true, this should be an array of values.
     * If allowMultiple is false, this should be a single value.
     */
    $value = model(undefined, {
        alias: 'value',
    });
    /**
     * The location of the check icon in dropdown option if an option is selected
     * @default 'none'
     */
    $selectedCheckIconLocation = model('none', {
        alias: 'selectedCheckIconLocation',
    });
    /**
     * Highlight the selected item(s) with a primary back color
     * @default true
     */
    $selectedItemHighlight = model(true, {
        alias: 'selectedItemHighlight',
    });
    /**
     * Whether multiple values can be selected
     * @default false
     */
    /**
     * The template context to use for the dropdown options
     * @remarks
     * Use this to display the 'icon', 'text', and 'hint' properties of the options conditionally
     */
    $itemTemplateContext = model({
        renderIcon: true,
        renderText: true,
        renderHint: true,
    }, {
        alias: 'itemTemplateContext',
    });
    // #endregion
    $itemTemplateActualContext = computed(() => {
        return {
            renderIcon: this.$itemTemplateContext().renderIcon,
            renderText: this.$itemTemplateContext().renderText,
            renderHint: this.$itemTemplateContext().renderHint,
            renderAsDisabled: this.$itemTemplateContext().renderAsDisabled ?? this.$disabled(),
        };
    });
    // #region ControlValueAccessor
    // eslint-disable-next-line @typescript-eslint/no-empty-function, @typescript-eslint/no-unused-vars
    onChange = (value) => { };
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    onTouched = () => { };
    writeValue(value) {
        this.$value.set(value);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.$disabled.set(isDisabled);
    }
    // #endregion
    // #region Value selection
    // nullable Signal type needs to be set explicitly -> ng-packagr strips nullability
    $highlightedOption = signal(undefined);
    selectValue(option, event) {
        event.preventDefault();
        event.stopPropagation();
        if (!this.$disabled() && !option.$disabled()) {
            const value = this.$value();
            const optionValue = option.$value();
            this.selectValueInternal(value, optionValue);
            this.onChange(this.$value());
            this.onTouched();
            if (this.elementRef.nativeElement.tabIndex !== -1) {
                this.elementRef.nativeElement.focus();
            }
        }
    }
    clearValue(e) {
        e.preventDefault();
        e.stopPropagation();
        if (this.$disabled()) {
            return;
        }
        this.clearValueInternal();
        this.onChange(this.$value());
        this.onTouched();
    }
    // #region Focus management
    $focused = signal(false);
    onFocus() {
        this.$focused.set(true);
    }
    onBlur() {
        this.$focused.set(false);
        this.$highlightedOption.set(undefined);
    }
    onMouseOut() {
        this.$highlightedOption.set(undefined);
    }
    /**
     *
     *
     * @param e Handles KeyDown event for:
     * - host element
     * - global keydown event when dropdown is open
     * @returns
     */
    onKeyDown(e) {
        if (e.key === 'Enter' || e.key === ' ') {
            if (this.$highlightedOption()) {
                this.selectValue(this.$highlightedOption(), new MouseEvent('click'));
            }
            e.preventDefault();
            e.stopPropagation();
        }
        if (e.key === 'ArrowUp' || e.key === 'ArrowDown') {
            // - we find the currently HIGHLIGHTED option
            // - we find the next option to highlight
            // - if no option is found, we highlight the first/last option
            let currentIndex;
            let nextIndex = -1;
            if (this.$highlightedOption()) {
                currentIndex = this.$options().findIndex((o) => o.$value() === this.$highlightedOption().$value());
            }
            else {
                // find already selected option
                const value = this.$value();
                let val;
                if (e.key === 'ArrowDown') {
                    // find the last selected option
                    if (this.$isMultiSelect()) {
                        if (value != null && Array.isArray(value) && value.length > 0) {
                            val = value[value.length - 1];
                        }
                    }
                    else {
                        if (value !== undefined && !Array.isArray(value)) {
                            val = value;
                        }
                    }
                }
                else {
                    // find the first selected option
                    if (this.$isMultiSelect()) {
                        if (value != null && Array.isArray(value) && value.length > 0) {
                            val = value[0];
                        }
                    }
                    else {
                        if (value !== undefined && !Array.isArray(value)) {
                            val = value;
                        }
                    }
                }
                nextIndex = currentIndex = this.$options().findIndex((o) => o.$value() === val);
            }
            if (nextIndex === -1) {
                // find the next index to highlight/select
                if (e.key === 'ArrowDown') {
                    if (currentIndex === -1) {
                        // find the first non disabled option
                        nextIndex = this.$options().findIndex((o) => !o.$disabled());
                    }
                    else {
                        // find the next option that is not disabled
                        nextIndex = this.$options().findIndex((o, i) => i > currentIndex && !o.$disabled());
                        // if no option is found, find the next option that is not disabled before the current item
                        if (nextIndex === -1) {
                            nextIndex = this.$options().findIndex((o, i) => i < currentIndex && !o.$disabled());
                        }
                    }
                }
                else if (e.key === 'ArrowUp') {
                    if (currentIndex === -1) {
                        // find the last non disabled option
                        nextIndex = this.$options()
                            .slice()
                            .reverse()
                            .findIndex((o) => !o.$disabled());
                        if (nextIndex !== -1) {
                            nextIndex = this.$options().length - nextIndex - 1;
                        }
                    }
                    else {
                        const flippedCurrentIndex = this.$options().length - currentIndex - 1;
                        // find the next option that is not disabled
                        nextIndex = [...this.$options()].reverse().findIndex((o, i) => i > flippedCurrentIndex && !o.$disabled());
                        // if no option is found, find the next option that is not disabled before the current item
                        if (nextIndex === -1) {
                            nextIndex = [...this.$options()].reverse().findIndex((o, i) => i < flippedCurrentIndex && !o.$disabled());
                        }
                        if (nextIndex !== -1) {
                            nextIndex = this.$options().length - nextIndex - 1;
                        }
                    }
                }
            }
            if (nextIndex !== -1) {
                this.$highlightedOption.set(this.$options()[nextIndex]);
                setTimeout(() => this.elementRef.nativeElement.querySelector(`.option-wrapper.highlight`)?.scrollIntoView({
                    block: 'nearest',
                }), 10);
            }
            e.preventDefault();
            e.stopPropagation();
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ListBaseComponent, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.2.0", version: "20.0.3", type: ListBaseComponent, isStandalone: true, inputs: { $focusMode: { classPropertyName: "$focusMode", publicName: "focusMode", isSignal: true, isRequired: false, transformFunction: null }, $disabled: { classPropertyName: "$disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, $value: { classPropertyName: "$value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, $selectedCheckIconLocation: { classPropertyName: "$selectedCheckIconLocation", publicName: "selectedCheckIconLocation", isSignal: true, isRequired: false, transformFunction: null }, $selectedItemHighlight: { classPropertyName: "$selectedItemHighlight", publicName: "selectedItemHighlight", isSignal: true, isRequired: false, transformFunction: null }, $itemTemplateContext: { classPropertyName: "$itemTemplateContext", publicName: "itemTemplateContext", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { $focusMode: "focusModeChange", $disabled: "disabledChange", $value: "valueChange", $selectedCheckIconLocation: "selectedCheckIconLocationChange", $selectedItemHighlight: "selectedItemHighlightChange", $itemTemplateContext: "itemTemplateContextChange" }, queries: [{ propertyName: "$options", predicate: (OptionComponent), isSignal: true }], ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ListBaseComponent, decorators: [{
            type: Directive
        }] });

class ListSingleSelectComponent extends ListBaseComponent {
    selectValueInternal = (currentValue, selectedValue) => {
        this.$value.set(selectedValue);
    };
    clearValueInternal = () => {
        this.$value.set(undefined);
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ListSingleSelectComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: ListSingleSelectComponent, isStandalone: false, selector: "tab-list-single-select", host: { listeners: { "keydown": "onKeyDown($event)", "blur": "onBlur()", "focus": "onFocus()", "mouseleave": "onMouseOut()" }, properties: { "class.silent-focus": "$focusMode() === \"silent\"", "tabindex": "$disabled() || $focusMode() === \"none\" ? -1 : 0" }, classAttribute: "tab-input" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => ListSingleSelectComponent),
                multi: true,
            },
        ], usesInheritance: true, ngImport: i0, template: "@for (option of $options(); track option.$value()) {\n    <!-- eslint-disable-next-line  @angular-eslint/template/interactive-supports-focus, @angular-eslint/template/click-events-have-key-events -->\n    <div\n        class=\"option-wrapper\"\n        [class.disabled]=\"option.$disabled() || $disabled()\"\n        [class.highlight]=\"!!$highlightedOption() && $highlightedOption()!.$value() === option.$value()\"\n        [class.selected]=\"($value() | isValueSelected: option.$value() : $isMultiSelect()) && $selectedItemHighlight()\"\n        (click)=\"selectValue(option, $event)\"\n        (mouseenter)=\"$highlightedOption.set(option)\"\n    >\n        <div class=\"check\" [ngClass]=\"$selectedCheckIconLocation()\">\n            @if ($value() | isValueSelected: option.$value() : $isMultiSelect()) {\n                <tab-icon value=\"check\" />\n            }\n        </div>\n        <div class=\"option-content\">\n            <ng-container [ngTemplateOutlet]=\"option.$template()\" [ngTemplateOutletContext]=\"$itemTemplateActualContext()\" />\n        </div>\n    </div>\n}\n", styles: [":host{background:var(--twc-color-base);border-color:var(--twc-color-border-light);border-radius:var(--twc-menu-border-radius);border-style:solid;border-width:1px;color:var(--twc-color-text);line-height:normal;overflow:hidden auto;-webkit-user-select:none;user-select:none;padding:.5rem;pointer-events:none;height:100%}:host.silent-focus{outline-color:var(--twc-color-border-light)}:host .option-wrapper{pointer-events:auto;display:grid;grid-template-columns:auto 1fr auto;align-items:center;border-radius:2px;padding-left:.5em;padding-right:.5em;border:1px solid transparent;margin-top:-1px}:host .option-wrapper .check{font-size:1.2em;width:1.2em;line-height:1;grid-row:1}:host .option-wrapper .check.left{grid-column:1;margin-right:.25em}:host .option-wrapper .check.right{grid-column:3;margin-left:.25em}:host .option-wrapper .check.none{display:none}:host .option-wrapper .option-content{grid-row:1;grid-column:2;padding:.25em 0}:host .option-wrapper:not(.disabled).highlight{background-color:var(--twc-color-highlight);cursor:pointer}:host .option-wrapper:not(.disabled).highlight:not(.selected){outline:var(--twc-menu-highlight-outline);outline-offset:var(--twc-menu-highlight-outline-offset)}:host .option-wrapper:not(.disabled).highlight.selected{outline-width:2px}:host .option-wrapper.selected{background-color:var(--twc-menu-selected-background-color);outline:var(--twc-menu-selected-outline);outline-offset:var(--twc-menu-selected-outline-offset)}:host .option-wrapper ::ng-deep .tab-option{line-height:normal}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.IconComponent, selector: "tab-icon", inputs: ["value", "color", "type", "fill", "weight", "grade", "opticalSizePx"] }, { kind: "pipe", type: IsValueSelectedPipe, name: "isValueSelected" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ListSingleSelectComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-list-single-select', standalone: false, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => ListSingleSelectComponent),
                            multi: true,
                        },
                    ], changeDetection: ChangeDetectionStrategy.OnPush, host: LIST_COMPONENT_HOST, template: "@for (option of $options(); track option.$value()) {\n    <!-- eslint-disable-next-line  @angular-eslint/template/interactive-supports-focus, @angular-eslint/template/click-events-have-key-events -->\n    <div\n        class=\"option-wrapper\"\n        [class.disabled]=\"option.$disabled() || $disabled()\"\n        [class.highlight]=\"!!$highlightedOption() && $highlightedOption()!.$value() === option.$value()\"\n        [class.selected]=\"($value() | isValueSelected: option.$value() : $isMultiSelect()) && $selectedItemHighlight()\"\n        (click)=\"selectValue(option, $event)\"\n        (mouseenter)=\"$highlightedOption.set(option)\"\n    >\n        <div class=\"check\" [ngClass]=\"$selectedCheckIconLocation()\">\n            @if ($value() | isValueSelected: option.$value() : $isMultiSelect()) {\n                <tab-icon value=\"check\" />\n            }\n        </div>\n        <div class=\"option-content\">\n            <ng-container [ngTemplateOutlet]=\"option.$template()\" [ngTemplateOutletContext]=\"$itemTemplateActualContext()\" />\n        </div>\n    </div>\n}\n", styles: [":host{background:var(--twc-color-base);border-color:var(--twc-color-border-light);border-radius:var(--twc-menu-border-radius);border-style:solid;border-width:1px;color:var(--twc-color-text);line-height:normal;overflow:hidden auto;-webkit-user-select:none;user-select:none;padding:.5rem;pointer-events:none;height:100%}:host.silent-focus{outline-color:var(--twc-color-border-light)}:host .option-wrapper{pointer-events:auto;display:grid;grid-template-columns:auto 1fr auto;align-items:center;border-radius:2px;padding-left:.5em;padding-right:.5em;border:1px solid transparent;margin-top:-1px}:host .option-wrapper .check{font-size:1.2em;width:1.2em;line-height:1;grid-row:1}:host .option-wrapper .check.left{grid-column:1;margin-right:.25em}:host .option-wrapper .check.right{grid-column:3;margin-left:.25em}:host .option-wrapper .check.none{display:none}:host .option-wrapper .option-content{grid-row:1;grid-column:2;padding:.25em 0}:host .option-wrapper:not(.disabled).highlight{background-color:var(--twc-color-highlight);cursor:pointer}:host .option-wrapper:not(.disabled).highlight:not(.selected){outline:var(--twc-menu-highlight-outline);outline-offset:var(--twc-menu-highlight-outline-offset)}:host .option-wrapper:not(.disabled).highlight.selected{outline-width:2px}:host .option-wrapper.selected{background-color:var(--twc-menu-selected-background-color);outline:var(--twc-menu-selected-outline);outline-offset:var(--twc-menu-selected-outline-offset)}:host .option-wrapper ::ng-deep .tab-option{line-height:normal}\n"] }]
        }] });

class ListMultiSelectComponent extends ListBaseComponent {
    $isMultiSelect() {
        return true;
    }
    selectValueInternal = (currentValue, selectedValue) => {
        if (currentValue === undefined || !Array.isArray(currentValue)) {
            this.$value.set([selectedValue]);
        }
        else if (!currentValue.includes(selectedValue)) {
            this.$value.set([...currentValue, selectedValue]);
        }
        else {
            this.$value.set(currentValue.filter((e) => e !== selectedValue));
        }
    };
    clearValueInternal = () => {
        this.$value.set([]);
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ListMultiSelectComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: ListMultiSelectComponent, isStandalone: false, selector: "tab-list-multi-select", host: { listeners: { "keydown": "onKeyDown($event)", "blur": "onBlur()", "focus": "onFocus()", "mouseleave": "onMouseOut()" }, properties: { "class.silent-focus": "$focusMode() === \"silent\"", "tabindex": "$disabled() || $focusMode() === \"none\" ? -1 : 0" }, classAttribute: "tab-input" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => ListMultiSelectComponent),
                multi: true,
            },
        ], usesInheritance: true, ngImport: i0, template: "@for (option of $options(); track option.$value()) {\n    <!-- eslint-disable-next-line  @angular-eslint/template/interactive-supports-focus, @angular-eslint/template/click-events-have-key-events -->\n    <div\n        class=\"option-wrapper\"\n        [class.disabled]=\"option.$disabled() || $disabled()\"\n        [class.highlight]=\"!!$highlightedOption() && $highlightedOption()!.$value() === option.$value()\"\n        [class.selected]=\"($value() | isValueSelected: option.$value() : $isMultiSelect()) && $selectedItemHighlight()\"\n        (click)=\"selectValue(option, $event)\"\n        (mouseenter)=\"$highlightedOption.set(option)\"\n    >\n        <div class=\"check\" [ngClass]=\"$selectedCheckIconLocation()\">\n            @if ($value() | isValueSelected: option.$value() : $isMultiSelect()) {\n                <tab-icon value=\"check\" />\n            }\n        </div>\n        <div class=\"option-content\">\n            <ng-container [ngTemplateOutlet]=\"option.$template()\" [ngTemplateOutletContext]=\"$itemTemplateActualContext()\" />\n        </div>\n    </div>\n}\n", styles: [":host{background:var(--twc-color-base);border-color:var(--twc-color-border-light);border-radius:var(--twc-menu-border-radius);border-style:solid;border-width:1px;color:var(--twc-color-text);line-height:normal;overflow:hidden auto;-webkit-user-select:none;user-select:none;padding:.5rem;pointer-events:none;height:100%}:host.silent-focus{outline-color:var(--twc-color-border-light)}:host .option-wrapper{pointer-events:auto;display:grid;grid-template-columns:auto 1fr auto;align-items:center;border-radius:2px;padding-left:.5em;padding-right:.5em;border:1px solid transparent;margin-top:-1px}:host .option-wrapper .check{font-size:1.2em;width:1.2em;line-height:1;grid-row:1}:host .option-wrapper .check.left{grid-column:1;margin-right:.25em}:host .option-wrapper .check.right{grid-column:3;margin-left:.25em}:host .option-wrapper .check.none{display:none}:host .option-wrapper .option-content{grid-row:1;grid-column:2;padding:.25em 0}:host .option-wrapper:not(.disabled).highlight{background-color:var(--twc-color-highlight);cursor:pointer}:host .option-wrapper:not(.disabled).highlight:not(.selected){outline:var(--twc-menu-highlight-outline);outline-offset:var(--twc-menu-highlight-outline-offset)}:host .option-wrapper:not(.disabled).highlight.selected{outline-width:2px}:host .option-wrapper.selected{background-color:var(--twc-menu-selected-background-color);outline:var(--twc-menu-selected-outline);outline-offset:var(--twc-menu-selected-outline-offset)}:host .option-wrapper ::ng-deep .tab-option{line-height:normal}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.IconComponent, selector: "tab-icon", inputs: ["value", "color", "type", "fill", "weight", "grade", "opticalSizePx"] }, { kind: "pipe", type: IsValueSelectedPipe, name: "isValueSelected" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ListMultiSelectComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-list-multi-select', standalone: false, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => ListMultiSelectComponent),
                            multi: true,
                        },
                    ], changeDetection: ChangeDetectionStrategy.OnPush, host: LIST_COMPONENT_HOST, template: "@for (option of $options(); track option.$value()) {\n    <!-- eslint-disable-next-line  @angular-eslint/template/interactive-supports-focus, @angular-eslint/template/click-events-have-key-events -->\n    <div\n        class=\"option-wrapper\"\n        [class.disabled]=\"option.$disabled() || $disabled()\"\n        [class.highlight]=\"!!$highlightedOption() && $highlightedOption()!.$value() === option.$value()\"\n        [class.selected]=\"($value() | isValueSelected: option.$value() : $isMultiSelect()) && $selectedItemHighlight()\"\n        (click)=\"selectValue(option, $event)\"\n        (mouseenter)=\"$highlightedOption.set(option)\"\n    >\n        <div class=\"check\" [ngClass]=\"$selectedCheckIconLocation()\">\n            @if ($value() | isValueSelected: option.$value() : $isMultiSelect()) {\n                <tab-icon value=\"check\" />\n            }\n        </div>\n        <div class=\"option-content\">\n            <ng-container [ngTemplateOutlet]=\"option.$template()\" [ngTemplateOutletContext]=\"$itemTemplateActualContext()\" />\n        </div>\n    </div>\n}\n", styles: [":host{background:var(--twc-color-base);border-color:var(--twc-color-border-light);border-radius:var(--twc-menu-border-radius);border-style:solid;border-width:1px;color:var(--twc-color-text);line-height:normal;overflow:hidden auto;-webkit-user-select:none;user-select:none;padding:.5rem;pointer-events:none;height:100%}:host.silent-focus{outline-color:var(--twc-color-border-light)}:host .option-wrapper{pointer-events:auto;display:grid;grid-template-columns:auto 1fr auto;align-items:center;border-radius:2px;padding-left:.5em;padding-right:.5em;border:1px solid transparent;margin-top:-1px}:host .option-wrapper .check{font-size:1.2em;width:1.2em;line-height:1;grid-row:1}:host .option-wrapper .check.left{grid-column:1;margin-right:.25em}:host .option-wrapper .check.right{grid-column:3;margin-left:.25em}:host .option-wrapper .check.none{display:none}:host .option-wrapper .option-content{grid-row:1;grid-column:2;padding:.25em 0}:host .option-wrapper:not(.disabled).highlight{background-color:var(--twc-color-highlight);cursor:pointer}:host .option-wrapper:not(.disabled).highlight:not(.selected){outline:var(--twc-menu-highlight-outline);outline-offset:var(--twc-menu-highlight-outline-offset)}:host .option-wrapper:not(.disabled).highlight.selected{outline-width:2px}:host .option-wrapper.selected{background-color:var(--twc-menu-selected-background-color);outline:var(--twc-menu-selected-outline);outline-offset:var(--twc-menu-selected-outline-offset)}:host .option-wrapper ::ng-deep .tab-option{line-height:normal}\n"] }]
        }] });

class TableauUiListModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiListModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiListModule, declarations: [IsValueSelectedPipe, ListSingleSelectComponent, ListMultiSelectComponent], imports: [CommonModule, TableauUiCommonModule, TableauUiIconModule], exports: [ListSingleSelectComponent, ListMultiSelectComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiListModule, imports: [CommonModule, TableauUiCommonModule, TableauUiIconModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiListModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, TableauUiCommonModule, TableauUiIconModule],
                    declarations: [IsValueSelectedPipe, ListSingleSelectComponent, ListMultiSelectComponent],
                    exports: [ListSingleSelectComponent, ListMultiSelectComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ListMultiSelectComponent, ListSingleSelectComponent, TableauUiListModule };
//# sourceMappingURL=tableau-ui-angular-list.mjs.map
