import * as i0 from '@angular/core';
import { signal, model, contentChildren, contentChild, forwardRef, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { OptionComponent, ErrorComponent, TableauUiCommonModule } from 'tableau-ui-angular/common';
import { generateRandomString } from 'tableau-ui-angular/utils';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';

class RadioGroupComponent {
    $disabled = signal(false);
    $value = model(undefined, {
        alias: 'value',
    });
    name = this.generateRandomGroupName();
    $options = contentChildren((OptionComponent));
    // nullable Signal type needs to be set explicitly -> ng-packagr strips nullability
    $errorElement = contentChild(ErrorComponent);
    // eslint-disable-next-line  @typescript-eslint/no-empty-function, @typescript-eslint/no-unused-vars
    onChange = (value) => { };
    // eslint-disable-next-line  @typescript-eslint/no-empty-function
    onTouched = () => { };
    writeValue(value) {
        this.$value.set(value);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.$disabled.set(isDisabled);
    }
    selectValue(option) {
        if (!this.$disabled() && !option.$disabled()) {
            if (this.$value() !== option.$value()) {
                this.$value.set(option.$value());
                this.onChange(this.$value());
            }
            this.onTouched();
        }
    }
    onKeyDown(e, option) {
        if (e.key === 'Enter' || e.key === ' ') {
            this.selectValue(option);
            e.preventDefault();
        }
    }
    generateRandomGroupName(length = 8) {
        return `group-${generateRandomString(length)}`;
    }
    optionTemplateContext = {
        renderIcon: true,
        renderText: true,
        renderHint: true,
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: RadioGroupComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: RadioGroupComponent, isStandalone: false, selector: "tab-radio-group", inputs: { $value: { classPropertyName: "$value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { $value: "valueChange" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => RadioGroupComponent),
                multi: true,
            },
        ], queries: [{ propertyName: "$options", predicate: (OptionComponent), isSignal: true }, { propertyName: "$errorElement", first: true, predicate: ErrorComponent, descendants: true, isSignal: true }], ngImport: i0, template: "<div class=\"options-grid\">\n    @for (option of $options(); track option.$value()) {\n        <!-- eslint-disable-next-line @angular-eslint/template/click-events-have-key-events, @angular-eslint/template/interactive-supports-focus -->\n        <label class=\"radio-option\" [class.disabled]=\"$disabled() || option.$disabled()\" [class.selected]=\"$value() === option.$value()\" (click)=\"selectValue(option)\">\n            <input\n                type=\"radio\"\n                [value]=\"option.$value()\"\n                [checked]=\"$value() === option.$value()\"\n                [tabindex]=\"$disabled() || option.$disabled() ? -1 : 0\"\n                [disabled]=\"$disabled() || option.$disabled()\"\n                [name]=\"name\"\n                (change)=\"selectValue(option)\"\n                (keydown)=\"onKeyDown($event, option)\"\n            />\n            <div class=\"box\">\n                @if ($value() === option.$value()) {\n                    <div class=\"filler\"></div>\n                }\n            </div>\n\n            <div class=\"label\">\n                <ng-container [ngTemplateOutlet]=\"option.$template()\" [ngTemplateOutletContext]=\"optionTemplateContext\" />\n            </div>\n        </label>\n    }\n\n    @if ($errorElement()) {\n        <div class=\"extra-info\">\n            <ng-content select=\"tab-error\" />\n        </div>\n    }\n</div>\n", styles: [".options-grid{gap:.5em;display:grid}.radio-option{box-sizing:border-box;color:var(--twc-color-text);display:grid;grid-template-columns:auto auto;grid-template-rows:auto;gap:.5em;width:fit-content;align-items:start}.radio-option .box{grid-column:1;grid-row:1;background-color:var(--twc-color-base);border:1px solid var(--twc-color-border-dark);box-sizing:border-box;width:1.2em;height:1.2em;border-radius:100%;display:grid;place-items:center center}.radio-option .box .filler{width:.7em;height:.7em;border-radius:100%;background-color:var(--twc-color-border-dark)}.radio-option input{grid-column:1;grid-row:1;box-sizing:border-box;width:1.2em;height:1.2em;min-height:0;background-color:initial;cursor:default;margin:0;opacity:0;padding:0;font-size:var(--twc-font-size-body)}.radio-option input:focus-visible+.box{outline:2px solid var(--twc-color-primary);outline-offset:2px}.radio-option .label{line-height:1.2;overflow:hidden;text-overflow:ellipsis;-webkit-user-select:none;user-select:none;grid-column:2;grid-row:1}@supports (width: round(1em,1px)){.radio-option input{width:round(1.2em,1px);height:round(1.2em,1px)}.radio-option .box{width:round(1.2em,2px);height:round(1.2em,2px)}.radio-option .box .filler{width:round(.7em,2px);height:round(.7em,2px)}}.radio-option:hover:not(.disabled) .box{background-color:var(--twc-color-mouse-highlight);border-color:var(--twc-color-border-dark)}.radio-option:active:not(.disabled) .box{background-color:var(--twc-color-border-dark-disabled);border-color:var(--twc-color-border-dark)}.radio-option:not(.disabled){cursor:pointer}.radio-option.disabled{color:var(--twc-color-disabled)}.radio-option.disabled .box{border-color:var(--twc-color-disabled)}.radio-option.disabled .box .filler{background-color:var(--twc-color-disabled)}.radio-option.disabled ::ng-deep .tab-hint{color:var(--twc-color-disabled)}.radio-option.disabled .label{color:var(--twc-color-disabled)}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: RadioGroupComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-radio-group', standalone: false, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => RadioGroupComponent),
                            multi: true,
                        },
                    ], changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"options-grid\">\n    @for (option of $options(); track option.$value()) {\n        <!-- eslint-disable-next-line @angular-eslint/template/click-events-have-key-events, @angular-eslint/template/interactive-supports-focus -->\n        <label class=\"radio-option\" [class.disabled]=\"$disabled() || option.$disabled()\" [class.selected]=\"$value() === option.$value()\" (click)=\"selectValue(option)\">\n            <input\n                type=\"radio\"\n                [value]=\"option.$value()\"\n                [checked]=\"$value() === option.$value()\"\n                [tabindex]=\"$disabled() || option.$disabled() ? -1 : 0\"\n                [disabled]=\"$disabled() || option.$disabled()\"\n                [name]=\"name\"\n                (change)=\"selectValue(option)\"\n                (keydown)=\"onKeyDown($event, option)\"\n            />\n            <div class=\"box\">\n                @if ($value() === option.$value()) {\n                    <div class=\"filler\"></div>\n                }\n            </div>\n\n            <div class=\"label\">\n                <ng-container [ngTemplateOutlet]=\"option.$template()\" [ngTemplateOutletContext]=\"optionTemplateContext\" />\n            </div>\n        </label>\n    }\n\n    @if ($errorElement()) {\n        <div class=\"extra-info\">\n            <ng-content select=\"tab-error\" />\n        </div>\n    }\n</div>\n", styles: [".options-grid{gap:.5em;display:grid}.radio-option{box-sizing:border-box;color:var(--twc-color-text);display:grid;grid-template-columns:auto auto;grid-template-rows:auto;gap:.5em;width:fit-content;align-items:start}.radio-option .box{grid-column:1;grid-row:1;background-color:var(--twc-color-base);border:1px solid var(--twc-color-border-dark);box-sizing:border-box;width:1.2em;height:1.2em;border-radius:100%;display:grid;place-items:center center}.radio-option .box .filler{width:.7em;height:.7em;border-radius:100%;background-color:var(--twc-color-border-dark)}.radio-option input{grid-column:1;grid-row:1;box-sizing:border-box;width:1.2em;height:1.2em;min-height:0;background-color:initial;cursor:default;margin:0;opacity:0;padding:0;font-size:var(--twc-font-size-body)}.radio-option input:focus-visible+.box{outline:2px solid var(--twc-color-primary);outline-offset:2px}.radio-option .label{line-height:1.2;overflow:hidden;text-overflow:ellipsis;-webkit-user-select:none;user-select:none;grid-column:2;grid-row:1}@supports (width: round(1em,1px)){.radio-option input{width:round(1.2em,1px);height:round(1.2em,1px)}.radio-option .box{width:round(1.2em,2px);height:round(1.2em,2px)}.radio-option .box .filler{width:round(.7em,2px);height:round(.7em,2px)}}.radio-option:hover:not(.disabled) .box{background-color:var(--twc-color-mouse-highlight);border-color:var(--twc-color-border-dark)}.radio-option:active:not(.disabled) .box{background-color:var(--twc-color-border-dark-disabled);border-color:var(--twc-color-border-dark)}.radio-option:not(.disabled){cursor:pointer}.radio-option.disabled{color:var(--twc-color-disabled)}.radio-option.disabled .box{border-color:var(--twc-color-disabled)}.radio-option.disabled .box .filler{background-color:var(--twc-color-disabled)}.radio-option.disabled ::ng-deep .tab-hint{color:var(--twc-color-disabled)}.radio-option.disabled .label{color:var(--twc-color-disabled)}\n"] }]
        }] });

class TableauUiRadioGroupModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiRadioGroupModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiRadioGroupModule, declarations: [RadioGroupComponent], imports: [CommonModule, TableauUiCommonModule], exports: [RadioGroupComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiRadioGroupModule, imports: [CommonModule, TableauUiCommonModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiRadioGroupModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, TableauUiCommonModule],
                    declarations: [RadioGroupComponent],
                    exports: [RadioGroupComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RadioGroupComponent, TableauUiRadioGroupModule };
//# sourceMappingURL=tableau-ui-angular-radio-group.mjs.map
