import * as i0 from '@angular/core';
import { InjectionToken, inject, ChangeDetectionStrategy, Component, Injector, ApplicationRef, EnvironmentInjector, createComponent, Injectable, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from 'tableau-ui-angular/icon';
import { TableauUiIconModule } from 'tableau-ui-angular/icon';
import * as i3 from '@angular/router';
import { RouterModule } from '@angular/router';

const TAB_SNACK_REF = new InjectionToken('TAB_SNACK_REF');
function injectSnackRef() {
    return inject(TAB_SNACK_REF);
}
class SnackRef {
    _closed$ = new Subject();
    closed$ = this._closed$.asObservable();
    _result = undefined;
    close(result) {
        this._closed$.next(result ?? this._result);
        this._closed$.complete();
    }
    /**
     * Sets the result of the dialog without closing it.
     * This is useful for cases where you want to update the result
     * but keep the dialog open, such as in a form submission.
     * If the close() function is called with a non-undefined result, it will overwrite this value
     * @param result The result to set.
     */
    setResultWithoutClosing(result) {
        this._result = result;
    }
}

const TAB_SNACK_DATA_REF = new InjectionToken('TAB_SANCK_DATA_REF');
function injectSnackData() {
    return inject(TAB_SNACK_DATA_REF);
}

class SnackComponent {
    data = inject(TAB_SNACK_DATA_REF);
    snackRef = injectSnackRef();
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: SnackComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: SnackComponent, isStandalone: false, selector: "tab-snack", ngImport: i0, template: `
        <div class="snack-content" [ngClass]="data.type">
            <div class="content">
                <tab-icon class="icon" [value]="data.type === 'success' ? 'check' : data.type" />
                @if (data.contentTemplate) {
                    <div>
                        <ng-container [ngTemplateOutlet]="data.contentTemplate!" [ngTemplateOutletContext]="data.contentTemplateContext" />
                    </div>
                } @else {
                    <div class="text">
                        {{ data.message }}
                        @if (data.actionLink && data.action) {
                            <a [routerLink]="[]" (click)="data.action(snackRef)">{{ data.actionLink }}</a>
                        }
                    </div>
                }

                <tab-icon class="close" tabindex="0" value="close" (click)="snackRef.close(true)" (keydown.enter)="snackRef.close(true)" (keydown.space)="snackRef.close(true)" />
            </div>
        </div>
    `, isInline: true, styles: [".snack-content{padding:10px 16px 10px 8px}.icon{font-size:1.5em}.info .icon{color:var(--twc-color-primary)}.error .icon{color:var(--twc-color-error)}.success .icon{color:var(--twc-color-success)}.content{display:flex;line-height:1.5}.content div{border-right:1px solid transparent;padding:0 8px}.content div.text{display:flex;align-items:center;gap:.5rem}.info .content div{border-color:#90d0fe}.error .content div{border-color:#ffa1a1}.success .content div{border-color:#93ce93}.close{font-size:1.5em;margin-left:.25em;color:var(--twc-color-border-dark);cursor:pointer}.close:hover{background-color:var(--twc-color-border-dark-disabled)}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.IconComponent, selector: "tab-icon", inputs: ["value", "color", "type", "fill", "weight", "grade", "opticalSizePx"] }, { kind: "directive", type: i3.RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: SnackComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-snack', standalone: false, template: `
        <div class="snack-content" [ngClass]="data.type">
            <div class="content">
                <tab-icon class="icon" [value]="data.type === 'success' ? 'check' : data.type" />
                @if (data.contentTemplate) {
                    <div>
                        <ng-container [ngTemplateOutlet]="data.contentTemplate!" [ngTemplateOutletContext]="data.contentTemplateContext" />
                    </div>
                } @else {
                    <div class="text">
                        {{ data.message }}
                        @if (data.actionLink && data.action) {
                            <a [routerLink]="[]" (click)="data.action(snackRef)">{{ data.actionLink }}</a>
                        }
                    </div>
                }

                <tab-icon class="close" tabindex="0" value="close" (click)="snackRef.close(true)" (keydown.enter)="snackRef.close(true)" (keydown.space)="snackRef.close(true)" />
            </div>
        </div>
    `, changeDetection: ChangeDetectionStrategy.OnPush, styles: [".snack-content{padding:10px 16px 10px 8px}.icon{font-size:1.5em}.info .icon{color:var(--twc-color-primary)}.error .icon{color:var(--twc-color-error)}.success .icon{color:var(--twc-color-success)}.content{display:flex;line-height:1.5}.content div{border-right:1px solid transparent;padding:0 8px}.content div.text{display:flex;align-items:center;gap:.5rem}.info .content div{border-color:#90d0fe}.error .content div{border-color:#ffa1a1}.success .content div{border-color:#93ce93}.close{font-size:1.5em;margin-left:.25em;color:var(--twc-color-border-dark);cursor:pointer}.close:hover{background-color:var(--twc-color-border-dark-disabled)}\n"] }]
        }] });

// Styles for the snack container are in _snack.service.scss in the styles folder
class SnackService {
    injector = inject(Injector);
    appRef = inject(ApplicationRef);
    environmentInjector = inject(EnvironmentInjector);
    openSnack(message, duration = 5000, type = 'info', location = 'top') {
        return this.openSnackComponent(SnackComponent, {
            type,
            message,
            contentTemplate: undefined,
            contentTemplateContext: undefined,
        }, duration, type, location);
    }
    openSnackWithAction(message, actionLabel, action, duration = 5000, type = 'info', location = 'top') {
        return this.openSnackComponent(SnackComponent, {
            type,
            message,
            actionLink: actionLabel,
            action: action,
            contentTemplate: undefined,
            contentTemplateContext: undefined,
        }, duration, type, location);
    }
    openSnackFromTemplate(template, templateContext, duration = 5000, type = 'info', location = 'top') {
        return this.openSnackComponent(SnackComponent, {
            type,
            message: undefined,
            contentTemplate: template,
            contentTemplateContext: templateContext,
        }, duration, type, location);
    }
    openSnackComponent(component, data, duration = 5000, type = 'info', location = 'top') {
        // check if snack container exists
        let container = document.querySelector(`.tab-snacks.${location} .snack-container`);
        if (!container) {
            const tabSnacks = document.createElement('div');
            tabSnacks.classList.add('tab-snacks', location);
            container = document.createElement('div');
            container.classList.add('snack-container');
            tabSnacks.appendChild(container);
            document.body.appendChild(tabSnacks);
        }
        // create the snack wrapper
        const snackWrapper = document.createElement('div');
        snackWrapper.classList.add('snack-wrapper', type);
        const snackRef = new SnackRef();
        // Create an injector that provides the SnackRef
        const injector = Injector.create({
            providers: [
                { provide: TAB_SNACK_REF, useValue: snackRef },
                { provide: TAB_SNACK_DATA_REF, useValue: data },
            ],
            parent: this.injector,
        });
        // Create the component view
        const componentView = this.createView(component, injector);
        // Attach component to the application
        this.appRef.attachView(componentView);
        const componentElement = componentView.rootNodes[0];
        snackWrapper.appendChild(componentElement);
        // add timer if needed
        let timer;
        if (duration > 0) {
            timer = document.createElement('div');
            timer.classList.add('timer');
            timer.style.transitionDuration = `${duration}ms`;
            snackWrapper.appendChild(timer);
        }
        if (location === 'top') {
            container.appendChild(snackWrapper);
        }
        else {
            container.insertBefore(snackWrapper, container.firstChild);
        }
        const getMargin = () => {
            const height = snackWrapper.offsetHeight + 3;
            if (location === 'top') {
                return `-${height}px 0 3px 0`;
            }
            else {
                return `3px 0 -${height}px 0`;
            }
        };
        snackWrapper.style.margin = getMargin();
        setTimeout(() => {
            if (timer) {
                timer.style.width = '0';
            }
            snackWrapper.style.transition = 'margin 200ms ease-in-out, opacity 200ms ease-in-out';
            if (location === 'top') {
                snackWrapper.style.marginTop = '0';
            }
            else {
                snackWrapper.style.marginBottom = '0';
            }
            snackWrapper.style.opacity = '1';
        }, 1);
        // Remove snack after duration
        if (duration > 0) {
            setTimeout(() => {
                snackRef.close(undefined);
            }, duration);
        }
        snackRef.closed$.subscribe(() => {
            snackWrapper.style.margin = getMargin();
            snackWrapper.style.opacity = '0';
            setTimeout(() => {
                snackWrapper.remove();
                this.appRef.detachView(componentView);
            }, 200);
        });
        return snackRef;
    }
    createView(component, injector) {
        const componentRef = createComponent(component, {
            environmentInjector: this.environmentInjector,
            elementInjector: injector,
        });
        return componentRef.hostView;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: SnackService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: SnackService, providedIn: 'any' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: SnackService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'any', // new instance for each injection -> also lazy loaded
                }]
        }] });

class TableauUiSnackModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiSnackModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiSnackModule, declarations: [SnackComponent], imports: [CommonModule, TableauUiIconModule, RouterModule] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiSnackModule, providers: [SnackService], imports: [CommonModule, TableauUiIconModule, RouterModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiSnackModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, TableauUiIconModule, RouterModule],
                    declarations: [SnackComponent],
                    providers: [SnackService],
                    exports: [],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { SnackRef, SnackService, TableauUiSnackModule, injectSnackData, injectSnackRef };
//# sourceMappingURL=tableau-ui-angular-snack.mjs.map
