import * as i0 from '@angular/core';
import { viewChild, input, output, ChangeDetectionStrategy, Component, contentChildren, viewChildren, signal, computed, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from 'tableau-ui-angular/arrow-scroll';
import { TableauUiArrowScrollModule } from 'tableau-ui-angular/arrow-scroll';
import * as i3 from 'tableau-ui-angular/icon';
import { TableauUiIconModule } from 'tableau-ui-angular/icon';

class TabComponent {
    $headerTemplate = viewChild.required('headerTemplate');
    $contentTemplate = viewChild.required('contentTemplate');
    $disabled = input(false, {
        alias: 'disabled',
    });
    afterActivate = output();
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TabComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.2.0", version: "20.0.3", type: TabComponent, isStandalone: false, selector: "tab", inputs: { $disabled: { classPropertyName: "$disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { afterActivate: "afterActivate" }, viewQueries: [{ propertyName: "$headerTemplate", first: true, predicate: ["headerTemplate"], descendants: true, isSignal: true }, { propertyName: "$contentTemplate", first: true, predicate: ["contentTemplate"], descendants: true, isSignal: true }], ngImport: i0, template: `
        <ng-template #headerTemplate>
            <ng-content select="[tab-header]" />
        </ng-template>
        <ng-template #contentTemplate>
            <ng-content />
        </ng-template>
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TabComponent, decorators: [{
            type: Component,
            args: [{
                    // eslint-disable-next-line @angular-eslint/component-selector
                    selector: 'tab',
                    standalone: false,
                    template: `
        <ng-template #headerTemplate>
            <ng-content select="[tab-header]" />
        </ng-template>
        <ng-template #contentTemplate>
            <ng-content />
        </ng-template>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                }]
        }] });

class TabGroupComponent {
    /**
     * Padding for the tab header, can be adjusted to fit design requirements.
     * @default '0.25rem 1.5rem'
     */
    $headerPadding = input('0.25rem 1.5rem', {
        alias: 'headerPadding',
    });
    /**
     * Size of the scroll arrows icon, can be adjusted to fit design requirements.
     * @default '1.5rem'
     */
    $scrollArrowsIconSize = input('1.5rem', {
        alias: 'scrollArrowsIconSize',
    });
    $tabs = contentChildren(TabComponent);
    $tabElements = viewChildren('tab');
    // Signals to manage the selected index
    $_selectedIndex = signal(0);
    get $selectedIndex() {
        return this.$_selectedIndex;
    }
    // nullable Signal type needs to be set explicitly -> ng-packagr strips nullability
    $selectedTab = computed(() => this.$tabs()[this.$selectedIndex()] ?? null);
    selectTab(index) {
        const tabs = this.$tabs();
        const tab = tabs[index];
        if (tab.$disabled()) {
            return;
        }
        this.$_selectedIndex.set(index);
        const tabElement = this.$tabElements()[index];
        tabElement.nativeElement.scrollIntoView({ behavior: 'smooth', block: 'nearest' });
        tab.afterActivate.emit();
    }
    ngAfterViewInit() {
        // Ensure the first tab is selected by default if available
        const firstNonDisabledTabIndex = this.$tabs().findIndex((tab) => !tab.$disabled());
        if (firstNonDisabledTabIndex !== -1) {
            this.selectTab(firstNonDisabledTabIndex);
        }
    }
    onkeydown(index, e) {
        switch (e.key) {
            case 'Enter':
            case ' ':
                this.selectTab(index);
                e.preventDefault();
                break;
            default:
                return;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TabGroupComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: TabGroupComponent, isStandalone: false, selector: "tab-group", inputs: { $headerPadding: { classPropertyName: "$headerPadding", publicName: "headerPadding", isSignal: true, isRequired: false, transformFunction: null }, $scrollArrowsIconSize: { classPropertyName: "$scrollArrowsIconSize", publicName: "scrollArrowsIconSize", isSignal: true, isRequired: false, transformFunction: null } }, queries: [{ propertyName: "$tabs", predicate: TabComponent, isSignal: true }], viewQueries: [{ propertyName: "$tabElements", predicate: ["tab"], descendants: true, isSignal: true }], ngImport: i0, template: "<tab-arrow-scroll scrollType=\"arrow\" scrollDirection=\"horizontal\" buttonsCssColor=\"var(--twc-color-text-light)\">\n    <tab-icon back-button value=\"keyboard_arrow_left\" [style.fontSize]=\"$scrollArrowsIconSize()\" />\n    <tab-icon forward-button value=\"keyboard_arrow_right\" [style.fontSize]=\"$scrollArrowsIconSize()\" />\n    <div class=\"tab-headers-container\">\n        <div class=\"tab-headers\">\n            @for (tab of $tabs(); let i = $index; track i) {\n                <div\n                    #tab\n                    class=\"tab\"\n                    [class.active]=\"$selectedIndex() === i\"\n                    [class.disabled]=\"tab.$disabled()\"\n                    [tabindex]=\"tab.$disabled() ? -1 : 0\"\n                    [style.padding]=\"$headerPadding()\"\n                    (click)=\"selectTab(i)\"\n                    (keydown)=\"onkeydown(i, $event)\"\n                >\n                    <div class=\"tab-header\">\n                        <ng-container *ngTemplateOutlet=\"tab.$headerTemplate()\" />\n                    </div>\n                </div>\n            }\n        </div>\n    </div>\n</tab-arrow-scroll>\n<div class=\"tab-headers-underline\"></div>\n@for (tab of $tabs(); let i = $index; track i) {\n    <div class=\"tab-content\" [style.display]=\"$selectedIndex() === i ? 'block' : 'none'\">\n        <ng-container *ngTemplateOutlet=\"tab.$contentTemplate()\" />\n    </div>\n}\n", styles: [":host{display:grid;grid-template-rows:auto auto 1fr;overflow:auto}:host tab-arrow-scroll{width:100%}:host .tab-headers{display:flex;flex-direction:row;width:fit-content}:host .tab-headers .tab{align-items:center;display:flex;height:100%;justify-content:center;border-bottom:solid 3px var(--twc-color-border-light);-webkit-user-select:none;user-select:none;z-index:1}:host .tab-headers .tab:focus-visible{border:3px solid var(--twc-color-primary);outline:none}:host .tab-headers .tab.disabled{color:var(--twc-color-disabled);cursor:not-allowed}:host .tab-headers .tab:hover:not(.disabled){border-bottom:solid 3px var(--twc-tab-color-active-underline);background-color:var(--twc-color-highlight)}:host .tab-headers .tab.active{border-bottom:solid 3px var(--twc-tab-color-active-underline);font-weight:700}:host .tab-headers .tab .tab-header{align-items:flex-end;box-sizing:border-box;display:flex;flex-direction:row;justify-content:flex-start;text-wrap:nowrap}:host .tab-content{overflow:auto}:host .tab-headers-underline{margin-top:-3px;border-bottom:solid 3px var(--twc-tab-color-inactive-underline)}[back-button],[forward-button]{font-size:1.5rem}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.ArrowScrollComponent, selector: "tab-arrow-scroll", inputs: ["scrollType", "scrollDirection", "buttonsGap", "buttonsColor", "buttonsCssColor", "buttonScrollAmount", "showScrollButtonSeparator"] }, { kind: "component", type: i3.IconComponent, selector: "tab-icon", inputs: ["value", "color", "type", "fill", "weight", "grade", "opticalSizePx"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TabGroupComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-group', standalone: false, changeDetection: ChangeDetectionStrategy.OnPush, host: {}, template: "<tab-arrow-scroll scrollType=\"arrow\" scrollDirection=\"horizontal\" buttonsCssColor=\"var(--twc-color-text-light)\">\n    <tab-icon back-button value=\"keyboard_arrow_left\" [style.fontSize]=\"$scrollArrowsIconSize()\" />\n    <tab-icon forward-button value=\"keyboard_arrow_right\" [style.fontSize]=\"$scrollArrowsIconSize()\" />\n    <div class=\"tab-headers-container\">\n        <div class=\"tab-headers\">\n            @for (tab of $tabs(); let i = $index; track i) {\n                <div\n                    #tab\n                    class=\"tab\"\n                    [class.active]=\"$selectedIndex() === i\"\n                    [class.disabled]=\"tab.$disabled()\"\n                    [tabindex]=\"tab.$disabled() ? -1 : 0\"\n                    [style.padding]=\"$headerPadding()\"\n                    (click)=\"selectTab(i)\"\n                    (keydown)=\"onkeydown(i, $event)\"\n                >\n                    <div class=\"tab-header\">\n                        <ng-container *ngTemplateOutlet=\"tab.$headerTemplate()\" />\n                    </div>\n                </div>\n            }\n        </div>\n    </div>\n</tab-arrow-scroll>\n<div class=\"tab-headers-underline\"></div>\n@for (tab of $tabs(); let i = $index; track i) {\n    <div class=\"tab-content\" [style.display]=\"$selectedIndex() === i ? 'block' : 'none'\">\n        <ng-container *ngTemplateOutlet=\"tab.$contentTemplate()\" />\n    </div>\n}\n", styles: [":host{display:grid;grid-template-rows:auto auto 1fr;overflow:auto}:host tab-arrow-scroll{width:100%}:host .tab-headers{display:flex;flex-direction:row;width:fit-content}:host .tab-headers .tab{align-items:center;display:flex;height:100%;justify-content:center;border-bottom:solid 3px var(--twc-color-border-light);-webkit-user-select:none;user-select:none;z-index:1}:host .tab-headers .tab:focus-visible{border:3px solid var(--twc-color-primary);outline:none}:host .tab-headers .tab.disabled{color:var(--twc-color-disabled);cursor:not-allowed}:host .tab-headers .tab:hover:not(.disabled){border-bottom:solid 3px var(--twc-tab-color-active-underline);background-color:var(--twc-color-highlight)}:host .tab-headers .tab.active{border-bottom:solid 3px var(--twc-tab-color-active-underline);font-weight:700}:host .tab-headers .tab .tab-header{align-items:flex-end;box-sizing:border-box;display:flex;flex-direction:row;justify-content:flex-start;text-wrap:nowrap}:host .tab-content{overflow:auto}:host .tab-headers-underline{margin-top:-3px;border-bottom:solid 3px var(--twc-tab-color-inactive-underline)}[back-button],[forward-button]{font-size:1.5rem}\n"] }]
        }] });

class TableauUiTabgroupModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiTabgroupModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiTabgroupModule, declarations: [TabComponent, TabGroupComponent], imports: [CommonModule, TableauUiArrowScrollModule, TableauUiIconModule], exports: [TabComponent, TabGroupComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiTabgroupModule, imports: [CommonModule, TableauUiArrowScrollModule, TableauUiIconModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiTabgroupModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, TableauUiArrowScrollModule, TableauUiIconModule],
                    declarations: [TabComponent, TabGroupComponent],
                    exports: [TabComponent, TabGroupComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { TabComponent, TabGroupComponent, TableauUiTabgroupModule };
//# sourceMappingURL=tableau-ui-angular-tab-group.mjs.map
