import * as i0 from '@angular/core';
import { input, inject, TemplateRef, Directive, contentChild, ElementRef, signal, computed, Renderer2, HostListener, Pipe, model, contentChildren, viewChildren, ChangeDetectorRef, viewChild, effect, untracked, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import { BehaviorSubject, of, map } from 'rxjs';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from 'tableau-ui-angular/icon';
import { TableauUiIconModule } from 'tableau-ui-angular/icon';
import * as i3 from 'tableau-ui-angular/button';
import { TableauUiButtonModule } from 'tableau-ui-angular/button';
import * as i4 from 'tableau-ui-angular/tooltip';
import { TableauUiTooltipModule } from 'tableau-ui-angular/tooltip';
import * as i5 from 'tableau-ui-angular/checkbox';
import { TableauUiCheckboxModule } from 'tableau-ui-angular/checkbox';

class CellDefDirective {
    table = input.required({
        alias: 'tabCellDef',
    });
    /**
     * When true, it will clamp the text content in the template to fit the cell height.
     * It will add an ellipsis (...) to the end of the text if it overflows.
     * This is useful for preventing overflow in table cells.
     * This will clamp to the maximum number of lines that can fit in the cell, respecting the height and padding of the cell.
     * It will also show a default tooltip with the full value of the cell uinless its turned off.
     * Only works if the cell template ONLY contains text, no HTML elements.
     * @default true
     */
    $textClamping = input(true, {
        alias: 'textClamping',
    });
    templateRef = inject((TemplateRef));
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellDefDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.3", type: CellDefDirective, isStandalone: false, selector: "[tabCellDef]", inputs: { table: { classPropertyName: "table", publicName: "tabCellDef", isSignal: true, isRequired: true, transformFunction: null }, $textClamping: { classPropertyName: "$textClamping", publicName: "textClamping", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellDefDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tabCellDef]',
                    standalone: false,
                }]
        }] });

class HeaderDefDirective {
    table = input.required({
        alias: 'tabHeaderDef',
    });
    templateRef = inject((TemplateRef));
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderDefDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.3", type: HeaderDefDirective, isStandalone: false, selector: "[tabHeaderDef]", inputs: { table: { classPropertyName: "table", publicName: "tabHeaderDef", isSignal: true, isRequired: true, transformFunction: null } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderDefDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tabHeaderDef]',
                    standalone: false,
                }]
        }] });

class HeaderToolipDefDirective {
    table = input.required({
        alias: 'tabHeaderTooltipDef',
    });
    $showTooltip = input(true, {
        alias: 'showTooltip',
    });
    $tooltipPosition = input('top', {
        alias: 'tooltipPosition',
    });
    $tooltipMargin = input('0px', {
        alias: 'tooltipMargin',
    });
    templateRef = inject((TemplateRef));
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderToolipDefDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.3", type: HeaderToolipDefDirective, isStandalone: false, selector: "[tabHeaderTooltipDef]", inputs: { table: { classPropertyName: "table", publicName: "tabHeaderTooltipDef", isSignal: true, isRequired: true, transformFunction: null }, $showTooltip: { classPropertyName: "$showTooltip", publicName: "showTooltip", isSignal: true, isRequired: false, transformFunction: null }, $tooltipPosition: { classPropertyName: "$tooltipPosition", publicName: "tooltipPosition", isSignal: true, isRequired: false, transformFunction: null }, $tooltipMargin: { classPropertyName: "$tooltipMargin", publicName: "tooltipMargin", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderToolipDefDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tabHeaderTooltipDef]',
                    standalone: false,
                }]
        }] });

class CellToolipDefDirective {
    table = input.required({
        alias: 'tabCellTooltipDef',
    });
    $showTooltip = input(true, {
        alias: 'showTooltip',
    });
    $tooltipPosition = input('bottom', {
        alias: 'tooltipPosition',
    });
    $tooltipMargin = input('0px', {
        alias: 'tooltipMargin',
    });
    templateRef = inject((TemplateRef));
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellToolipDefDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.3", type: CellToolipDefDirective, isStandalone: false, selector: "[tabCellTooltipDef]", inputs: { table: { classPropertyName: "table", publicName: "tabCellTooltipDef", isSignal: true, isRequired: true, transformFunction: null }, $showTooltip: { classPropertyName: "$showTooltip", publicName: "showTooltip", isSignal: true, isRequired: false, transformFunction: null }, $tooltipPosition: { classPropertyName: "$tooltipPosition", publicName: "tooltipPosition", isSignal: true, isRequired: false, transformFunction: null }, $tooltipMargin: { classPropertyName: "$tooltipMargin", publicName: "tooltipMargin", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellToolipDefDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tabCellTooltipDef]',
                    standalone: false,
                }]
        }] });

class ColumnDefDirective {
    /**
     * The unique identifier for the column.
     */
    $id = input.required({
        alias: 'tabColumnDef',
    });
    /**
     * The property name of the column, used for sorting purposes.
     * If not provided, it will default to the column ID.
     * @default undefined
     */
    $propertyName = input(undefined, {
        alias: 'propertyName',
    });
    /**
     * The CSS width of the column.
     * Can be a string representing a CSS value (e.g., '100px', '20%', '1rem') or a number repesenting flex-grow (fill space).
     * @default "1"
     */
    $width = input(1, {
        alias: 'width',
    });
    /**
     * The CSS minimum width of the column.
     * Can be a string representing a CSS value (e.g., '100px', '20%', '1rem'). If no unit is provided, it will be treated as pixels.
     * @default "100px"
     */
    $minWidth = input('5rem', {
        alias: 'minWidth',
    });
    /**
     * The CSS maximum width of the column.
     * Can be a string representing a CSS value (e.g., '100px', '20%', '1rem'). If no unit is provided, it will be treated as pixels.
     * If undefined, there is no maximum width.
     * @default undefined
     */
    $maxWidth = input(undefined, {
        alias: 'maxWidth',
    });
    /**
     * Whether the column is resizable by the user.
     * @default true
     */
    $resizable = input(true, {
        alias: 'resizable',
    });
    /**
     * Whether the column is sortable by the user.
     * @default true
     */
    $sortable = input(true, {
        alias: 'sortable',
    });
    /**
     * The sort order of the column when it is sorted.
     * Can be 'asc' for ascending, 'desc' for descending, or an array of two values to indicate the order of sorting.
     * @default "['asc', 'desc']"
     */
    $sortOrder = input(['asc', 'desc'], {
        alias: 'sortOrder',
    });
    /**
     * The CSS class to apply to the column header.
     * Can be a string or a function that returns a string based on the header context.
     * If undefined, no class will be applied.
     * @default undefined
     */
    $headerClass = input(undefined, {
        alias: 'headerClass',
    });
    /**
     * The CSS class to apply to the column cells.
     * Can be a string or a function that returns a string based on the cell context.
     * If undefined, no class will be applied.
     * @default undefined
     */
    $cellClass = input(undefined, {
        alias: 'cellClass',
    });
    /**
     * Show automatic header tooltip when no tabHeaderTooltipDef is provided on the column.
     * @default true
     */
    $showAutoHeaderTooltip = input(true, {
        alias: 'showAutoHeaderTooltip',
    });
    /**
     * Show automatic cell tooltip when no tabCellTooltipDef is provided on the column.
     * The auto cell tooltip displays the column value when it's clipped. Only works for tabCellDefs with $textClipping() enabled.
     * If the cell value is not clipped, no automatic tooltip will be shown.
     * When a tabCellTooltipDef overrides the automatic tooltip, this setting has no effect.
     * @default true
     */
    $showAutoCellTooltip = input(true, {
        alias: 'showAutoCellTooltip',
    });
    $cell = contentChild.required(CellDefDirective);
    $header = contentChild(HeaderDefDirective);
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    $headerTooltip = contentChild(HeaderToolipDefDirective);
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    $cellTooltip = contentChild(CellToolipDefDirective);
    buildHeaderContext(index, first, last, even, odd, count) {
        return {
            columnDef: this,
            meta: {
                index,
                first,
                last,
                even,
                odd,
                count,
            },
        };
    }
    buildCellContext(value, maxRowCount, index, first, last, even, odd, count, columnIndex, columnFirst, columnLast, columnEven, columnOdd, columnCount) {
        return {
            row: value,
            meta: {
                columnDef: this,
                index: index,
                first: first,
                last: last,
                even: even,
                odd: odd,
                count: count,
                columnIndex: columnIndex,
                columnFirst: columnFirst,
                columnLast: columnLast,
                columnEven: columnEven,
                columnOdd: columnOdd,
                columnCount: columnCount,
            },
            maxRowCount,
        };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ColumnDefDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.2.0", version: "20.0.3", type: ColumnDefDirective, isStandalone: false, selector: "[tabColumnDef]", inputs: { $id: { classPropertyName: "$id", publicName: "tabColumnDef", isSignal: true, isRequired: true, transformFunction: null }, $propertyName: { classPropertyName: "$propertyName", publicName: "propertyName", isSignal: true, isRequired: false, transformFunction: null }, $width: { classPropertyName: "$width", publicName: "width", isSignal: true, isRequired: false, transformFunction: null }, $minWidth: { classPropertyName: "$minWidth", publicName: "minWidth", isSignal: true, isRequired: false, transformFunction: null }, $maxWidth: { classPropertyName: "$maxWidth", publicName: "maxWidth", isSignal: true, isRequired: false, transformFunction: null }, $resizable: { classPropertyName: "$resizable", publicName: "resizable", isSignal: true, isRequired: false, transformFunction: null }, $sortable: { classPropertyName: "$sortable", publicName: "sortable", isSignal: true, isRequired: false, transformFunction: null }, $sortOrder: { classPropertyName: "$sortOrder", publicName: "sortOrder", isSignal: true, isRequired: false, transformFunction: null }, $headerClass: { classPropertyName: "$headerClass", publicName: "headerClass", isSignal: true, isRequired: false, transformFunction: null }, $cellClass: { classPropertyName: "$cellClass", publicName: "cellClass", isSignal: true, isRequired: false, transformFunction: null }, $showAutoHeaderTooltip: { classPropertyName: "$showAutoHeaderTooltip", publicName: "showAutoHeaderTooltip", isSignal: true, isRequired: false, transformFunction: null }, $showAutoCellTooltip: { classPropertyName: "$showAutoCellTooltip", publicName: "showAutoCellTooltip", isSignal: true, isRequired: false, transformFunction: null } }, queries: [{ propertyName: "$cell", first: true, predicate: CellDefDirective, descendants: true, isSignal: true }, { propertyName: "$header", first: true, predicate: HeaderDefDirective, descendants: true, isSignal: true }, { propertyName: "$headerTooltip", first: true, predicate: HeaderToolipDefDirective, descendants: true, isSignal: true }, { propertyName: "$cellTooltip", first: true, predicate: CellToolipDefDirective, descendants: true, isSignal: true }], ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ColumnDefDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[tabColumnDef]',
                    standalone: false,
                }]
        }] });

class ColRenderedWidthDirective {
    columnId = input.required({
        alias: 'colRenderedWidth',
    });
    element = inject(ElementRef);
    _renderedWidth = new BehaviorSubject(0);
    get renderedWidth() {
        return this._renderedWidth;
    }
    observer;
    get isObserving() {
        return this.observer !== undefined;
    }
    ngAfterViewInit() {
        this.observer = new ResizeObserver(() => {
            const width = +getComputedStyle(this.element.nativeElement).width.replace('px', '');
            this._renderedWidth.next(width);
        });
        this.observer.observe(this.element.nativeElement);
    }
    ngOnDestroy() {
        if (this.observer) {
            this.observer.disconnect();
            this.observer = undefined;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ColRenderedWidthDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.3", type: ColRenderedWidthDirective, isStandalone: false, selector: "[colRenderedWidth]", inputs: { columnId: { classPropertyName: "columnId", publicName: "colRenderedWidth", isSignal: true, isRequired: true, transformFunction: null } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ColRenderedWidthDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[colRenderedWidth]',
                    standalone: false,
                }]
        }] });

class DataBlock {
    id;
    abort;
    blockRowCount;
    getKey;
    dataPromise;
    $_status = signal('loading');
    get $status() {
        return this.$_status;
    }
    $response = signal([]);
    $data = computed(() => {
        const status = this.$status();
        const response = this.$response();
        if (status === 'success') {
            return response;
        }
        else {
            const row = {};
            return Array.from({ length: Number.isFinite(this.blockRowCount) ? this.blockRowCount : 0 }, (_, a) => ({
                key: a,
                data: row,
            }));
        }
    });
    get offset() {
        return this.id * this.blockRowCount;
    }
    constructor(id, abort, blockRowCount, getKey, dataPromise) {
        this.id = id;
        this.abort = abort;
        this.blockRowCount = blockRowCount;
        this.getKey = getKey;
        this.dataPromise = dataPromise;
        this.dataPromise
            .then((data) => {
            this.$response.set(data);
            this.$_status.set('success');
        })
            .catch((error) => {
            if (this.abort?.signal.aborted === true) {
                this.$_status.set('canceled');
                return;
            }
            this.$_status.set('error');
            console.error('Error loading data block:', error);
            throw error;
        });
    }
}

class BaseDataOptions {
    getRowKey;
    constructor(getRowKey) {
        this.getRowKey = getRowKey;
    }
}
class IncrementalDataOptions extends BaseDataOptions {
    getDataBlock;
    constructor(getRowKey, getDataBlock) {
        super(getRowKey);
        this.getDataBlock = getDataBlock;
    }
}
class FullDataOptions extends BaseDataOptions {
    getAllData;
    constructor(getRowKey, getAllData) {
        super(getRowKey);
        this.getAllData = getAllData;
    }
}

class DataManager {
    cdr;
    constructor(cdr) {
        this.cdr = cdr;
    }
    dataRowHeightPx = 0;
    dataWindowHeightPx = 0;
    sort = [];
    dataBlockWindow = 0;
    dataBlockHeightPx = 0;
    blockRowCount = 0;
    _totalRowCount = 0;
    get totalRowCount() {
        return this._totalRowCount;
    }
    dataOptions = undefined;
    $_blocks = signal({
        prePixels: 0,
        blocks: [],
        postPixels: 0,
    });
    get $blocks() {
        return this.$_blocks;
    }
    _allDataInfo = undefined;
    get allDataInfo() {
        return this._allDataInfo;
    }
    resetting = false;
    async reset(dataWindowHeightPx, dataRowHeightPx, sort, dataBlockWindow, dataOptions) {
        this.resetting = true;
        this.dataOptions = dataOptions;
        this.dataRowHeightPx = dataRowHeightPx;
        this.dataWindowHeightPx = dataWindowHeightPx;
        this.sort = sort;
        this.dataBlockWindow = dataBlockWindow;
        this.blockRowCount = Math.floor(dataWindowHeightPx / dataRowHeightPx);
        this.dataBlockHeightPx = dataRowHeightPx * this.blockRowCount;
        this._totalRowCount = 0;
        if (this._allDataInfo) {
            this._allDataInfo.abort.abort();
            this._allDataInfo = undefined;
        }
        if (!Number.isFinite(this.blockRowCount) || this.blockRowCount <= 0) {
            this.$_blocks.set({
                prePixels: 0,
                blocks: [],
                postPixels: 0,
            });
            this.resetting = false;
            return;
        }
        let initialBlock = undefined;
        if (this.dataOptions instanceof IncrementalDataOptions) {
            initialBlock = this.getBlock(0);
        }
        else if (this.dataOptions instanceof FullDataOptions) {
            const allDataAbort = new AbortController();
            let allDataPromise;
            if (!Number.isFinite(this.blockRowCount)) {
                allDataPromise = Promise.resolve([]);
            }
            else {
                allDataPromise = this.dataOptions
                    .getAllData({
                    sort: sort,
                    abort: allDataAbort.signal,
                })
                    .then((response) => {
                    this._totalRowCount = response.data.length;
                    return response.data.map((row) => ({
                        key: this.dataOptions.getRowKey(row),
                        data: row,
                    }));
                });
            }
            this._allDataInfo = new AllDataInfo(allDataPromise, allDataAbort);
            initialBlock = this.getBlock(0);
        }
        else {
            this.resetting = false;
            throw new Error('Unsupported data options type');
        }
        // load initial block
        this.$_blocks.update((blocks) => {
            // Clear existing blocks
            blocks.blocks.forEach((block) => {
                block.abort?.abort();
            });
            return {
                prePixels: 0,
                blocks: [initialBlock],
                postPixels: 0,
            };
        });
        this.cdr.markForCheck();
        try {
            await initialBlock.dataPromise;
            this.cdr.markForCheck();
            this.resetting = false;
            this.setScrollPosition(0);
        }
        catch (error) {
            console.error('Error loading initial data block:', error);
            this.cdr.markForCheck();
            this.resetting = false;
        }
        // const initialBlockStatus = initialBlock.$status();
        // if (initialBlockStatus !== 'success') {
        //     console.error('Initial data block failed to load:', initialBlockStatus);
        //     this.cdr.markForCheck();
        //     return;
        // }
    }
    getBlock(blockId) {
        if (this.allDataInfo) {
            // we are using full data
            const blockPromise = this.allDataInfo.promise.then((data) => {
                return data.slice(blockId * this.blockRowCount, (blockId + 1) * this.blockRowCount);
            });
            return new DataBlock(blockId, undefined, this.blockRowCount, this.dataOptions.getRowKey, blockPromise);
        }
        else {
            // we are using incremental data
            const blockAbort = new AbortController();
            let blockPromise;
            if (!Number.isFinite(this.blockRowCount)) {
                blockPromise = Promise.resolve([]);
            }
            else {
                blockPromise = this.dataOptions
                    .getDataBlock({
                    offset: blockId * this.blockRowCount,
                    count: this.blockRowCount,
                    sort: this.sort,
                    abort: blockAbort.signal,
                })
                    .then((response) => {
                    this._totalRowCount = response.total;
                    return response.data.map((row) => ({
                        key: this.dataOptions.getRowKey(row),
                        data: row,
                    }));
                })
                    .then((data) => {
                    if (data.length > this.blockRowCount) {
                        console.warn(`Data block received unexpected data: count ${data.length}, expected max count ${this.blockRowCount}`);
                        throw new Error(`Data block received unexpected data: count ${data.length}, expected max count ${this.blockRowCount}`);
                    }
                    return data;
                });
            }
            return new DataBlock(blockId, blockAbort, this.blockRowCount, this.dataOptions.getRowKey, blockPromise);
        }
    }
    setScrollPosition(topPx) {
        if (this.resetting) {
            return;
        }
        // get the block IDs in the current viewPort
        const bottomPx = topPx + this.dataWindowHeightPx;
        const firstVisibleBlockId = Math.floor(topPx / this.dataBlockHeightPx);
        const lastVisibleBlockId = Math.floor(bottomPx / this.dataBlockHeightPx);
        const dataBlockWindow = this.dataBlockWindow;
        // we are loading
        // - [dataBlockWindow] blocks before the first visible block
        // - all the visible blocks
        // - [dataBlockWindow] blocks after the last visible block
        const blockIdsToLoad = [];
        for (let i = firstVisibleBlockId - dataBlockWindow; i <= lastVisibleBlockId + dataBlockWindow; i++) {
            if (i < 0) {
                continue;
            }
            if (i * this.blockRowCount >= this.totalRowCount) {
                // No more data to load
                continue;
            }
            blockIdsToLoad.push(i);
        }
        this.$_blocks.update((existing) => {
            const blocks = [];
            for (const existingBlock of existing.blocks) {
                if (blockIdsToLoad.includes(existingBlock.id)) {
                    blocks.push(existingBlock);
                }
                else {
                    existingBlock.abort?.abort();
                }
            }
            for (const blockId of blockIdsToLoad) {
                if (!blocks.some((b) => b.id === blockId)) {
                    const newBlock = this.getBlock(blockId);
                    blocks.push(newBlock);
                }
            }
            existing.blocks = blocks.sort((a, b) => a.id - b.id);
            // // rows before the first block
            existing.prePixels = existing.blocks.length === 0 ? 0 : existing.blocks[0].id * this.dataBlockHeightPx;
            // // rows after the last block
            const lastBlock = existing.blocks.length === 0 ? undefined : existing.blocks[existing.blocks.length - 1];
            const preAndDisplayedRowsCount = (lastBlock?.offset ?? 0) + (this.blockRowCount ?? 0);
            const postRowsCount = this.totalRowCount - preAndDisplayedRowsCount;
            existing.postPixels = Math.max(0, postRowsCount) * this.dataRowHeightPx;
            return existing;
        });
    }
}
class AllDataInfo {
    promise;
    abort;
    $_allKeys = signal(new Set());
    get $allKeys() {
        return this.$_allKeys;
    }
    $_status = signal('loading');
    get $status() {
        return this.$_status;
    }
    constructor(promise, abort) {
        this.promise = promise;
        this.abort = abort;
        promise
            .then((data) => {
            this.$_allKeys.set(new Set(data.map((item) => item.key)));
            this.$_status.set('success');
        })
            .catch((error) => {
            if (this.abort.signal.aborted) {
                this.$_status.set('canceled');
                throw error;
            }
            this.$_status.set('error');
            console.error('Error loading all data:', error);
            throw error;
        });
    }
}

class CommonSelectionOptions {
    selectionMode;
    clearSelectedKeysOnManualReset;
    clearSelectedKeysOnAnyReset;
    constructor(selectionMode = 'row-and-checkbox', clearSelectedKeysOnManualReset = true, clearSelectedKeysOnAnyReset = false) {
        this.selectionMode = selectionMode;
        this.clearSelectedKeysOnManualReset = clearSelectedKeysOnManualReset;
        this.clearSelectedKeysOnAnyReset = clearSelectedKeysOnAnyReset;
    }
}
class SingleSelectionOptions extends CommonSelectionOptions {
    constructor(
    /**
     * Selection mode for the table.
     * - 'checkbox': Only checkbox selection is allowed.
     * - 'row-and-checkbox': Both row and checkbox selection are allowed.
     *
     */
    selectionMode = 'row-and-checkbox', 
    /**
     * Clear the selected keys when a manual reset is triggered.
     * @default true
     */
    clearSelectedRowsOnManualReset = true, 
    /**
     * Clear the selected keys when any reset is triggered.
     * This includes manual resets and automatic resets (e.g., when size/sort/displayed cols, etc changes).
     * @default false
     */
    clearSelectedRowsOnAnyReset = false) {
        super(selectionMode, clearSelectedRowsOnManualReset, clearSelectedRowsOnAnyReset);
    }
}
class MultiSelectionOptions extends CommonSelectionOptions {
    headerCheckboxMode;
    constructor(
    /**
     * Configuration for the header checkbox mode.
     * This determines how the header checkbox behaves.
     * - 'none': No header checkbox is displayed.
     * - 'selectNone': A header checkbox is displayed that can only unselect all rows that have been selected
     * - `SelectAll`: A header checkbox is displayed that can select all rows that have been selected. Requires FullDataOptions to be used which can lead to performance issues with large datasets.
     */
    headerCheckboxMode, 
    /**
     * Selection mode for the table.
     * - 'checkbox': Only checkbox selection is allowed.
     * - 'row-and-checkbox': Both row and checkbox selection are allowed.
     *
     */
    selectionMode = 'row-and-checkbox', 
    /**
     * Clear the selected keys when a manual reset is triggered.
     * @default true
     */
    clearSelectedKeysOnManualReset = true, 
    /**
     * Clear the selected keys when any reset is triggered.
     * This includes manual resets and automatic resets (e.g., when size/sort/displayed cols, etc changes).
     * @default false
     */
    clearSelectedKeysOnAnyReset = false) {
        super(selectionMode, clearSelectedKeysOnManualReset, clearSelectedKeysOnAnyReset);
        this.headerCheckboxMode = headerCheckboxMode;
    }
}

class ResizerDirective {
    $columnElement = input.required({
        alias: 'resizerFor',
    });
    $enabled = input(true, {
        alias: 'enabled',
    });
    resizerElement = inject(ElementRef);
    renderer = inject(Renderer2);
    dragging;
    onMouseDown(event) {
        if (this.dragging !== undefined || !this.$enabled()) {
            return;
        }
        const element = this.$columnElement();
        this.dragging = {
            columnElement: element,
            startWidth: +getComputedStyle(element).width.replace('px', ''),
            startX: event.clientX,
        };
        this.renderer.addClass(this.resizerElement.nativeElement, 'dragging');
        event.preventDefault();
        event.stopPropagation();
        document.body.style.userSelect = 'none';
        const mouseMoveHandler = (e) => {
            const x = e.clientX;
            if (!this.dragging) {
                return;
            }
            const change = x - this.dragging.startX;
            const newWidth = this.dragging.startWidth + change;
            this.dragging.columnElement.style.width = `${newWidth}px`;
            this.renderer.setStyle(element, 'flex-grow', 'unset');
        };
        document.addEventListener('mousemove', mouseMoveHandler);
        const mouseUpHandler = () => {
            this.renderer.removeClass(this.resizerElement.nativeElement, 'dragging');
            this.dragging = undefined;
            document.removeEventListener('mousemove', mouseMoveHandler);
            document.removeEventListener('mouseup', mouseUpHandler);
            document.body.style.userSelect = '';
        };
        document.addEventListener('mouseup', mouseUpHandler);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ResizerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.3", type: ResizerDirective, isStandalone: false, selector: "[resizerFor]", inputs: { $columnElement: { classPropertyName: "$columnElement", publicName: "resizerFor", isSignal: true, isRequired: true, transformFunction: null }, $enabled: { classPropertyName: "$enabled", publicName: "enabled", isSignal: true, isRequired: false, transformFunction: null } }, host: { listeners: { "mousedown": "onMouseDown($event)" } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ResizerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[resizerFor]',
                    standalone: false,
                }]
        }], propDecorators: { onMouseDown: [{
                type: HostListener,
                args: ['mousedown', ['$event']]
            }] } });

class HeaderTooltipPipe {
    transform(columnDef, table, headerContext, autoHeaderTooltipTemplate, contextParams) {
        return () => {
            const tooltipArgs = {
                template: undefined,
                position: 'top',
                margin: '1rem',
                context: {
                    $implicit: {
                        ...headerContext,
                        headerTemplate: columnDef.$header()?.templateRef,
                        ...contextParams,
                    },
                },
            };
            // if we have a custom [tabHeaderTooltipDef] directive in our column definition
            const tooltipDef = columnDef.$headerTooltip();
            if (tooltipDef) {
                // check if user has provided a value to show the custom tooltip
                // this can be a boolean or a function that returns a boolean
                const showCustomParam = tooltipDef.$showTooltip();
                let showCustomTooltip;
                // if its a function, call it with the header context to see if we need to show the custom tooltip
                if (typeof showCustomParam === 'function') {
                    showCustomTooltip = showCustomParam(headerContext);
                }
                else {
                    // if its a boolean, use it directly
                    showCustomTooltip = showCustomParam;
                }
                // if we show custom tooltip, use the custom template
                if (showCustomTooltip) {
                    tooltipArgs.template = tooltipDef.templateRef;
                    tooltipArgs.position = tooltipDef.$tooltipPosition();
                    tooltipArgs.margin = tooltipDef.$tooltipMargin();
                }
            }
            // if we have not set tooltipArgs.template yet,
            // it means we are not showing a custom tooltip
            if (tooltipArgs.template === undefined && columnDef.$showAutoHeaderTooltip()) {
                tooltipArgs.template = autoHeaderTooltipTemplate;
            }
            // return the tooltip args
            return tooltipArgs;
        };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderTooltipPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: HeaderTooltipPipe, isStandalone: false, name: "headerTooltip" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderTooltipPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'headerTooltip',
                    standalone: false,
                }]
        }] });

class HeaderContextPipe {
    transform(value, index, first, last, even, odd, count) {
        return {
            $implicit: value.buildHeaderContext(index, first, last, even, odd, count),
        };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderContextPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: HeaderContextPipe, isStandalone: false, name: "headerContext" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderContextPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'headerContext',
                    standalone: false,
                }]
        }] });

class HeaderClassPipe {
    transform(ctx) {
        if (typeof ctx.columnDef.$headerClass() === 'string') {
            return ctx.columnDef.$headerClass();
        }
        if (typeof ctx.columnDef.$headerClass() === 'function') {
            return ctx.columnDef.$headerClass()(ctx);
        }
        return undefined;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderClassPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: HeaderClassPipe, isStandalone: false, name: "headerClass" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderClassPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'headerClass',
                    standalone: false,
                }]
        }] });

class CellContextPipe {
    transform(value, maxRowCount, def, index, first, last, even, odd, count, columnIndex, columnFirst, columnLast, columnEven, columnOdd, columnCount) {
        return {
            $implicit: def.buildCellContext(value, maxRowCount, index, first, last, even, odd, count, columnIndex, columnFirst, columnLast, columnEven, columnOdd, columnCount),
        };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellContextPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: CellContextPipe, isStandalone: false, name: "cellContext" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellContextPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'cellContext',
                    standalone: false,
                }]
        }] });

class CellClassPipe {
    transform(ctx) {
        if (typeof ctx.meta.columnDef.$cellClass() === 'string') {
            return ctx.meta.columnDef.$cellClass();
        }
        if (typeof ctx.meta.columnDef.$cellClass() === 'function') {
            return ctx.meta.columnDef.$cellClass()(ctx);
        }
        return undefined;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellClassPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: CellClassPipe, isStandalone: false, name: "cellClass" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellClassPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'cellClass',
                    standalone: false,
                }]
        }] });

class CellTooltipPipe {
    transform(cellElement, columnDef, cellContext, block) {
        return () => {
            const tooltipArgs = {
                template: undefined,
                position: 'bottom',
                margin: '0px',
                context: {
                    $implicit: {
                        ...cellContext,
                        cellTemplate: columnDef.$cell().templateRef,
                        isRowCellClamped: false,
                    },
                },
            };
            // if the cell's block is not loaded yet, we don't show the tooltip
            if (block.$status() !== 'success') {
                return tooltipArgs;
            }
            // if we have a custom [tabCellTooltipDef] directive in our column definition
            const tooltipDef = columnDef.$cellTooltip();
            if (tooltipDef !== undefined) {
                // check if user has provided a value to show the custom tooltip
                // this can be a boolean or a function that returns a boolean
                const showCustomParam = tooltipDef.$showTooltip();
                let showCustomTooltip;
                // if its a function, call it with the header context to see if we need to show the custom tooltip
                if (typeof showCustomParam === 'function') {
                    showCustomTooltip = showCustomParam(cellContext);
                }
                else {
                    // if its a boolean, use it directly
                    showCustomTooltip = showCustomParam;
                }
                // if we show custom tooltip, use the custom template
                if (showCustomTooltip) {
                    tooltipArgs.context.$implicit.isRowCellClamped = this.isClamped(cellElement);
                    tooltipArgs.template = tooltipDef.templateRef;
                    tooltipArgs.position = tooltipDef.$tooltipPosition();
                    tooltipArgs.margin = tooltipDef.$tooltipMargin();
                }
            }
            // if we have not set tooltipArgs.template yet,
            // it means we are not showing a custom tooltip
            // check if we have auto tooltip enabled and we have clamped the cell context
            if (tooltipArgs.template === undefined && columnDef.$showAutoCellTooltip()) {
                // check if the cell is clamped
                const clampElement = cellElement.querySelector('.line-clamp');
                const isClamped = clampElement !== null && clampElement.scrollHeight > clampElement.clientHeight;
                // if the cell is clamped, we show the auto tooltip
                if (isClamped) {
                    // use the cell template as the tooltip template
                    const cellTemplate = columnDef.$cell().templateRef;
                    tooltipArgs.template = cellTemplate;
                }
            }
            return tooltipArgs;
        };
    }
    isClamped(cellElement) {
        const clampElement = cellElement.querySelector('.line-clamp');
        return clampElement !== null && clampElement.scrollHeight > clampElement.clientHeight;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellTooltipPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: CellTooltipPipe, isStandalone: false, name: "cellTooltip" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellTooltipPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'cellTooltip',
                    standalone: false,
                }]
        }] });

class SortInfoPipe {
    transform(sorts, colId, propertyName) {
        return SortInfoPipe.getSortInfo(sorts, colId, propertyName);
    }
    static getSortInfo(sorts, colId, propertyName) {
        const p = propertyName ?? colId;
        const index = sorts.findIndex((e) => e.property === p);
        if (index === -1) {
            return undefined;
        }
        const info = sorts[index];
        return { info, index };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: SortInfoPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: SortInfoPipe, isStandalone: false, name: "sortInfoPipe" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: SortInfoPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'sortInfoPipe',
                    standalone: false,
                }]
        }] });

class ColWidthPipe {
    transform(value, mode) {
        if (value === undefined) {
            return '';
        }
        if (typeof value === 'string') {
            const isNumber = /^(\d*(?:\.\d+)?)$/.exec(value.trim());
            if (!isNumber) {
                switch (mode) {
                    case 'widthUnitsOnly':
                    case 'width':
                        return value;
                    case 'flexGrowOnly':
                        return '';
                }
            }
        }
        switch (mode) {
            case 'widthUnitsOnly':
                return '';
            case 'flexGrowOnly':
                return value.toString();
            case 'width':
                return `${value}px`;
            default:
                return '';
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ColWidthPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: ColWidthPipe, isStandalone: false, name: "colWidth" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ColWidthPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'colWidth',
                    standalone: false,
                }]
        }] });

class CellWidthPipe {
    transform(directives, colId, padding) {
        const col = directives.find((d) => d.columnId() === colId);
        if (!col) {
            return of('');
        }
        const pad = this.parsePadding(padding);
        //return of('10px');
        return col.renderedWidth.pipe(map((e) => `calc(${e}px - ${pad.left} - ${pad.right})`));
    }
    parsePadding(padding) {
        const parts = padding.trim().split(/\s+/);
        switch (parts.length) {
            case 1:
                return {
                    top: parts[0],
                    right: parts[0],
                    bottom: parts[0],
                    left: parts[0],
                };
            case 2:
                return {
                    top: parts[0],
                    right: parts[1],
                    bottom: parts[0],
                    left: parts[1],
                };
            case 3:
                return {
                    top: parts[0],
                    right: parts[1],
                    bottom: parts[2],
                    left: parts[1],
                };
            case 4:
                return {
                    top: parts[0],
                    right: parts[1],
                    bottom: parts[2],
                    left: parts[3],
                };
            default:
                throw new Error('Invalid padding value');
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellWidthPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: CellWidthPipe, isStandalone: false, name: "cellWidth" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: CellWidthPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'cellWidth',
                    standalone: false,
                }]
        }] });

class HeaderCheckboxModePipe {
    transform(selectionOptions) {
        if (selectionOptions instanceof MultiSelectionOptions) {
            return selectionOptions.headerCheckboxMode;
        }
        return 'none';
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderCheckboxModePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: HeaderCheckboxModePipe, isStandalone: false, name: "headerCheckboxMode" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: HeaderCheckboxModePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'headerCheckboxMode',
                    standalone: false,
                }]
        }] });

class RowSelectedPipe {
    transform(row, selectedRows, dataOptions) {
        const key = dataOptions.getRowKey(row);
        return selectedRows.has(key);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: RowSelectedPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: RowSelectedPipe, isStandalone: false, name: "rowSelected" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: RowSelectedPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'rowSelected',
                    standalone: false,
                }]
        }] });

class TableComponent {
    checkboxColWidth = '2.5em';
    self = this;
    // #region Inputs & Outputs
    /**
     * The column IDs to display in the table. The order of the IDs determines the order of the columns.
     * If undefined, all columns will be displayed in the order they are defined in the table.
     * @default undefined
     */
    $displayedColumns = model(undefined, {
        alias: 'displayedColumns',
    });
    $dataOptions = input.required({
        alias: 'dataOptions',
    });
    /**
     * The number of data blocks to load before and after the currently displayed block(s) based on scroll position.
     * This is used to determine how many blocks to load in advance for smooth scrolling.
     * A data block is a chunk of data that is loaded from the server. It's size is is whatever fits the current viewport.
     * @default 3
     */
    $dataBlockWindow = input(3, {
        alias: 'dataBlockWindow',
    });
    /**
     * The height of the table data row.
     * This must be a valid CSS value.
     * Fixed height is required for virtual scrolling to work properly.
     * If the height is not fixed, the table will not be able to calculate the row heights and will not be able to scroll properly.
     * @default '2.5em'
     */
    $dataRowHeight = input('2.5em', {
        alias: 'dataRowHeight',
    });
    /**
     * The margin for all header cells
     * @default '0.5em'
     */
    $headerPadding = input('0.5em', {
        alias: 'headerPadding',
    });
    /**
     * The margin for all data cells
     * @default '0 0.5em'
     */
    $dataPadding = input('0 0.5em', {
        alias: 'dataPadding',
    });
    /**
     * The sorting mode. When multi sort is enabled, holding SHIFT when clicking a column header will add it to the sort list
     * @default single
     */
    $sortMode = input('single', {
        alias: 'sortMode',
    });
    /**
     * The sort models. Initial sort mode can be provided here.
     * This gets updated when the sort is changed by the user on the UI dynamically
     * @default []
     */
    $sort = model([], {
        alias: 'sort',
    });
    /**
     * The column ID to pin to the left side of the table.
     * If undefined, no column will be pinned to the left.
     * @default undefined
     */
    $pinnedLeftColumn = model(undefined, {
        alias: 'pinnedLeftColumn',
    });
    /**
     * The column ID to pin to the right side of the table.
     * If undefined, no column will be pinned to the right.
     * @default undefined
     */
    $pinnedRightColumn = model(undefined, {
        alias: 'pinnedRightColumn',
    });
    /**
     * Whether to show a striped table.
     * This will alternate the background color of the rows.
     * @default false
     */
    $striped = model(false, {
        alias: 'striped',
    });
    /**
     * The template to use when there is no data to display.
     * If 'default', a default template will be used.
     * If a TemplateRef is provided, it will be used as the no data template.
     * @default 'default'
     */
    $noDataTemplate = input('default', {
        alias: 'noDataTemplate',
    });
    /**
     * The options for the selection mode.
     * If undefined, no selection will be enabled.
     * If a SingleSelectionOptions is provided, single selection will be enabled.
     * If a MultiSelectionOptions is provided, multi selection will be enabled.
     * @default undefined
     */
    $selectionOptions = input(undefined, {
        alias: 'selectionOptions',
    });
    /**
     * The selected rows.
     * This is used to determine which rows are selected in the table.
     * If the selection options are set to single selection, this will only contain a maximum of one row.
     * If the selection options are set to multi selection, this can contain multiple rows.
     * This is updated when the selection changes.
     * @default []
     * @see {@link $selectionOptions}
     */
    $selectedRows = model(new Map(), {
        alias: 'selectedRows',
    });
    // #endregion
    // #region Columns
    $columnDefs = contentChildren(ColumnDefDirective);
    $displayedColumnDefs = computed(() => {
        let columnDefs = this.$columnDefs();
        const displayedColumns = this.$displayedColumns();
        const pinnedLeftColumnId = this.$pinnedLeftColumn();
        const pinnedRightColumnId = this.$pinnedRightColumn();
        if (displayedColumns) {
            const displayColumnDefs = [];
            for (const colId of displayedColumns) {
                const colDef = columnDefs.find((e) => e.$id() === colId);
                if (colDef) {
                    displayColumnDefs.push(colDef);
                }
            }
            columnDefs = displayColumnDefs;
        }
        const pinnedLeftColumn = columnDefs.find((e) => e.$id() === pinnedLeftColumnId);
        const pinnedRightColumn = columnDefs.find((e) => e.$id() === pinnedRightColumnId);
        const ret = [];
        if (pinnedLeftColumn) {
            ret.push({
                id: pinnedLeftColumn.$id(),
                col: pinnedLeftColumn,
                pinnedLeft: true,
                pinnedRight: false,
                sortOrder: pinnedLeftColumn.$sortOrder(),
            });
        }
        for (const col of columnDefs.filter((e) => e !== pinnedLeftColumn && e !== pinnedRightColumn)) {
            ret.push({
                id: col.$id(),
                col,
                pinnedLeft: false,
                pinnedRight: false,
                sortOrder: col.$sortOrder(),
            });
        }
        if (pinnedRightColumn) {
            ret.push({
                id: pinnedRightColumn.$id(),
                col: pinnedRightColumn,
                pinnedLeft: false,
                pinnedRight: true,
                sortOrder: pinnedRightColumn.$sortOrder(),
            });
        }
        return ret;
    }, {
        equal: (a, b) => {
            if (a.length !== b.length) {
                return false;
            }
            for (let i = 0; i < a.length; i++) {
                if (a[i].id !== b[i].id || a[i].pinnedLeft !== b[i].pinnedLeft || a[i].pinnedRight !== b[i].pinnedRight || a[i].col.$id() !== b[i].col.$id()) {
                    return false;
                }
            }
            return true;
        },
    });
    // #endregion
    // #region View Children
    $columnWidthDirectives = viewChildren(ColRenderedWidthDirective);
    hostElement = inject(ElementRef);
    cdr = inject(ChangeDetectorRef);
    $headerRow = viewChild.required('headerRow');
    $dataRowSizer = viewChild.required('dataSizer');
    // #endregion
    dataManager = new DataManager(this.cdr);
    // #region Load & Reset
    loaded = false;
    dataWindowHeightPx = 0;
    dataRowHeightPx = 0;
    /**
     * Loads the table data. Only callable once. If the table is already loaded, this will do nothing.
     * This will calculate the available window and row height and reset() the table.
     * Use this to load the table initially
     * Use reload() to reload the table data if the table size or row size changes
     */
    async load() {
        if (this.loaded) {
            return false;
        }
        return this.reload();
    }
    /**
     * Reloads the table data.
     * This will re-calculate the available window and row height and reset() the table.
     * Use this to reload the table data if the table size or row size changes
     */
    async reload() {
        this.loaded = false;
        const host = this.hostElement.nativeElement;
        // calculate data window height
        this.dataWindowHeightPx = host.clientHeight - this.$headerRow().nativeElement.clientHeight;
        this.dataRowHeightPx = this.$dataRowSizer().nativeElement.clientHeight;
        const initialLoad = await this.resetInternal(this.$sort(), this.$dataOptions(), this.$dataBlockWindow());
        if (initialLoad) {
            this.loaded = true;
        }
        return initialLoad;
    }
    dataManagerReset = effect(() => {
        const sort = this.$sort();
        const dataOptions = this.$dataOptions();
        const dataBlockWindow = this.$dataBlockWindow();
        const selectionOptions = this.$selectionOptions();
        if (!this.loaded) {
            return;
        }
        if (selectionOptions?.clearSelectedKeysOnAnyReset === true) {
            this.$selectedRows.set(new Map());
        }
        if (!this.loaded) {
            return;
        }
        untracked(() => void this.resetInternal(sort, dataOptions, dataBlockWindow));
    });
    async resetInternal(sort, dataOptions, dataBlockWindow) {
        if (this.dataRowHeightPx === 0 || this.dataWindowHeightPx === 0 || !sort || !dataOptions) {
            console.warn('Table reset called with undefined parameters, ignoring');
            return false;
        }
        await this.dataManager.reset(this.dataWindowHeightPx, this.dataRowHeightPx, sort, dataBlockWindow, dataOptions);
        return true;
    }
    /**
     * Resets the table to its initial state.
     * This will reset the scroll position, data, and optionally selection.
     * If resetSort is true, the sort will also be reset to the initial state.
     * @param resetSort Whether to reset the sort to the initial state
     * @returns A promise that resolves to true if the reset was successful, false otherwise.
     */
    async reset(resetSort = false) {
        if (!this.loaded) {
            return false;
        }
        if (resetSort) {
            this.$sort.set([]);
        }
        const sort = this.$sort();
        const dataOptions = this.$dataOptions();
        const dataBlockWindow = this.$dataBlockWindow();
        const selectionOptions = this.$selectionOptions();
        if (selectionOptions?.clearSelectedKeysOnManualReset !== false) {
            this.$selectedRows.set(new Map());
        }
        return this.resetInternal(sort, dataOptions, dataBlockWindow);
    }
    // #endregion
    // #region Sort
    onColumnHeaderClick(e, def) {
        if (!def.$sortable()) {
            return;
        }
        e.preventDefault();
        e.stopPropagation();
        e.target.blur();
        const propertyName = def.$propertyName() ?? def.$id();
        const sort = this.$sort();
        const sortOrder = def.$sortOrder();
        const currentSort = sort.find((f) => f.property === propertyName);
        if (this.$sortMode() === 'single' || !e.shiftKey) {
            if (currentSort?.direction === sortOrder[1]) {
                this.$sort.set([]);
            }
            else {
                this.$sort.set([
                    {
                        property: propertyName,
                        direction: currentSort === undefined ? sortOrder[0] : currentSort.direction === 'asc' ? 'desc' : 'asc',
                    },
                ]);
            }
        }
        else {
            for (const s of sort) {
                if (s.property === propertyName) {
                    // toggle sort mode
                    if (s.direction === def.$sortOrder()[1]) {
                        // emove sort
                        this.$sort.set(sort.filter((f) => f.property !== propertyName));
                        return;
                    }
                    else {
                        s.direction = s.direction === 'asc' ? 'desc' : 'asc';
                        this.$sort.set([...sort]);
                    }
                    return;
                }
            }
            // add new sort
            this.$sort.set([
                ...sort,
                {
                    property: propertyName,
                    direction: def.$sortOrder()[0],
                },
            ]);
        }
    }
    // #endregion
    // #region Scrolling & Virtualization
    onScroll(element) {
        this.dataManager.setScrollPosition(element.scrollTop);
    }
    // #endregion
    // #region Selection
    // #region MultiSelect Header Checkbox
    $selectionMultiHeaderCheckboxSelected = model(this.$selectedRows().size > 0 ? 'partial' : false);
    selectionMultiHeaderCheckboxSelectNoneChanged() {
        this.$selectedRows.set(new Map());
    }
    async selectionMultiHeaderCheckboxSelectAllChanged(val) {
        if (val === true) {
            if (this.dataManager.allDataInfo?.$status() !== 'success') {
                return;
            }
            const allData = await this.dataManager.allDataInfo.promise;
            this.$selectedRows.set(new Map(allData.map((e) => [e.key, e.data])));
        }
        else {
            this.$selectedRows.set(new Map());
        }
    }
    updateSelectionMultiHeaderCheckboxSelected = effect(() => {
        let value = false;
        const selectedRows = this.$selectedRows();
        if (selectedRows.size === 0) {
            value = false;
        }
        else if (this.dataManager.allDataInfo?.$status() === 'success' && [...this.dataManager.allDataInfo.$allKeys().keys()].every((key) => selectedRows.has(key))) {
            value = true;
        }
        else {
            value = 'partial';
        }
        this.$selectionMultiHeaderCheckboxSelected.set(value);
    });
    // #endregion
    rowClicked(row, e) {
        const selectionOptions = this.$selectionOptions();
        if (!selectionOptions) {
            return;
        }
        if (selectionOptions.selectionMode !== 'row-and-checkbox') {
            return;
        }
        e.stopPropagation();
        e.preventDefault();
        const dataOptions = this.$dataOptions();
        const key = dataOptions.getRowKey(row);
        const selectedRows = this.$selectedRows();
        const isSelected = selectedRows.has(key);
        if (selectionOptions instanceof MultiSelectionOptions) {
            if (e.shiftKey || e.ctrlKey || e.metaKey) {
                this.checkboxSelectChange(row, !isSelected);
            }
            else {
                this.$selectedRows.set(new Map([[key, row]]));
            }
        }
        else if (selectionOptions instanceof SingleSelectionOptions) {
            if (isSelected) {
                this.$selectedRows.set(new Map());
            }
            else {
                this.$selectedRows.set(new Map([[key, row]]));
            }
        }
        // select the row
    }
    checkboxClicked(e) {
        e.stopPropagation();
        e.preventDefault();
    }
    checkboxSelectChange(row, checked) {
        const selectionOptions = this.$selectionOptions();
        if (!selectionOptions) {
            return;
        }
        const dataOptions = this.$dataOptions();
        if (selectionOptions instanceof MultiSelectionOptions) {
            const key = dataOptions.getRowKey(row);
            const selectedRows = this.$selectedRows();
            if (checked === true) {
                selectedRows.set(key, row);
            }
            else {
                selectedRows.delete(key);
            }
            this.$selectedRows.set(new Map(selectedRows));
        }
        else if (selectionOptions instanceof SingleSelectionOptions) {
            const key = dataOptions.getRowKey(row);
            if (checked === true) {
                this.$selectedRows.set(new Map([[key, row]]));
            }
            else {
                this.$selectedRows.set(new Map());
            }
        }
    }
    // #endregion
    // #region Line clamping
    $lineClampRows = signal(1);
    $lineClampElementHeightPx = signal(0);
    initializeLineClamp() {
        const rowSizer = this.$dataRowSizer().nativeElement;
        try {
            const cellStyle = getComputedStyle(rowSizer);
            const cellLineHeightString = cellStyle.lineHeight;
            const cellLineHeightPx = cellLineHeightString.endsWith('px') ? parseFloat(cellLineHeightString) : parseFloat(cellLineHeightString) * parseFloat(cellStyle.fontSize);
            const cellPaddingTop = parseFloat(cellStyle.paddingTop);
            const cellPaddingBottom = parseFloat(cellStyle.paddingBottom);
            const rowHeight = rowSizer.clientHeight - cellPaddingTop - cellPaddingBottom;
            const rows = Math.max(Math.floor(rowHeight / cellLineHeightPx), 1);
            this.$lineClampRows.set(rows);
            this.$lineClampElementHeightPx.set(cellLineHeightPx * rows);
        }
        catch (error) {
            console.warn('Failed to initialize line clamp:', error);
        }
    }
    // #endregion
    ngAfterViewInit() {
        this.initializeLineClamp();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.3", type: TableComponent, isStandalone: false, selector: "tab-table", inputs: { $displayedColumns: { classPropertyName: "$displayedColumns", publicName: "displayedColumns", isSignal: true, isRequired: false, transformFunction: null }, $dataOptions: { classPropertyName: "$dataOptions", publicName: "dataOptions", isSignal: true, isRequired: true, transformFunction: null }, $dataBlockWindow: { classPropertyName: "$dataBlockWindow", publicName: "dataBlockWindow", isSignal: true, isRequired: false, transformFunction: null }, $dataRowHeight: { classPropertyName: "$dataRowHeight", publicName: "dataRowHeight", isSignal: true, isRequired: false, transformFunction: null }, $headerPadding: { classPropertyName: "$headerPadding", publicName: "headerPadding", isSignal: true, isRequired: false, transformFunction: null }, $dataPadding: { classPropertyName: "$dataPadding", publicName: "dataPadding", isSignal: true, isRequired: false, transformFunction: null }, $sortMode: { classPropertyName: "$sortMode", publicName: "sortMode", isSignal: true, isRequired: false, transformFunction: null }, $sort: { classPropertyName: "$sort", publicName: "sort", isSignal: true, isRequired: false, transformFunction: null }, $pinnedLeftColumn: { classPropertyName: "$pinnedLeftColumn", publicName: "pinnedLeftColumn", isSignal: true, isRequired: false, transformFunction: null }, $pinnedRightColumn: { classPropertyName: "$pinnedRightColumn", publicName: "pinnedRightColumn", isSignal: true, isRequired: false, transformFunction: null }, $striped: { classPropertyName: "$striped", publicName: "striped", isSignal: true, isRequired: false, transformFunction: null }, $noDataTemplate: { classPropertyName: "$noDataTemplate", publicName: "noDataTemplate", isSignal: true, isRequired: false, transformFunction: null }, $selectionOptions: { classPropertyName: "$selectionOptions", publicName: "selectionOptions", isSignal: true, isRequired: false, transformFunction: null }, $selectedRows: { classPropertyName: "$selectedRows", publicName: "selectedRows", isSignal: true, isRequired: false, transformFunction: null }, $selectionMultiHeaderCheckboxSelected: { classPropertyName: "$selectionMultiHeaderCheckboxSelected", publicName: "$selectionMultiHeaderCheckboxSelected", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { $displayedColumns: "displayedColumnsChange", $sort: "sortChange", $pinnedLeftColumn: "pinnedLeftColumnChange", $pinnedRightColumn: "pinnedRightColumnChange", $striped: "stripedChange", $selectedRows: "selectedRowsChange", $selectionMultiHeaderCheckboxSelected: "$selectionMultiHeaderCheckboxSelectedChange" }, host: { listeners: { "scroll": "onScroll($event.target)" } }, queries: [{ propertyName: "$columnDefs", predicate: ColumnDefDirective, isSignal: true }], viewQueries: [{ propertyName: "$columnWidthDirectives", predicate: ColRenderedWidthDirective, descendants: true, isSignal: true }, { propertyName: "$headerRow", first: true, predicate: ["headerRow"], descendants: true, isSignal: true }, { propertyName: "$dataRowSizer", first: true, predicate: ["dataSizer"], descendants: true, isSignal: true }], ngImport: i0, template: "@let rowSelectionMode = $selectionOptions()?.selectionMode === 'row-and-checkbox';\n@let hasCheckboxColumn = $selectionOptions();\n<div class=\"table\" role=\"table\" [class.has-row-selection]=\"rowSelectionMode\">\n    <!--Data Row Sizer. This is a position fixed, 0px wide row with the given row height px. used to calculate the actual height of data rows prior to virtualizing-->\n    <div #dataSizer class=\"data-sizer\" [style.height]=\"$dataRowHeight()\"></div>\n    <!-- Column Row -->\n    <div #headerRow class=\"column-row\">\n        @if (hasCheckboxColumn) {\n            <div class=\"column-header pinned-left\" role=\"columnheader\" [style.width]=\"checkboxColWidth\" [style.minWidth]=\"checkboxColWidth\">\n                <div class=\"content check-select\">\n                    @switch ($selectionOptions() | headerCheckboxMode) {\n                        @case ('none') {}\n                        @case ('selectNone') {\n                            <tab-checkbox\n                                [disabled]=\"$selectionMultiHeaderCheckboxSelected() !== 'partial'\"\n                                [value]=\"$selectionMultiHeaderCheckboxSelected()\"\n                                [valueAfterPartial]=\"false\"\n                                (valueChange)=\"selectionMultiHeaderCheckboxSelectNoneChanged()\"\n                            />\n                        }\n                        @case ('selectAll') {\n                            <tab-checkbox\n                                [loading]=\"dataManager.allDataInfo?.$status() === 'loading'\"\n                                [disabled]=\"$selectionMultiHeaderCheckboxSelected() === false && dataManager.allDataInfo?.$status() !== 'success'\"\n                                [value]=\"$selectionMultiHeaderCheckboxSelected()\"\n                                [valueAfterPartial]=\"false\"\n                                (valueChange)=\"selectionMultiHeaderCheckboxSelectAllChanged($event)\"\n                            />\n                        }\n                    }\n                </div>\n            </div>\n        }\n        <!-- prettier-ignore -->\n        @for (def of $displayedColumnDefs(); let index = $index; let count = $count; let first = $first; let last = $last; let even = $even; let odd = $odd; track def.id) {\n            @let headerContext = def.col | headerContext: index : first : last : even : odd : count;\n            <!-- @let headerTooltip = def.col.$headerTooltip(); -->\n            <div\n                #header\n                class=\"column-header\"\n                role=\"columnheader\"\n                [attr.data-column-id]=\"def.id\"\n                [attr.data-column-index]=\"index\"\n                [attr.data-column-count]=\"count\"\n                [attr.data-column-first]=\"first\"\n                [attr.data-column-last]=\"last\"\n                [attr.data-column-even]=\"even\"\n                [attr.data-column-odd]=\"odd\"\n                [style.minWidth]=\"def.col.$minWidth() | colWidth: 'width'\"\n                [style.maxWidth]=\"def.col.$maxWidth() | colWidth: 'width'\"\n                [style.width]=\"def.col.$width() | colWidth: 'widthUnitsOnly'\"\n                [style.flexGrow]=\"def.col.$width() | colWidth: 'flexGrowOnly'\"\n                [class.resizeable]=\"def.col.$resizable()\"\n                [class.sortable]=\"def.col.$sortable()\"\n                [class.pinned-left]=\"def.pinnedLeft\"\n                [style.left]=\"!def.pinnedLeft ? 'initial': hasCheckboxColumn ? checkboxColWidth: '0'\"\n                [class.pinned-right]=\"def.pinnedRight\"\n                [ngClass]=\"headerContext.$implicit| headerClass\"\n                [colRenderedWidth]=\"def.id\"\n            >\n            <!-- [tooltipFullArgs]=\"headerTooltip | headerTooltip:headerContext.$implicit:def.col.$showAutoHeaderTooltip():defaultHeaderTooltipTemplate:\" -->\n                <div class=\"content\" [style.padding]=\"$headerPadding()\">\n                    <button\n                        class=\"header-button\"\n                        color=\"plain\"\n                        layout=\"small-icon\"\n                        tooltip\n                        tooltipArgsMode=\"lazy\"\n                        [class.not-sortable]=\"!def.col.$sortable()\"\n                        [tabindex]=\"def.col.$sortable() ? '0' : '-1'\"\n                        [tooltipLazyArgs]=\"def.col | headerTooltip:self:headerContext.$implicit:defaultHeaderTooltipTemplate:{\n                            sortMode: $sortMode(),\n                            sortable: def.col.$sortable(),\n                            sortOrder: def.col.$sortOrder(),\n                            currentSort: $sort() | sortInfoPipe: def.id : def.col.$propertyName(),\n                            allSorts: $sort()\n                        }\"\n                        (click)=\"onColumnHeaderClick($event, def.col)\"\n                    >\n                        <div class=\"content\">\n                            <div class=\"text\">\n                                @if (def.col.$header()) {\n                                    <ng-container [ngTemplateOutlet]=\"def.col.$header()!.templateRef\" [ngTemplateOutletContext]=\"headerContext\" />\n                                }\n                            </div>\n                            @if (def.col.$sortable()) {\n                                <div class=\"sort-indicator\">\n                                    @let currentSort = $sort() | sortInfoPipe: def.id : def.col.$propertyName();\n                                    @switch (currentSort?.info?.direction) {\n                                        @case ('asc') {\n                                            <tab-icon value=\"arrow_upward\" />\n                                        }\n                                        @case ('desc') {\n                                            <tab-icon value=\"arrow_downward\" />\n                                        }\n                                        @default {\n                                            <tab-icon class=\"no-sort\" value=\"swap_vert\" />\n                                        }\n                                    }\n                                    @if ($sortMode() === 'multi' && currentSort) {\n                                        <span class=\"sort-order\">\n                                            {{ currentSort.index + 1 }}\n                                        </span>\n                                    }\n                                </div>\n                            }\n                        </div>\n                    </button>\n                </div>\n                @if (def.col.$resizable()) {\n                    <div class=\"resizer\" [resizerFor]=\"header\" [enabled]=\"def.col.$resizable()\" \n                    [class.enabled]=\"def.col.$resizable()\"\n                    [class.last]=\"last\"\n                    >\n                        <div class=\"line\"></div>\n                    </div>\n                }\n               \n            </div>\n\n            <ng-template #defaultHeaderTooltipTemplate let-ctx [tabHeaderTooltipDef]=\"self\">\n                <div class=\"default-header-tooltip\">\n                    <div class=\"column-name\">\n                        <ng-container [ngTemplateOutlet]=\"ctx.headerTemplate\" [ngTemplateOutletContext]=\"{ $implicit: ctx }\" />\n                    </div>\n\n                    @if (ctx.sortable) {\n                        <div class=\"sort\">\n                            @if (ctx.currentSort) {\n                                <div class=\"current\">\n                                    Currently sorted in\n                                    <b>{{ ctx.currentSort.info.direction === 'asc' ? 'Ascending' : 'Descending' }} order.</b>\n                                </div>\n                            }\n                            @let nextSort = !ctx.currentSort ? ctx.sortOrder[0] : ctx.currentSort.info.direction === ctx.sortOrder[1] ? undefined : ctx.currentSort.info.direction === 'asc' ? 'desc' : 'asc';\n                            @let isSubSort = ctx.currentSort && ctx.currentSort.index > 0;\n                            @let addMultiSort = ctx.sortMode === 'multi' && !ctx.currentSort && ctx.allSorts.length > 0;\n                            @if (addMultiSort) {\n                                <div class=\"multi-sort\">\n                                    <b>Shift + Click</b>\n                                    to add add to multi-sort in\n                                    <b>{{ nextSort === 'asc' ? 'Ascending' : 'Descending' }}</b>\n                                    order.\n                                </div>\n                            }\n                            @if (isSubSort) {\n                                <div class=\"next\">\n                                    @if (!nextSort) {\n                                        <b>Shift + Click</b>\n                                        to remove sorting this column from multi-sort.\n                                    } @else {\n                                        <b>Shift + Click</b>\n                                        to change sorting to\n                                        <b>{{ nextSort === 'asc' ? 'Ascending' : 'Descending' }}</b>\n                                        order.\n                                    }\n                                </div>\n                                <div class=\"next\">\n                                    @if (!nextSort) {\n                                        Click to clear all sorting.\n                                    } @else {\n                                        Click to clear multi-sort and change to\n                                        <b>{{ nextSort === 'asc' ? 'Ascending' : 'Descending' }}</b>\n                                        order.\n                                    }\n                                </div>\n                            } @else {\n                                <div class=\"next\">\n                                    @if (!nextSort) {\n                                        Click to remove sorting.\n                                    } @else {\n                                        Click to sort in\n                                        <b>{{ nextSort === 'asc' ? 'Ascending' : 'Descending' }}</b>\n                                        order.\n                                    }\n                                </div>\n                            }\n                        </div>\n                    }\n                </div>\n            </ng-template>\n        }\n    </div>\n\n    <div class=\"data-rows\" [class.striped]=\"$striped()\">\n        @let dmBlocks = dataManager.$blocks();\n        @if (dmBlocks.blocks.length === 0) {\n            @let _noDataTemplate = $noDataTemplate();\n            <ng-container [ngTemplateOutlet]=\"_noDataTemplate === 'default' ? defaultNoData : _noDataTemplate\" />\n            <ng-template #defaultNoData>\n                <div class=\"no-data\" [style.padding]=\"$dataPadding()\">\n                    <span>No data available</span>\n                </div>\n            </ng-template>\n        } @else {\n            <div class=\"virtualize pre\" [style.height]=\"`${dmBlocks.prePixels}px`\"></div>\n\n            <!-- prettier-ignore-start -->\n            @for (block of dmBlocks.blocks; track block.id) {\n                <!-- prettier-ignore -->\n                @for (r of block.$data(); let index = $index; let count = $count; let first = $first; let last = $last; let even = $even; let odd = $odd; track r.key) {\n                    <!-- prettier-ignore-end -->\n                    <!-- eslint-disable-next-line @angular-eslint/template/click-events-have-key-events, @angular-eslint/template/interactive-supports-focus -->\n                    <div\n                        class=\"row\"\n                        role=\"row\"\n                        [style.height]=\"$dataRowHeight()\"\n                        [class.even]=\"(block.offset + index) % 2 === 0\"\n                        [class.selected]=\"r.data | rowSelected: $selectedRows() : $dataOptions()\"\n                        (click)=\"rowClicked(r.data, $event)\"\n                    >\n                        @if (hasCheckboxColumn) {\n                            <div class=\"cell check-select pinned-left\" role=\"cell\" [style.width]=\"checkboxColWidth\" [style.minWidth]=\"checkboxColWidth\">\n                                @if (block.$status() === 'success') {\n                                    <tab-checkbox\n                                    [value]=\"r.data | rowSelected: $selectedRows() : $dataOptions()\"\n                                    (valueChange)=\"checkboxSelectChange(r.data, $event)\"\n                                    (click)=\"checkboxClicked($event)\" />\n                                }\n                            </div>\n                        }\n                        <!-- prettier-ignore -->\n                        @for (def of $displayedColumnDefs(); let colindex = $index; let colcount = $count; let colfirst = $first; let collast = $last; let coleven = $even; let colodd = $odd; track def.id) {\n                            <!-- prettier-ignore-end -->\n                            @let cellContext =\n                            r.data\n                                    | cellContext\n                                        : $lineClampRows()\n                                        : def.col\n                                        : block.offset + index\n                                        : block.offset === 0 && first\n                                        : block.offset + index === dataManager.totalRowCount\n                                        : (block.offset + index) % 2 === 0\n                                        : (block.offset + index) % 2 === 1\n                                        : dataManager.totalRowCount\n                                        : colindex\n                                        : colfirst\n                                        : collast\n                                        : coleven\n                                        : colodd\n                                        : colcount;\n\n                            \n                            <div\n                                #cell\n                                class=\"cell\"\n                                role=\"cell\"\n                                tooltip\n                                tooltipArgsMode=\"lazy\"\n                                [attr.data-column-id]=\"def.id\"\n                                [attr.data-column-index]=\"block.offset + index\"\n                                [attr.data-column-count]=\"colcount\"\n                                [attr.data-column-first]=\"colfirst\"\n                                [attr.data-column-last]=\"collast\"\n                                [attr.data-column-even]=\"coleven\"\n                                [attr.data-column-odd]=\"colodd\"\n                                [class.pinned-left]=\"def.pinnedLeft\"\n                                [style.left]=\"!def.pinnedLeft ? 'initial': hasCheckboxColumn ? checkboxColWidth: '0'\"\n                                [class.pinned-right]=\"def.pinnedRight\"\n                                [style.padding]=\"$dataPadding()\"\n                                [style.width]=\"$columnWidthDirectives() | cellWidth: def.id : $dataPadding() | async\"\n                                [ngClass]=\"cellContext.$implicit | cellClass\"\n                                [tooltipLazyArgs]=\"cell | cellTooltip: def.col: cellContext.$implicit: block\"\n                            >\n                                @switch (block.$status()) {\n                                    @case ('loading') {\n                                        <div class=\"status loader\"></div>\n                                    }\n                                    @case ('error') {\n                                        <div class=\"status error\"></div>\n                                    }\n                                    @case ('success') {\n                                        @let cellDef = def.col.$cell();\n                                        @if (cellDef.$textClamping()) {\n                                            <div class=\"line-clamp\"\n                                                [style.height]=\"$lineClampElementHeightPx()\"\n                                                [style.-webkit-line-clamp]=\"$lineClampRows()\"                                       >\n                                                <ng-container [ngTemplateOutlet]=\"cellDef.templateRef\" [ngTemplateOutletContext]=\"cellContext\" />\n                                            </div>\n                                        } @else {\n                                            <ng-container [ngTemplateOutlet]=\"cellDef.templateRef\" [ngTemplateOutletContext]=\"cellContext\" />\n                                        }\n                                        \n                                    }\n                                }\n                            </div>\n                        }\n                    </div>\n                }\n            }\n            <div class=\"virtualize post\" [style.height]=\"`${dmBlocks.postPixels}px`\"></div>\n        }\n    </div>\n</div>\n", styles: [":host{display:block;overflow:auto;min-height:300px;height:100%;max-height:100%;scrollbar-gutter:stable}:host .table{min-height:100%;display:grid;grid-template-rows:auto 1fr}:host .table .data-sizer{position:fixed;top:0;left:0;visibility:hidden;width:0}:host .table .column-row{display:flex;position:sticky;width:fit-content;top:0;box-shadow:inset 0 -1px 0 var(--twc-color-border);background:var(--twc-color-base);background-clip:padding-box;z-index:2;min-width:100%}:host .table .column-row .column-header{display:grid;grid-template-columns:100% 0;grid-template-rows:auto}:host .table .column-row .column-header .content{grid-column:1;grid-row:1}:host .table .column-row .column-header .content .header-button .content{display:grid;gap:.5em;grid-template-columns:1fr auto}:host .table .column-row .column-header .content .header-button .content .text{-webkit-user-select:none;user-select:none;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}:host .table .column-row .column-header .content .header-button .content .sort-indicator{display:flex;align-items:center}:host .table .column-row .column-header .content .header-button .content .sort-indicator .no-sort{color:var(--twc-color-text-gray)}:host .table .column-row .column-header .content .header-button .content .sort-indicator span{font-size:.8em;color:var(--twc-color-text-gray);margin-top:.1em}:host .table .column-row .column-header .content .header-button.not-sortable{outline:none;cursor:default}:host .table .column-row .column-header .content .header-button.not-sortable:hover{background:initial}:host .table .column-row .column-header .content .header-button.not-sortable .content{gap:0;grid-template-columns:1fr}:host .table .column-row .column-header.pinned-left{box-shadow:inset 0 -1px 0 var(--twc-color-border),inset -1px 0 0 var(--twc-color-border-light);left:0;background:var(--twc-color-base);position:sticky;z-index:4}:host .table .column-row .column-header.pinned-right{box-shadow:inset 0 -1px 0 var(--twc-color-border),inset 1px 0 0 var(--twc-color-border-light);right:0;background:var(--twc-color-base);position:sticky;z-index:4}:host .table .column-row .column-header .resizer{grid-column:2;grid-row:1;width:8px;cursor:col-resize;display:flex;justify-content:center;z-index:3;margin-left:-4px;margin-right:-4px}:host .table .column-row .column-header .resizer.last{margin-right:-8px}:host .table .column-row .column-header:hover .resizer .line{width:1px;background:var(--twc-color-border-light)}:host .table .column-row .column-header .resizer.enabled:hover .line{width:3px;background:var(--twc-color-primary)}:host .table .column-row .column-header .resizer:not(.enabled):hover{cursor:not-allowed}:host .table .column-row .column-header .resizer:not(.enabled):hover .line{width:3px;background:var(--twc-color-error)}:host .table .column-row .column-header .resizer.enabled.dragging .line{width:3px;background:var(--twc-color-primary)}:host .table .data-rows{width:fit-content;z-index:1}:host .table .data-rows .no-data{color:var(--twc-color-text-gray);margin-top:.5em;font-size:var(--twc-font-size-subtitle)}:host .table .data-rows .row{display:flex;width:fit-content;box-shadow:inset 0 -1px 0 var(--twc-color-border-light)}:host .table .data-rows .row .cell{display:flex;align-items:center;overflow:hidden}:host .table .data-rows .row .cell .line-clamp{overflow:hidden;display:-webkit-box;-webkit-box-orient:vertical;overflow-wrap:break-word}:host .table .data-rows .row .cell.pinned-left{box-shadow:inset 0 -1px 0 var(--twc-color-border-light),inset -1px 0 0 var(--twc-color-border-light);left:0;background:var(--twc-color-base);position:sticky}:host .table .data-rows .row .cell.pinned-right{box-shadow:inset 0 -1px 0 var(--twc-color-border-light),inset 1px 0 0 var(--twc-color-border-light);right:0;background:var(--twc-color-base);position:sticky}:host .table .data-rows .row .cell .status{border-radius:1em;min-height:1em;width:100%;height:1em;max-height:70%}:host .table .data-rows .row .cell .status.loader{background-color:var(--twc-color-highlight);animation:pulse 1.2s infinite ease-in-out}@keyframes pulse{0%{opacity:1}50%{opacity:.3}to{opacity:1}}:host .table .data-rows .row .cell .status.error{background-color:var(--twc-color-error);opacity:.3}:host .table .data-rows.striped .row:not(.even,.selected){background-color:var(--twc-color-mouse-highlight)}:host .table .data-rows.striped .row:not(.even,.selected) .pinned-left,:host .table .data-rows.striped .row:not(.even,.selected) .pinned-right{background-color:var(--twc-color-mouse-highlight)}:host .table.has-row-selection .data-rows .row:not(.selected):hover{background-color:var(--twc-color-highlight)}:host .table.has-row-selection .data-rows .row:not(.selected):hover .pinned-left,:host .table.has-row-selection .data-rows .row:not(.selected):hover .pinned-right{background-color:var(--twc-color-highlight)}:host .table.has-row-selection .data-rows .row:hover{cursor:pointer}:host .table.has-row-selection .data-rows .row:hover .pinned-left,:host .table.has-row-selection .data-rows .row:hover .pinned-right{cursor:pointer}:host .table .data-rows .row.selected{background-color:var(--twc-color-primary-light)}:host .table .data-rows .row.selected .pinned-left,:host .table .data-rows .row.selected .pinned-right{background-color:var(--twc-color-primary-light)}:host .table .check-select{display:flex;align-items:center;justify-content:center}.default-header-tooltip{display:flex;flex-direction:column;gap:.5em}.default-header-tooltip .column-name{font-weight:700}.default-header-tooltip .sort{display:flex;flex-direction:column;gap:.25em;font-size:.8em;color:var(--twc-color-text-gray)}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.IconComponent, selector: "tab-icon", inputs: ["value", "color", "type", "fill", "weight", "grade", "opticalSizePx"] }, { kind: "component", type: i3.ButtonComponent, selector: "button:not([tab-menu-button]),a[button]:not([tab-menu-button])", inputs: ["disabled", "loading", "tabindex", "type", "kind", "color", "layout", "inline", "noFocusOnClick"] }, { kind: "directive", type: i4.TooltipDirective, selector: "[tooltip]", inputs: ["tooltip", "tooltipContext", "tooltipPosition", "tooltipMargin", "tooltipPadding", "tooltipArgsMode", "tooltipFullArgs", "tooltipLazyArgs"], outputs: ["tooltipChange", "tooltipContextChange", "tooltipPositionChange", "tooltipMarginChange", "tooltipPaddingChange"] }, { kind: "component", type: i5.CheckboxComponent, selector: "tab-checkbox", inputs: ["disabled", "value", "loading", "valueAfterPartial", "id", "name", "autocomplete"], outputs: ["disabledChange", "valueChange"] }, { kind: "directive", type: HeaderToolipDefDirective, selector: "[tabHeaderTooltipDef]", inputs: ["tabHeaderTooltipDef", "showTooltip", "tooltipPosition", "tooltipMargin"] }, { kind: "directive", type: ColRenderedWidthDirective, selector: "[colRenderedWidth]", inputs: ["colRenderedWidth"] }, { kind: "directive", type: ResizerDirective, selector: "[resizerFor]", inputs: ["resizerFor", "enabled"] }, { kind: "pipe", type: i1.AsyncPipe, name: "async" }, { kind: "pipe", type: HeaderTooltipPipe, name: "headerTooltip" }, { kind: "pipe", type: HeaderContextPipe, name: "headerContext" }, { kind: "pipe", type: HeaderClassPipe, name: "headerClass" }, { kind: "pipe", type: CellContextPipe, name: "cellContext" }, { kind: "pipe", type: CellClassPipe, name: "cellClass" }, { kind: "pipe", type: CellTooltipPipe, name: "cellTooltip" }, { kind: "pipe", type: SortInfoPipe, name: "sortInfoPipe" }, { kind: "pipe", type: ColWidthPipe, name: "colWidth" }, { kind: "pipe", type: CellWidthPipe, name: "cellWidth" }, { kind: "pipe", type: HeaderCheckboxModePipe, name: "headerCheckboxMode" }, { kind: "pipe", type: RowSelectedPipe, name: "rowSelected" }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tab-table', standalone: false, changeDetection: ChangeDetectionStrategy.OnPush, host: {}, template: "@let rowSelectionMode = $selectionOptions()?.selectionMode === 'row-and-checkbox';\n@let hasCheckboxColumn = $selectionOptions();\n<div class=\"table\" role=\"table\" [class.has-row-selection]=\"rowSelectionMode\">\n    <!--Data Row Sizer. This is a position fixed, 0px wide row with the given row height px. used to calculate the actual height of data rows prior to virtualizing-->\n    <div #dataSizer class=\"data-sizer\" [style.height]=\"$dataRowHeight()\"></div>\n    <!-- Column Row -->\n    <div #headerRow class=\"column-row\">\n        @if (hasCheckboxColumn) {\n            <div class=\"column-header pinned-left\" role=\"columnheader\" [style.width]=\"checkboxColWidth\" [style.minWidth]=\"checkboxColWidth\">\n                <div class=\"content check-select\">\n                    @switch ($selectionOptions() | headerCheckboxMode) {\n                        @case ('none') {}\n                        @case ('selectNone') {\n                            <tab-checkbox\n                                [disabled]=\"$selectionMultiHeaderCheckboxSelected() !== 'partial'\"\n                                [value]=\"$selectionMultiHeaderCheckboxSelected()\"\n                                [valueAfterPartial]=\"false\"\n                                (valueChange)=\"selectionMultiHeaderCheckboxSelectNoneChanged()\"\n                            />\n                        }\n                        @case ('selectAll') {\n                            <tab-checkbox\n                                [loading]=\"dataManager.allDataInfo?.$status() === 'loading'\"\n                                [disabled]=\"$selectionMultiHeaderCheckboxSelected() === false && dataManager.allDataInfo?.$status() !== 'success'\"\n                                [value]=\"$selectionMultiHeaderCheckboxSelected()\"\n                                [valueAfterPartial]=\"false\"\n                                (valueChange)=\"selectionMultiHeaderCheckboxSelectAllChanged($event)\"\n                            />\n                        }\n                    }\n                </div>\n            </div>\n        }\n        <!-- prettier-ignore -->\n        @for (def of $displayedColumnDefs(); let index = $index; let count = $count; let first = $first; let last = $last; let even = $even; let odd = $odd; track def.id) {\n            @let headerContext = def.col | headerContext: index : first : last : even : odd : count;\n            <!-- @let headerTooltip = def.col.$headerTooltip(); -->\n            <div\n                #header\n                class=\"column-header\"\n                role=\"columnheader\"\n                [attr.data-column-id]=\"def.id\"\n                [attr.data-column-index]=\"index\"\n                [attr.data-column-count]=\"count\"\n                [attr.data-column-first]=\"first\"\n                [attr.data-column-last]=\"last\"\n                [attr.data-column-even]=\"even\"\n                [attr.data-column-odd]=\"odd\"\n                [style.minWidth]=\"def.col.$minWidth() | colWidth: 'width'\"\n                [style.maxWidth]=\"def.col.$maxWidth() | colWidth: 'width'\"\n                [style.width]=\"def.col.$width() | colWidth: 'widthUnitsOnly'\"\n                [style.flexGrow]=\"def.col.$width() | colWidth: 'flexGrowOnly'\"\n                [class.resizeable]=\"def.col.$resizable()\"\n                [class.sortable]=\"def.col.$sortable()\"\n                [class.pinned-left]=\"def.pinnedLeft\"\n                [style.left]=\"!def.pinnedLeft ? 'initial': hasCheckboxColumn ? checkboxColWidth: '0'\"\n                [class.pinned-right]=\"def.pinnedRight\"\n                [ngClass]=\"headerContext.$implicit| headerClass\"\n                [colRenderedWidth]=\"def.id\"\n            >\n            <!-- [tooltipFullArgs]=\"headerTooltip | headerTooltip:headerContext.$implicit:def.col.$showAutoHeaderTooltip():defaultHeaderTooltipTemplate:\" -->\n                <div class=\"content\" [style.padding]=\"$headerPadding()\">\n                    <button\n                        class=\"header-button\"\n                        color=\"plain\"\n                        layout=\"small-icon\"\n                        tooltip\n                        tooltipArgsMode=\"lazy\"\n                        [class.not-sortable]=\"!def.col.$sortable()\"\n                        [tabindex]=\"def.col.$sortable() ? '0' : '-1'\"\n                        [tooltipLazyArgs]=\"def.col | headerTooltip:self:headerContext.$implicit:defaultHeaderTooltipTemplate:{\n                            sortMode: $sortMode(),\n                            sortable: def.col.$sortable(),\n                            sortOrder: def.col.$sortOrder(),\n                            currentSort: $sort() | sortInfoPipe: def.id : def.col.$propertyName(),\n                            allSorts: $sort()\n                        }\"\n                        (click)=\"onColumnHeaderClick($event, def.col)\"\n                    >\n                        <div class=\"content\">\n                            <div class=\"text\">\n                                @if (def.col.$header()) {\n                                    <ng-container [ngTemplateOutlet]=\"def.col.$header()!.templateRef\" [ngTemplateOutletContext]=\"headerContext\" />\n                                }\n                            </div>\n                            @if (def.col.$sortable()) {\n                                <div class=\"sort-indicator\">\n                                    @let currentSort = $sort() | sortInfoPipe: def.id : def.col.$propertyName();\n                                    @switch (currentSort?.info?.direction) {\n                                        @case ('asc') {\n                                            <tab-icon value=\"arrow_upward\" />\n                                        }\n                                        @case ('desc') {\n                                            <tab-icon value=\"arrow_downward\" />\n                                        }\n                                        @default {\n                                            <tab-icon class=\"no-sort\" value=\"swap_vert\" />\n                                        }\n                                    }\n                                    @if ($sortMode() === 'multi' && currentSort) {\n                                        <span class=\"sort-order\">\n                                            {{ currentSort.index + 1 }}\n                                        </span>\n                                    }\n                                </div>\n                            }\n                        </div>\n                    </button>\n                </div>\n                @if (def.col.$resizable()) {\n                    <div class=\"resizer\" [resizerFor]=\"header\" [enabled]=\"def.col.$resizable()\" \n                    [class.enabled]=\"def.col.$resizable()\"\n                    [class.last]=\"last\"\n                    >\n                        <div class=\"line\"></div>\n                    </div>\n                }\n               \n            </div>\n\n            <ng-template #defaultHeaderTooltipTemplate let-ctx [tabHeaderTooltipDef]=\"self\">\n                <div class=\"default-header-tooltip\">\n                    <div class=\"column-name\">\n                        <ng-container [ngTemplateOutlet]=\"ctx.headerTemplate\" [ngTemplateOutletContext]=\"{ $implicit: ctx }\" />\n                    </div>\n\n                    @if (ctx.sortable) {\n                        <div class=\"sort\">\n                            @if (ctx.currentSort) {\n                                <div class=\"current\">\n                                    Currently sorted in\n                                    <b>{{ ctx.currentSort.info.direction === 'asc' ? 'Ascending' : 'Descending' }} order.</b>\n                                </div>\n                            }\n                            @let nextSort = !ctx.currentSort ? ctx.sortOrder[0] : ctx.currentSort.info.direction === ctx.sortOrder[1] ? undefined : ctx.currentSort.info.direction === 'asc' ? 'desc' : 'asc';\n                            @let isSubSort = ctx.currentSort && ctx.currentSort.index > 0;\n                            @let addMultiSort = ctx.sortMode === 'multi' && !ctx.currentSort && ctx.allSorts.length > 0;\n                            @if (addMultiSort) {\n                                <div class=\"multi-sort\">\n                                    <b>Shift + Click</b>\n                                    to add add to multi-sort in\n                                    <b>{{ nextSort === 'asc' ? 'Ascending' : 'Descending' }}</b>\n                                    order.\n                                </div>\n                            }\n                            @if (isSubSort) {\n                                <div class=\"next\">\n                                    @if (!nextSort) {\n                                        <b>Shift + Click</b>\n                                        to remove sorting this column from multi-sort.\n                                    } @else {\n                                        <b>Shift + Click</b>\n                                        to change sorting to\n                                        <b>{{ nextSort === 'asc' ? 'Ascending' : 'Descending' }}</b>\n                                        order.\n                                    }\n                                </div>\n                                <div class=\"next\">\n                                    @if (!nextSort) {\n                                        Click to clear all sorting.\n                                    } @else {\n                                        Click to clear multi-sort and change to\n                                        <b>{{ nextSort === 'asc' ? 'Ascending' : 'Descending' }}</b>\n                                        order.\n                                    }\n                                </div>\n                            } @else {\n                                <div class=\"next\">\n                                    @if (!nextSort) {\n                                        Click to remove sorting.\n                                    } @else {\n                                        Click to sort in\n                                        <b>{{ nextSort === 'asc' ? 'Ascending' : 'Descending' }}</b>\n                                        order.\n                                    }\n                                </div>\n                            }\n                        </div>\n                    }\n                </div>\n            </ng-template>\n        }\n    </div>\n\n    <div class=\"data-rows\" [class.striped]=\"$striped()\">\n        @let dmBlocks = dataManager.$blocks();\n        @if (dmBlocks.blocks.length === 0) {\n            @let _noDataTemplate = $noDataTemplate();\n            <ng-container [ngTemplateOutlet]=\"_noDataTemplate === 'default' ? defaultNoData : _noDataTemplate\" />\n            <ng-template #defaultNoData>\n                <div class=\"no-data\" [style.padding]=\"$dataPadding()\">\n                    <span>No data available</span>\n                </div>\n            </ng-template>\n        } @else {\n            <div class=\"virtualize pre\" [style.height]=\"`${dmBlocks.prePixels}px`\"></div>\n\n            <!-- prettier-ignore-start -->\n            @for (block of dmBlocks.blocks; track block.id) {\n                <!-- prettier-ignore -->\n                @for (r of block.$data(); let index = $index; let count = $count; let first = $first; let last = $last; let even = $even; let odd = $odd; track r.key) {\n                    <!-- prettier-ignore-end -->\n                    <!-- eslint-disable-next-line @angular-eslint/template/click-events-have-key-events, @angular-eslint/template/interactive-supports-focus -->\n                    <div\n                        class=\"row\"\n                        role=\"row\"\n                        [style.height]=\"$dataRowHeight()\"\n                        [class.even]=\"(block.offset + index) % 2 === 0\"\n                        [class.selected]=\"r.data | rowSelected: $selectedRows() : $dataOptions()\"\n                        (click)=\"rowClicked(r.data, $event)\"\n                    >\n                        @if (hasCheckboxColumn) {\n                            <div class=\"cell check-select pinned-left\" role=\"cell\" [style.width]=\"checkboxColWidth\" [style.minWidth]=\"checkboxColWidth\">\n                                @if (block.$status() === 'success') {\n                                    <tab-checkbox\n                                    [value]=\"r.data | rowSelected: $selectedRows() : $dataOptions()\"\n                                    (valueChange)=\"checkboxSelectChange(r.data, $event)\"\n                                    (click)=\"checkboxClicked($event)\" />\n                                }\n                            </div>\n                        }\n                        <!-- prettier-ignore -->\n                        @for (def of $displayedColumnDefs(); let colindex = $index; let colcount = $count; let colfirst = $first; let collast = $last; let coleven = $even; let colodd = $odd; track def.id) {\n                            <!-- prettier-ignore-end -->\n                            @let cellContext =\n                            r.data\n                                    | cellContext\n                                        : $lineClampRows()\n                                        : def.col\n                                        : block.offset + index\n                                        : block.offset === 0 && first\n                                        : block.offset + index === dataManager.totalRowCount\n                                        : (block.offset + index) % 2 === 0\n                                        : (block.offset + index) % 2 === 1\n                                        : dataManager.totalRowCount\n                                        : colindex\n                                        : colfirst\n                                        : collast\n                                        : coleven\n                                        : colodd\n                                        : colcount;\n\n                            \n                            <div\n                                #cell\n                                class=\"cell\"\n                                role=\"cell\"\n                                tooltip\n                                tooltipArgsMode=\"lazy\"\n                                [attr.data-column-id]=\"def.id\"\n                                [attr.data-column-index]=\"block.offset + index\"\n                                [attr.data-column-count]=\"colcount\"\n                                [attr.data-column-first]=\"colfirst\"\n                                [attr.data-column-last]=\"collast\"\n                                [attr.data-column-even]=\"coleven\"\n                                [attr.data-column-odd]=\"colodd\"\n                                [class.pinned-left]=\"def.pinnedLeft\"\n                                [style.left]=\"!def.pinnedLeft ? 'initial': hasCheckboxColumn ? checkboxColWidth: '0'\"\n                                [class.pinned-right]=\"def.pinnedRight\"\n                                [style.padding]=\"$dataPadding()\"\n                                [style.width]=\"$columnWidthDirectives() | cellWidth: def.id : $dataPadding() | async\"\n                                [ngClass]=\"cellContext.$implicit | cellClass\"\n                                [tooltipLazyArgs]=\"cell | cellTooltip: def.col: cellContext.$implicit: block\"\n                            >\n                                @switch (block.$status()) {\n                                    @case ('loading') {\n                                        <div class=\"status loader\"></div>\n                                    }\n                                    @case ('error') {\n                                        <div class=\"status error\"></div>\n                                    }\n                                    @case ('success') {\n                                        @let cellDef = def.col.$cell();\n                                        @if (cellDef.$textClamping()) {\n                                            <div class=\"line-clamp\"\n                                                [style.height]=\"$lineClampElementHeightPx()\"\n                                                [style.-webkit-line-clamp]=\"$lineClampRows()\"                                       >\n                                                <ng-container [ngTemplateOutlet]=\"cellDef.templateRef\" [ngTemplateOutletContext]=\"cellContext\" />\n                                            </div>\n                                        } @else {\n                                            <ng-container [ngTemplateOutlet]=\"cellDef.templateRef\" [ngTemplateOutletContext]=\"cellContext\" />\n                                        }\n                                        \n                                    }\n                                }\n                            </div>\n                        }\n                    </div>\n                }\n            }\n            <div class=\"virtualize post\" [style.height]=\"`${dmBlocks.postPixels}px`\"></div>\n        }\n    </div>\n</div>\n", styles: [":host{display:block;overflow:auto;min-height:300px;height:100%;max-height:100%;scrollbar-gutter:stable}:host .table{min-height:100%;display:grid;grid-template-rows:auto 1fr}:host .table .data-sizer{position:fixed;top:0;left:0;visibility:hidden;width:0}:host .table .column-row{display:flex;position:sticky;width:fit-content;top:0;box-shadow:inset 0 -1px 0 var(--twc-color-border);background:var(--twc-color-base);background-clip:padding-box;z-index:2;min-width:100%}:host .table .column-row .column-header{display:grid;grid-template-columns:100% 0;grid-template-rows:auto}:host .table .column-row .column-header .content{grid-column:1;grid-row:1}:host .table .column-row .column-header .content .header-button .content{display:grid;gap:.5em;grid-template-columns:1fr auto}:host .table .column-row .column-header .content .header-button .content .text{-webkit-user-select:none;user-select:none;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}:host .table .column-row .column-header .content .header-button .content .sort-indicator{display:flex;align-items:center}:host .table .column-row .column-header .content .header-button .content .sort-indicator .no-sort{color:var(--twc-color-text-gray)}:host .table .column-row .column-header .content .header-button .content .sort-indicator span{font-size:.8em;color:var(--twc-color-text-gray);margin-top:.1em}:host .table .column-row .column-header .content .header-button.not-sortable{outline:none;cursor:default}:host .table .column-row .column-header .content .header-button.not-sortable:hover{background:initial}:host .table .column-row .column-header .content .header-button.not-sortable .content{gap:0;grid-template-columns:1fr}:host .table .column-row .column-header.pinned-left{box-shadow:inset 0 -1px 0 var(--twc-color-border),inset -1px 0 0 var(--twc-color-border-light);left:0;background:var(--twc-color-base);position:sticky;z-index:4}:host .table .column-row .column-header.pinned-right{box-shadow:inset 0 -1px 0 var(--twc-color-border),inset 1px 0 0 var(--twc-color-border-light);right:0;background:var(--twc-color-base);position:sticky;z-index:4}:host .table .column-row .column-header .resizer{grid-column:2;grid-row:1;width:8px;cursor:col-resize;display:flex;justify-content:center;z-index:3;margin-left:-4px;margin-right:-4px}:host .table .column-row .column-header .resizer.last{margin-right:-8px}:host .table .column-row .column-header:hover .resizer .line{width:1px;background:var(--twc-color-border-light)}:host .table .column-row .column-header .resizer.enabled:hover .line{width:3px;background:var(--twc-color-primary)}:host .table .column-row .column-header .resizer:not(.enabled):hover{cursor:not-allowed}:host .table .column-row .column-header .resizer:not(.enabled):hover .line{width:3px;background:var(--twc-color-error)}:host .table .column-row .column-header .resizer.enabled.dragging .line{width:3px;background:var(--twc-color-primary)}:host .table .data-rows{width:fit-content;z-index:1}:host .table .data-rows .no-data{color:var(--twc-color-text-gray);margin-top:.5em;font-size:var(--twc-font-size-subtitle)}:host .table .data-rows .row{display:flex;width:fit-content;box-shadow:inset 0 -1px 0 var(--twc-color-border-light)}:host .table .data-rows .row .cell{display:flex;align-items:center;overflow:hidden}:host .table .data-rows .row .cell .line-clamp{overflow:hidden;display:-webkit-box;-webkit-box-orient:vertical;overflow-wrap:break-word}:host .table .data-rows .row .cell.pinned-left{box-shadow:inset 0 -1px 0 var(--twc-color-border-light),inset -1px 0 0 var(--twc-color-border-light);left:0;background:var(--twc-color-base);position:sticky}:host .table .data-rows .row .cell.pinned-right{box-shadow:inset 0 -1px 0 var(--twc-color-border-light),inset 1px 0 0 var(--twc-color-border-light);right:0;background:var(--twc-color-base);position:sticky}:host .table .data-rows .row .cell .status{border-radius:1em;min-height:1em;width:100%;height:1em;max-height:70%}:host .table .data-rows .row .cell .status.loader{background-color:var(--twc-color-highlight);animation:pulse 1.2s infinite ease-in-out}@keyframes pulse{0%{opacity:1}50%{opacity:.3}to{opacity:1}}:host .table .data-rows .row .cell .status.error{background-color:var(--twc-color-error);opacity:.3}:host .table .data-rows.striped .row:not(.even,.selected){background-color:var(--twc-color-mouse-highlight)}:host .table .data-rows.striped .row:not(.even,.selected) .pinned-left,:host .table .data-rows.striped .row:not(.even,.selected) .pinned-right{background-color:var(--twc-color-mouse-highlight)}:host .table.has-row-selection .data-rows .row:not(.selected):hover{background-color:var(--twc-color-highlight)}:host .table.has-row-selection .data-rows .row:not(.selected):hover .pinned-left,:host .table.has-row-selection .data-rows .row:not(.selected):hover .pinned-right{background-color:var(--twc-color-highlight)}:host .table.has-row-selection .data-rows .row:hover{cursor:pointer}:host .table.has-row-selection .data-rows .row:hover .pinned-left,:host .table.has-row-selection .data-rows .row:hover .pinned-right{cursor:pointer}:host .table .data-rows .row.selected{background-color:var(--twc-color-primary-light)}:host .table .data-rows .row.selected .pinned-left,:host .table .data-rows .row.selected .pinned-right{background-color:var(--twc-color-primary-light)}:host .table .check-select{display:flex;align-items:center;justify-content:center}.default-header-tooltip{display:flex;flex-direction:column;gap:.5em}.default-header-tooltip .column-name{font-weight:700}.default-header-tooltip .sort{display:flex;flex-direction:column;gap:.25em;font-size:.8em;color:var(--twc-color-text-gray)}\n"] }]
        }], propDecorators: { onScroll: [{
                type: HostListener,
                args: ['scroll', ['$event.target']]
            }] } });

class TableauUiTableModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiTableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.3", ngImport: i0, type: TableauUiTableModule, declarations: [TableComponent,
            HeaderDefDirective,
            HeaderToolipDefDirective,
            HeaderTooltipPipe,
            HeaderContextPipe,
            HeaderClassPipe,
            ColumnDefDirective,
            CellDefDirective,
            CellContextPipe,
            CellClassPipe,
            CellToolipDefDirective,
            CellTooltipPipe,
            SortInfoPipe,
            ColWidthPipe,
            ColRenderedWidthDirective,
            CellWidthPipe,
            ResizerDirective,
            HeaderCheckboxModePipe,
            RowSelectedPipe], imports: [CommonModule, TableauUiIconModule, TableauUiButtonModule, TableauUiTooltipModule, TableauUiCheckboxModule], exports: [TableComponent, HeaderDefDirective, HeaderToolipDefDirective, ColumnDefDirective, CellDefDirective, CellToolipDefDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiTableModule, imports: [CommonModule, TableauUiIconModule, TableauUiButtonModule, TableauUiTooltipModule, TableauUiCheckboxModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: TableauUiTableModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, TableauUiIconModule, TableauUiButtonModule, TableauUiTooltipModule, TableauUiCheckboxModule],
                    declarations: [
                        TableComponent,
                        HeaderDefDirective,
                        HeaderToolipDefDirective,
                        HeaderTooltipPipe,
                        HeaderContextPipe,
                        HeaderClassPipe,
                        ColumnDefDirective,
                        CellDefDirective,
                        CellContextPipe,
                        CellClassPipe,
                        CellToolipDefDirective,
                        CellTooltipPipe,
                        SortInfoPipe,
                        ColWidthPipe,
                        ColRenderedWidthDirective,
                        CellWidthPipe,
                        ResizerDirective,
                        HeaderCheckboxModePipe,
                        RowSelectedPipe,
                    ],
                    exports: [TableComponent, HeaderDefDirective, HeaderToolipDefDirective, ColumnDefDirective, CellDefDirective, CellToolipDefDirective],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { CellDefDirective, CellToolipDefDirective, ColumnDefDirective, FullDataOptions, HeaderDefDirective, HeaderToolipDefDirective, IncrementalDataOptions, MultiSelectionOptions, SingleSelectionOptions, TableComponent, TableauUiTableModule };
//# sourceMappingURL=tableau-ui-angular-table.mjs.map
