import * as i0 from '@angular/core';
import { Injectable } from '@angular/core';
import { toSignal } from '@angular/core/rxjs-interop';
import { BehaviorSubject, combineLatest, map } from 'rxjs';

class ThemeService {
    themeKey = 'theme-config';
    defaultTheme = {
        fontSize: '12px',
        mode: 'auto',
    };
    _theme$ = new BehaviorSubject(this.getInitialTheme());
    get theme$() {
        return this._theme$;
    }
    autoColor$ = new BehaviorSubject(window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light');
    $theme = toSignal(this._theme$, {
        initialValue: this._theme$.value,
    });
    appliedThemeMode$ = combineLatest([this._theme$, this.autoColor$]).pipe(map(([theme, autoColor]) => {
        return this.getAppliedThemeMode(theme, autoColor);
    }));
    $appliedThemeMode = toSignal(this.appliedThemeMode$, { initialValue: this.getAppliedThemeMode(this._theme$.value, this.autoColor$.value) });
    getAppliedThemeMode(theme, autoColor) {
        return theme.mode === 'auto' ? autoColor : theme.mode;
    }
    initialize() {
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', (e) => {
            if (e.matches) {
                this.autoColor$.next('dark');
            }
            else {
                this.autoColor$.next('light');
            }
        });
        this._theme$.subscribe((theme) => {
            localStorage.setItem(this.themeKey, JSON.stringify(theme));
            document.documentElement.style.setProperty('--twc-font-size', theme.fontSize);
        });
        combineLatest([this._theme$, this.autoColor$]).subscribe(([theme, autoColor]) => {
            const color = theme.mode === 'auto' ? autoColor : theme.mode;
            switch (color) {
                case 'dark':
                    {
                        if (!document.body.classList.contains('dark-mode')) {
                            document.body.classList.add('dark-mode');
                        }
                        document.body.style.colorScheme = 'dark';
                    }
                    break;
                case 'light':
                    {
                        if (document.body.classList.contains('dark-mode')) {
                            document.body.classList.remove('dark-mode');
                        }
                        document.body.style.colorScheme = 'light';
                    }
                    break;
            }
            const { fontSize } = theme;
            document.documentElement.style.setProperty('--twc-font-size-body', fontSize);
        });
    }
    setColorMode(mode) {
        const theme = this._theme$.value;
        theme.mode = mode;
        this._theme$.next(theme);
    }
    setFontSize(fontSize) {
        const theme = this._theme$.value;
        theme.fontSize = fontSize;
        this._theme$.next(theme);
    }
    reset() {
        this._theme$.next(this.defaultTheme);
    }
    getInitialTheme() {
        const storedTheme = localStorage.getItem(this.themeKey);
        if (storedTheme !== null) {
            const t = JSON.parse(storedTheme);
            t.fontSize = t.fontSize ?? '12px';
            t.mode = t.mode ?? 'auto';
            return t;
        }
        else {
            return this.defaultTheme;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ThemeService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ThemeService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.3", ngImport: i0, type: ThemeService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ThemeService };
//# sourceMappingURL=tableau-ui-angular-theme.mjs.map
