import * as _angular_core from '@angular/core';
import { ModelSignal, ElementRef, Signal, OnDestroy, InputSignal, WritableSignal, TemplateRef, OutputRefSubscription, PipeTransform } from '@angular/core';
import * as tableau_ui_angular_dialog from 'tableau-ui-angular/dialog';
import { DialogRef } from 'tableau-ui-angular/dialog';
import * as i8 from 'tableau-ui-angular/common';
import { PrefixComponent, SuffixComponent } from 'tableau-ui-angular/common';
import * as i7 from '@angular/common';
import * as i10 from 'tableau-ui-angular/icon';
import * as i11 from 'tableau-ui-angular/utils';

declare class MenuComponent {
    private readonly dialogService;
    private readonly elementRef;
    /**
     * The parent control to which the autocomplete is attached to
     * // nullable Signal type needs to be set explicitly -> ng-packagr strips nullability
     */
    readonly $parentControl: ModelSignal<ElementRef<HTMLElement> | undefined>;
    /**
     * The CSS text to apply to the dropdown container
     * @remarks
     * Use this to apply height, maxHeight, etc. to the dropdown container
     * @default '{}'
     */
    readonly $menuContainerCss: ModelSignal<Record<string, string>>;
    private readonly defaultContainerCss;
    /**
     * The CSS text to apply to the backdrop container
     * @remarks
     * Use this to apply user-select: none, etc. to the backdrop container
     * @default '{}'
     */
    readonly $backdropCss: ModelSignal<Record<string, string>>;
    /**
     * The width of the container
     * @remarks
     * Use 'parentWidth' to maintain the same width as the parent control
     * Use 'fit-content' to auto size the dropdown for the content
     * Use any CSS width value (1rem, 12px, etc) to explicitly set width
     * @default 'fit-content'
     */
    readonly $width: _angular_core.InputSignal<string>;
    /**
     * The max width of the container
     * @remarks
     * Keep it undefined for default behavior
     * Use any CSS width value (1rem, 12px, etc) to explicitly set maximum width
     * @default 'undefined'
     */
    readonly $maxWidth: _angular_core.InputSignal<string>;
    /**
     * The height of the container
     * @remarks
     * Use 'fit-content' to auto size the dropdown for the content
     * Use any CSS height value (1rem, 12px, etc) to explicitly set height
     * @default 'fit-content'
     */
    readonly $height: _angular_core.InputSignal<string>;
    /**
     * The max height of the container
     * @remarks
     * Keep it undefined for default behavior
     * Use any CSS height value (1rem, 12px, etc) to explicitly set maximum height
     * @default 'undefined'
     */
    readonly $maxHeight: _angular_core.InputSignal<string>;
    /**
     * Close on backdrop click
     * @remarks
     * When true, the menu will close when the backdrop is clicked
     * @default 'true'
     */
    readonly $closeOnBackdropClick: _angular_core.InputSignal<boolean>;
    /**
     * Close on escape key press
     * @remarks
     * When true, the menu will close when the escape key is pressed
     * @default 'true'
     */
    readonly $closeOnEscape: _angular_core.InputSignal<boolean>;
    /**
     * Trap focus within the menu
     * @remarks
     * When true, the focus will be trapped within the menu until it is closed
     * @default 'true'
     */
    readonly $trapFocus: _angular_core.InputSignal<boolean>;
    /**
     * The location of the menu relative to the parent control
     * @remarks
     * The menu may be repositioned if page bounds are hit to the opposite side
     * @default 'bottom'
     */
    readonly $menuLocation: _angular_core.InputSignal<"bottom" | "left" | "right" | "top">;
    protected readonly $prefix: Signal<PrefixComponent | undefined>;
    protected readonly $suffix: Signal<SuffixComponent | undefined>;
    private readonly $template;
    private readonly $openDialog;
    open(forceReOpen?: boolean): DialogRef<unknown>;
    close(): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<MenuComponent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<MenuComponent, "tab-menu", never, { "$parentControl": { "alias": "$parentControl"; "required": false; "isSignal": true; }; "$menuContainerCss": { "alias": "menuContainerCss"; "required": false; "isSignal": true; }; "$backdropCss": { "alias": "backdropCss"; "required": false; "isSignal": true; }; "$width": { "alias": "width"; "required": false; "isSignal": true; }; "$maxWidth": { "alias": "maxWidth"; "required": false; "isSignal": true; }; "$height": { "alias": "height"; "required": false; "isSignal": true; }; "$maxHeight": { "alias": "maxHeight"; "required": false; "isSignal": true; }; "$closeOnBackdropClick": { "alias": "closeOnBackdropClick"; "required": false; "isSignal": true; }; "$closeOnEscape": { "alias": "closeOnEscape"; "required": false; "isSignal": true; }; "$trapFocus": { "alias": "trapFocus"; "required": false; "isSignal": true; }; "$menuLocation": { "alias": "menuLocation"; "required": false; "isSignal": true; }; }, { "$parentControl": "$parentControlChange"; "$menuContainerCss": "menuContainerCssChange"; "$backdropCss": "backdropCssChange"; }, ["$prefix", "$suffix"], ["tab-prefix", "*", "tab-suffix"], false, never>;
}

declare class MenuDirective {
    readonly $menu: _angular_core.InputSignal<MenuComponent>;
    private readonly el;
    private readonly menuChanged;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<MenuDirective, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<MenuDirective, "[menu]", never, { "$menu": { "alias": "menu"; "required": true; "isSignal": true; }; }, {}, never, never, false, never>;
}

declare class MenuButtonComponent implements OnDestroy {
    readonly id: string;
    protected readonly contentElement: _angular_core.Signal<ElementRef<any>>;
    readonly $disabled: InputSignal<boolean>;
    readonly $loading: InputSignal<boolean>;
    readonly $color: InputSignal<"error" | "plain" | "primary" | "secondary">;
    readonly $hoverToOpenSubMenuMs: InputSignal<number | undefined>;
    readonly $actualHoverMs: WritableSignal<number | undefined>;
    readonly updateChildrenHover: _angular_core.EffectRef;
    readonly $highlight: WritableSignal<boolean>;
    highlightEffect: _angular_core.EffectRef;
    readonly highlightChange: _angular_core.OutputEmitterRef<boolean>;
    readonly $children: _angular_core.Signal<readonly MenuButtonComponent[]>;
    readonly mouseoverChange: _angular_core.OutputEmitterRef<boolean>;
    readonly $template: _angular_core.Signal<TemplateRef<null>>;
    readonly openSubMenu: _angular_core.OutputEmitterRef<Event>;
    readonly click: _angular_core.OutputEmitterRef<Event>;
    constructor();
    hoverInterval: ReturnType<typeof setTimeout> | undefined;
    hoverstart: number;
    onMouseEnter(): void;
    onMouseLeave(): void;
    ngOnDestroy(): void;
    onMouseDown(e: Event): void;
    onClick(e: Event): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<MenuButtonComponent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<MenuButtonComponent, "tab-menu-button", never, { "$disabled": { "alias": "disabled"; "required": false; "isSignal": true; }; "$loading": { "alias": "loading"; "required": false; "isSignal": true; }; "$color": { "alias": "color"; "required": false; "isSignal": true; }; "$hoverToOpenSubMenuMs": { "alias": "hoverToOpenSubMenuMs"; "required": false; "isSignal": true; }; }, { "highlightChange": "highlightChange"; "mouseoverChange": "mouseoverChange"; "openSubMenu": "openSubMenu"; "click": "click"; }, ["$children"], ["*"], false, never>;
}

declare class MenuButtonGroupComponent implements OnDestroy {
    readonly nativeElement: ElementRef<HTMLElement>;
    readonly $hoverToOpenSubMenuMs: InputSignal<number | undefined>;
    readonly buttonClicked: _angular_core.OutputEmitterRef<{
        button: MenuButtonComponent;
        event: Event;
    }>;
    protected readonly $children: _angular_core.Signal<readonly MenuButtonComponent[]>;
    private previousChildrenIds;
    readonly childrenEffect: _angular_core.EffectRef;
    readonly $menuGroupStack: WritableSignal<IMenuGroup[]>;
    private readonly $height;
    private readonly $width;
    init(): void;
    ngOnDestroy(): void;
    addMenuGroup(parentButton?: MenuButtonComponent): IMenuGroup;
    updateSizes(): void;
    destroyGroupsUntil(id?: string): void;
    onFocusIn(): void;
    onFocusOut(): void;
    onKeyDown(event: KeyboardEvent): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<MenuButtonGroupComponent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<MenuButtonGroupComponent, "tab-menu-button-group", never, { "$hoverToOpenSubMenuMs": { "alias": "hoverToOpenSubMenuMs"; "required": false; "isSignal": true; }; }, { "buttonClicked": "buttonClicked"; }, ["$children"], never, false, never>;
}
interface IMenuGroup {
    id: string;
    $top: WritableSignal<number>;
    $left: WritableSignal<number>;
    $position: WritableSignal<'absolute' | 'fixed'>;
    parentButton: HTMLElement | null;
    buttons: readonly MenuButtonComponent[];
    element: Element | null;
    mouseoverSubscriptions: OutputRefSubscription[];
    openSubMenuSubscriptions: OutputRefSubscription[];
    clickSubscriptions: OutputRefSubscription[];
    highlightSubscriptions: OutputRefSubscription[];
}

declare class ButtonMenuComponent extends MenuComponent implements OnDestroy {
    readonly $menuContainerCss: ModelSignal<Record<string, string>>;
    readonly $closeOnBackdropClick: InputSignal<boolean>;
    readonly $width: ModelSignal<string | 'fit-content' | 'parentWidth'>;
    readonly menuGroup: Signal<MenuButtonGroupComponent | undefined>;
    private readonly subs;
    open(forceReOpen?: boolean): tableau_ui_angular_dialog.DialogRef<unknown>;
    ngOnDestroy(): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<ButtonMenuComponent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<ButtonMenuComponent, "tab-button-menu", never, { "$menuContainerCss": { "alias": "menuContainerCss"; "required": false; "isSignal": true; }; "$closeOnBackdropClick": { "alias": "closeOnBackdropClick"; "required": false; "isSignal": true; }; "$width": { "alias": "width"; "required": false; "isSignal": true; }; }, { "$menuContainerCss": "menuContainerCssChange"; "$closeOnBackdropClick": "closeOnBackdropClickChange"; "$width": "widthChange"; }, ["menuGroup"], ["tab-prefix", "*", "tab-suffix"], false, never>;
}

declare class EntriesPipe implements PipeTransform {
    transform<T>(arr: readonly T[]): [number, T][];
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<EntriesPipe, never>;
    static ɵpipe: _angular_core.ɵɵPipeDeclaration<EntriesPipe, "entries", false>;
}

declare class TableauUiMenuModule {
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<TableauUiMenuModule, never>;
    static ɵmod: _angular_core.ɵɵNgModuleDeclaration<TableauUiMenuModule, [typeof MenuComponent, typeof MenuDirective, typeof MenuButtonComponent, typeof MenuButtonGroupComponent, typeof ButtonMenuComponent, typeof EntriesPipe], [typeof i7.CommonModule, typeof i8.TableauUiCommonModule, typeof tableau_ui_angular_dialog.TableauUiDialogModule, typeof i10.TableauUiIconModule, typeof i11.TableauUiUtilsModule], [typeof MenuComponent, typeof MenuDirective, typeof MenuButtonComponent, typeof MenuButtonGroupComponent, typeof ButtonMenuComponent]>;
    static ɵinj: _angular_core.ɵɵInjectorDeclaration<TableauUiMenuModule>;
}

export { ButtonMenuComponent, MenuButtonComponent, MenuButtonGroupComponent, MenuComponent, MenuDirective, TableauUiMenuModule };
