import * as i0 from '@angular/core';
import { TemplateRef, Type } from '@angular/core';
import { Observable } from 'rxjs';
import * as i2 from '@angular/common';
import * as i3 from 'tableau-ui-angular/icon';
import * as i4 from '@angular/router';

declare function injectSnackRef<T>(): SnackRef<T>;
interface ISnackRef {
    closed$: Observable<unknown | undefined>;
    close: () => void;
}
declare class SnackRef<T = unknown> implements ISnackRef {
    private readonly _closed$;
    readonly closed$: Observable<T | undefined>;
    private _result;
    close(result?: T): void;
    /**
     * Sets the result of the dialog without closing it.
     * This is useful for cases where you want to update the result
     * but keep the dialog open, such as in a form submission.
     * If the close() function is called with a non-undefined result, it will overwrite this value
     * @param result The result to set.
     */
    setResultWithoutClosing(result?: T): void;
}

declare class SnackService {
    private readonly injector;
    private readonly appRef;
    private readonly environmentInjector;
    openSnack(message: string, duration?: number | undefined, type?: 'error' | 'info' | 'success', location?: 'bottom' | 'top'): SnackRef<boolean>;
    openSnackWithAction(message: string, actionLabel: string, action: (s: SnackRef<boolean>) => void, duration?: number | undefined, type?: 'error' | 'info' | 'success', location?: 'bottom' | 'top'): SnackRef<boolean>;
    openSnackFromTemplate<TContext>(template: TemplateRef<TContext>, templateContext?: TContext, duration?: number | undefined, type?: 'error' | 'info' | 'success', location?: 'bottom' | 'top'): SnackRef<boolean>;
    openSnackComponent<TComponent, TData, TResult>(component: Type<TComponent>, data: TData, duration?: number | undefined, type?: 'error' | 'info' | 'success', location?: 'bottom' | 'top'): SnackRef<TResult>;
    private createView;
    static ɵfac: i0.ɵɵFactoryDeclaration<SnackService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SnackService>;
}

declare function injectSnackData<T>(): T;

declare class SnackComponent<TContext> {
    protected readonly data: SnackComponentData<TContext>;
    protected readonly snackRef: SnackRef<boolean>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SnackComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SnackComponent<any>, "tab-snack", never, {}, {}, never, never, false, never>;
}
interface SnackComponentData<TContext> {
    type: 'error' | 'info' | 'success';
    message: string | undefined;
    actionLink?: string | undefined;
    action?: ((s: SnackRef<boolean>) => void) | undefined;
    contentTemplate: TemplateRef<TContext> | undefined;
    contentTemplateContext: TContext | undefined;
}

declare class TableauUiSnackModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<TableauUiSnackModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<TableauUiSnackModule, [typeof SnackComponent], [typeof i2.CommonModule, typeof i3.TableauUiIconModule, typeof i4.RouterModule], never>;
    static ɵinj: i0.ɵɵInjectorDeclaration<TableauUiSnackModule>;
}

export { SnackRef, SnackService, TableauUiSnackModule, injectSnackData, injectSnackRef };
