import * as i0 from '@angular/core';
import { Signal, OnInit, OnDestroy, InputSignal, TemplateRef, WritableSignal, AfterContentInit } from '@angular/core';
import * as rxjs from 'rxjs';
import * as i5 from '@angular/common';
import * as i6 from 'tableau-ui-angular/button';
import * as i7 from 'tableau-ui-angular/icon';
import * as i8 from 'tableau-ui-angular/tooltip';

declare class CollapsedContentDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<CollapsedContentDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CollapsedContentDirective, "[collapsedContent]", never, {}, {}, never, never, false, never>;
}

declare class ExpandedContentDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<ExpandedContentDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ExpandedContentDirective, "[expandedContent]", never, {}, {}, never, never, false, never>;
}

declare class TreeNodeRegistry {
    readonly nodes: i0.WritableSignal<TabTreeNodeComponent[]>;
    register(node: TabTreeNodeComponent): void;
    unregister(node: TabTreeNodeComponent): void;
}

interface TreeNodeInterface {
    $parent: Signal<TreeNodeInterface | null>;
    $expanded: Signal<boolean>;
}

declare class TabTreeNodeComponent implements OnInit, OnDestroy, TreeNodeInterface {
    readonly headerButtonId: string;
    private readonly hierarchyModeAutoParent;
    private readonly tabTree;
    readonly $expanded: i0.ModelSignal<boolean>;
    readonly expanded$: rxjs.Observable<boolean>;
    readonly expandedChange: i0.OutputEmitterRef<boolean>;
    protected readonly $collapsedContent: Signal<CollapsedContentDirective | undefined>;
    protected readonly $expandedContent: Signal<ExpandedContentDirective | undefined>;
    readonly $expandButtonColor: InputSignal<string | undefined>;
    readonly $template: Signal<TemplateRef<TreeNodeTemplate> | undefined>;
    readonly $hierarchyId: InputSignal<string>;
    readonly $hierarchyParentId: InputSignal<string | undefined>;
    readonly $children: WritableSignal<TabTreeNodeComponent[]>;
    readonly $parent: WritableSignal<TabTreeNodeComponent | null>;
    readonly $allParentsExpanded: Signal<boolean>;
    readonly $depth: WritableSignal<number>;
    readonly $order: InputSignal<number>;
    readonly $registry: InputSignal<TreeNodeRegistry>;
    ngOnInit(): void;
    ngOnDestroy(): void;
    setExpanded(expanded: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TabTreeNodeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TabTreeNodeComponent, "tab-tree-node", never, { "$expanded": { "alias": "expanded"; "required": false; "isSignal": true; }; "$expandButtonColor": { "alias": "expandButtonColor"; "required": false; "isSignal": true; }; "$hierarchyId": { "alias": "hierarchyId"; "required": false; "isSignal": true; }; "$hierarchyParentId": { "alias": "hierarchyParentId"; "required": false; "isSignal": true; }; "$order": { "alias": "order"; "required": false; "isSignal": true; }; "$registry": { "alias": "registry"; "required": false; "isSignal": true; }; }, { "$expanded": "expandedChange"; "expandedChange": "expandedChange"; }, ["$collapsedContent", "$expandedContent"], ["[expandedContent]", "[collapsedContent]", "*"], false, never>;
}
interface TreeNodeTemplate {
    $childrenIndent: Signal<string>;
    $expandButtonSize: Signal<string>;
    $expandButtonColor: Signal<string | undefined>;
    $expandButtonGap: Signal<string | undefined>;
    $expandButtonTooltip: Signal<ExpandButtonTooltipParams | undefined>;
    $expandButtonAlign: Signal<string>;
    $keepButtonOffsetOnNoChildren: Signal<boolean>;
}

declare class TabTreeComponent implements AfterContentInit, OnDestroy {
    private readonly selfElementRef;
    readonly $showRootGridLines: InputSignal<boolean>;
    readonly $gridLinesBorder: InputSignal<string | undefined>;
    readonly $gridLinesBorderRadius: InputSignal<string>;
    readonly $expandButtonSize: InputSignal<string>;
    readonly $expandButtonColor: InputSignal<string | undefined>;
    readonly $expandButtonGap: InputSignal<string | undefined>;
    readonly $expandButtonTooltip: InputSignal<ExpandButtonTooltipParams | undefined>;
    readonly $expandButtonAlign: InputSignal<string>;
    readonly $childrenIndent: InputSignal<string>;
    readonly $keepButtonOffsetOnNoChildren: InputSignal<boolean>;
    readonly $hierarchyMode: InputSignal<"auto" | "manual">;
    readonly registry: TreeNodeRegistry;
    templateParams: TreeNodeTemplate;
    constructor();
    hierarchyModeAutoSetChildrenDepthAndId(allNodes: TabTreeNodeComponent[], node: TabTreeNodeComponent, parentNode: TabTreeNodeComponent | null, depth: number): void;
    hierarchyModeManualSetChildrenDepthAndId(child: TabTreeNodeComponent, currentChildDepth: number): void;
    protected readonly $childrenDisplayOrder: i0.Signal<TabTreeNodeComponent[]>;
    getChildrenDisplayOrder(node: TabTreeNodeComponent): TabTreeNodeComponent[];
    private resizeObserver;
    ngAfterContentInit(): void;
    ngOnDestroy(): void;
    existingGridLines: {
        id: string;
        element: HTMLDivElement;
    }[];
    private redrawCounter;
    redrawGridLines(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TabTreeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TabTreeComponent, "tab-tree", never, { "$showRootGridLines": { "alias": "showRootGridLines"; "required": false; "isSignal": true; }; "$gridLinesBorder": { "alias": "gridLinesBorder"; "required": false; "isSignal": true; }; "$gridLinesBorderRadius": { "alias": "gridLinesBorderRadius"; "required": false; "isSignal": true; }; "$expandButtonSize": { "alias": "expandButtonSize"; "required": false; "isSignal": true; }; "$expandButtonColor": { "alias": "expandButtonColor"; "required": false; "isSignal": true; }; "$expandButtonGap": { "alias": "expandButtonGap"; "required": false; "isSignal": true; }; "$expandButtonTooltip": { "alias": "expandButtonTooltip"; "required": false; "isSignal": true; }; "$expandButtonAlign": { "alias": "expandButtonAlign"; "required": false; "isSignal": true; }; "$childrenIndent": { "alias": "childrenIndent"; "required": false; "isSignal": true; }; "$keepButtonOffsetOnNoChildren": { "alias": "keepButtonOffsetOnNoChildren"; "required": false; "isSignal": true; }; "$hierarchyMode": { "alias": "hierarchyMode"; "required": false; "isSignal": true; }; }, {}, never, never, false, never>;
}
interface ExpandButtonTooltipParams<T = unknown> {
    expand: TemplateRef<T> | string | undefined;
    collapse: TemplateRef<T> | string | undefined;
    position: 'bottom' | 'left' | 'right' | 'top';
    margin?: string;
    context?: T | undefined;
}

declare class TableauUiTreeModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<TableauUiTreeModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<TableauUiTreeModule, [typeof TabTreeComponent, typeof TabTreeNodeComponent, typeof ExpandedContentDirective, typeof CollapsedContentDirective], [typeof i5.CommonModule, typeof i6.TableauUiButtonModule, typeof i7.TableauUiIconModule, typeof i8.TableauUiTooltipModule], [typeof TabTreeComponent, typeof TabTreeNodeComponent, typeof ExpandedContentDirective, typeof CollapsedContentDirective]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<TableauUiTreeModule>;
}

export { CollapsedContentDirective, ExpandedContentDirective, TabTreeComponent, TabTreeNodeComponent, TableauUiTreeModule, TreeNodeRegistry };
export type { ExpandButtonTooltipParams };
